import _extends from "@babel/runtime/helpers/extends";
import _typeof from "@babel/runtime/helpers/typeof";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children", "collapsed", "contentProps", "hasDivider", "headerProps", "icon", "id", "sticky", "stickySectionProps", "subTitle", "title", "titleTag", "type", "onClick"];
import React, { useEffect, useState, useRef, useCallback } from 'react';
import { spacingLv1 } from 'unify-token/build/v2/spacings';
import { canUseDOM } from "../../build/Providers/common/functions";
import { noop } from "../../build/Providers/common/functions/noop";
import { Container, Content, Divider, StickySection, ContentChildren } from "./style";
import AccordionHeader from "./_AccordionHeader";

var Accordion = function Accordion(_ref) {
  var children = _ref.children,
      _ref$collapsed = _ref.collapsed,
      collapsed = _ref$collapsed === void 0 ? false : _ref$collapsed,
      _ref$contentProps = _ref.contentProps,
      contentProps = _ref$contentProps === void 0 ? {} : _ref$contentProps,
      _ref$hasDivider = _ref.hasDivider,
      hasDivider = _ref$hasDivider === void 0 ? true : _ref$hasDivider,
      _ref$headerProps = _ref.headerProps,
      headerProps = _ref$headerProps === void 0 ? {} : _ref$headerProps,
      icon = _ref.icon,
      id = _ref.id,
      _ref$sticky = _ref.sticky,
      sticky = _ref$sticky === void 0 ? false : _ref$sticky,
      _ref$stickySectionPro = _ref.stickySectionProps,
      stickySectionProps = _ref$stickySectionPro === void 0 ? {} : _ref$stickySectionPro,
      subTitle = _ref.subTitle,
      title = _ref.title,
      _ref$titleTag = _ref.titleTag,
      titleTag = _ref$titleTag === void 0 ? 6 : _ref$titleTag,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'default' : _ref$type,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? noop : _ref$onClick,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var containerRef = useRef(null);
  var headerRef = useRef(null);
  var contentRef = useRef(null);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      topOfSticky = _useState2[0],
      setTopOfSticky = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      contentHeight = _useState4[0],
      setContentHeight = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      switchPosition = _useState6[0],
      setSwitchPosition = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      isSticky = _useState8[0],
      setSticky = _useState8[1];

  var _useState9 = useState(collapsed),
      _useState10 = _slicedToArray(_useState9, 2),
      isCollapsed = _useState10[0],
      setIsCollapsed = _useState10[1];

  var titleToId = typeof title === 'string' ? title.split(' ').join('-') : '';
  var accordionId = id ? id : titleToId;

  var getContentHeight = function getContentHeight() {
    if (!contentRef.current || !contentRef.current.scrollHeight) {
      return;
    }

    canUseDOM && setContentHeight(contentRef.current.scrollHeight);
  };

  var handleSticky = useCallback(function () {
    if (!headerRef.current || !headerRef.current.scrollHeight) {
      return;
    }

    if (!containerRef.current || !containerRef.current.scrollHeight) {
      return;
    }

    if (canUseDOM) {
      var heightOfHeader = headerRef.current.scrollHeight;
      var topOfContainer = containerRef.current.getBoundingClientRect().top;
      var heightOfContainer = containerRef.current.scrollHeight;
      var SPACER = parseInt(spacingLv1, 10);

      if (typeof sticky === 'boolean') {
        setTopOfSticky(0);
        setSticky(sticky);
      } else if (_typeof(sticky) === 'object') {
        if (sticky.top === (undefined || null) || sticky.top < 0 || typeof sticky.top !== 'number') {
          setSticky(false);
        } else {
          setTopOfSticky(sticky.top);
          setSticky(sticky);
        }
      }

      if (topOfContainer <= topOfSticky && topOfContainer - topOfSticky >= Math.abs(heightOfContainer) * -1) {
        setSticky(sticky);

        if (!isCollapsed && topOfContainer - topOfSticky <= Math.abs(heightOfContainer - heightOfHeader) * -1 + SPACER) {
          setSwitchPosition(true);
        } else {
          setSwitchPosition(false);
        }
      } else {
        setSticky(false);
      }
    }
  }, [sticky, topOfSticky, isCollapsed]);
  useEffect(function () {
    return setIsCollapsed(collapsed);
  }, [collapsed]);
  useEffect(function () {
    if (canUseDOM && isCollapsed) {
      contentHeight === 'auto' && getContentHeight();
      var autoTimeout = setTimeout(function () {
        setContentHeight(0);
      }, 20);
      return function () {
        return clearTimeout(autoTimeout);
      };
    } else {
      getContentHeight();

      var _autoTimeout = setTimeout(function () {
        setContentHeight('auto');
      }, 1000);

      return function () {
        return clearTimeout(_autoTimeout);
      };
    }
  }, [isCollapsed]);
  useEffect(function () {
    if (canUseDOM) {
      window.addEventListener('scroll', handleSticky);
    }

    return function () {
      if (canUseDOM) {
        window.removeEventListener('scroll', handleSticky);
      }
    };
  }, [handleSticky]);

  var handleClick = function handleClick(e) {
    onClick(e);
    setIsCollapsed(function (prevOpen) {
      return !prevOpen;
    });
  };

  var renderStickySection = function renderStickySection() {
    if (!isCollapsed && isSticky) {
      return React.createElement(StickySection, _extends({
        className: "unf-accordion__sticky-section",
        switchPosition: switchPosition,
        position: topOfSticky,
        zIndex: typeof sticky === 'boolean' ? 1 : sticky.zIndex,
        maxWidth: typeof sticky === 'boolean' ? '100%' : sticky.maxWidth
      }, stickySectionProps), React.createElement(AccordionHeader, {
        onClick: handleClick,
        collapsed: isCollapsed,
        icon: icon,
        id: accordionId,
        titleTag: titleTag,
        title: title,
        subTitle: subTitle
      }));
    }
  };

  return React.createElement(Container, _extends({
    className: isCollapsed ? 'unf-accordion' : 'unf-accordion unf-accordion--active',
    innerRef: containerRef
  }, otherProps), React.createElement(AccordionHeader, _extends({
    collapsed: isCollapsed,
    onClick: handleClick,
    icon: icon,
    id: accordionId,
    titleTag: titleTag,
    title: title,
    type: type,
    subTitle: subTitle,
    innerRef: headerRef
  }, headerProps)), React.createElement(Content, _extends({
    id: "content-".concat(accordionId),
    "aria-labelledby": "header-".concat(accordionId),
    className: isCollapsed ? 'unf-accordion__content' : 'unf-accordion__content unf-accordion__content--active',
    contentHeight: contentHeight,
    collapsed: isCollapsed,
    innerRef: contentRef
  }, contentProps, {
    "aria-hidden": isCollapsed
  }), React.createElement("div", {
    className: ContentChildren
  }, children)), hasDivider && React.createElement(Divider, null), renderStickySection());
};

Accordion.Header = AccordionHeader;
export default Accordion;