import React from 'react';
declare type AccordionAttributes = React.ComponentPropsWithoutRef<'div'>;
export interface AccordionProps extends Omit<AccordionAttributes, 'css'> {
    /**
     * Set Accordion into collapsed
     */
    collapsed?: boolean;
    /**
     * Set Accordion body content to custom component
     */
    contentProps?: React.ComponentPropsWithoutRef<'div'>;
    /**
     * To apply divider element
     */
    hasDivider?: boolean;
    /**
     * Insert custom property into AccordionHeader
     */
    headerProps?: React.ComponentPropsWithoutRef<'div'>;
    /**
     * To specify image source
     */
    icon?: React.ReactNode;
    /**
     * Give component unique identifier, also used for a11y
     */
    id?: string;
    /**
     * To apply header sticky design
     */
    sticky?: boolean | {
        top: number;
        zIndex: number;
        maxWidth: string;
    };
    /**
     * Set Accordion subTitle
     */
    subTitle?: string;
    /**
     * Insert custom property into StickySection
     */
    stickySectionProps?: Omit<React.ComponentPropsWithoutRef<'div'>, 'css'>;
    /**
     * Set Accordion title
     */
    title?: string;
    /**
     * To change html tag on title
     */
    titleTag?: number;
    /**
     * To set the type of accordion
     */
    type?: 'default' | 'text';
    /**
     * Action when Header is clicked
     */
    onClick?: (e: React.MouseEvent<HTMLDivElement>) => void;
}
export interface ContentProps extends Pick<AccordionProps, 'collapsed'> {
    contentHeight?: number | string;
}
export interface StickySectionProps {
    maxWidth?: string;
    position?: number;
    switchPosition?: boolean;
    top?: number;
    zIndex?: number;
}
export interface AccordionHeaderProps extends AccordionProps {
    hasSubtitle?: boolean;
}
export {};
