import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["actionText", "children", "className", "closeProps", "display", "dynamicContent", "full", "initialPos", "lang", "padding", "title", "titleProps", "withClose", "withKnob", "onActionClick", "onClose", "onDrag", "onDragEnd", "onDragStart", "onMaximize", "onMinimize", "onScroll"],
    _excluded2 = ["children", "className"];
import React, { useEffect, useRef, useState } from 'react';
import { cx } from 'react-emotion';
import { durationT4 } from 'unify-token/build/v2/motions';
import Close from 'unify-icons/system/Close';
import { NN900 } from 'unify-token/colors';
import wrapper from "../../build/Providers/common/HOC/withBottomSheetOverlay";
import Typography from "../../build/Typography";
import Link from "../../build/Link";
import { canUseDOM } from "../../build/Providers/common/functions";
import { clamp, getTapPosition, isAndroid, isEditableElement } from "./_utils";
import { Wrapper, InnerWrapper, Sheet, Content, Header, DragHandler } from "./style";
export var CLASSNAMES = {
  sheet: 'unf-sheet',
  wrapper: 'unf-sheet__wrapper',
  innerWrapper: 'unf-sheet__inner-wrapper',
  dragHandler: 'unf-sheet__drag-handler',
  closeButton: 'unf-sheet__close-btn',
  content: 'unf-sheet__content',
  header: 'unf-sheet__header',
  actionText: 'unf-sheet__action-text',
  title: 'unf-sheet__title'
};
export var BUTTON_LABELS = {
  closeButton: {
    en: 'Close current display',
    id: 'Tutup tampilan ini'
  }
};
var DRAG_THRESHOLD = 40;
var MIN_DEVICE_HEIGHT = 568;
export var BaseBottomSheetV2 = function BaseBottomSheetV2(_ref) {
  var actionText = _ref.actionText,
      children = _ref.children,
      className = _ref.className,
      closeProps = _ref.closeProps,
      _ref$display = _ref.display,
      display = _ref$display === void 0 ? false : _ref$display,
      _ref$dynamicContent = _ref.dynamicContent,
      dynamicContent = _ref$dynamicContent === void 0 ? true : _ref$dynamicContent,
      _ref$full = _ref.full,
      full = _ref$full === void 0 ? false : _ref$full,
      _ref$initialPos = _ref.initialPos,
      initialPos = _ref$initialPos === void 0 ? 0 : _ref$initialPos,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? '0' : _ref$padding,
      title = _ref.title,
      titleProps = _ref.titleProps,
      _ref$withClose = _ref.withClose,
      withClose = _ref$withClose === void 0 ? true : _ref$withClose,
      _ref$withKnob = _ref.withKnob,
      withKnob = _ref$withKnob === void 0 ? false : _ref$withKnob,
      onActionClick = _ref.onActionClick,
      onClose = _ref.onClose,
      onDrag = _ref.onDrag,
      onDragEnd = _ref.onDragEnd,
      onDragStart = _ref.onDragStart,
      onMaximize = _ref.onMaximize,
      onMinimize = _ref.onMinimize,
      onScroll = _ref.onScroll,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var SCREEN_HEIGHT = canUseDOM ? Math.min(document.documentElement.clientHeight, window.innerHeight) : MIN_DEVICE_HEIGHT;
  var MAX_SHEET_HEIGHT = Math.round(SCREEN_HEIGHT * 0.95);
  var CLOSE_TRIGGER_THRESHOLD = Math.round(MAX_SHEET_HEIGHT * 0.4);
  var innerWrapperElement = useRef(null);
  var hasMounted = useRef(false);
  var hasInputFocus = useRef(false);
  var initialSheetPosition = useRef(0);
  var initialSheetContentHeight = useRef(0);
  var sheetLastPosition = useRef(0);
  var tapGapFromHeader = useRef(0);
  var isFull = useRef(full);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isDisplay = _useState2[0],
      setDisplay = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      isDragging = _useState4[0],
      setDragging = _useState4[1];

  var _useState5 = useState(full),
      _useState6 = _slicedToArray(_useState5, 2),
      isMaximized = _useState6[0],
      setMaximized = _useState6[1];

  var _useState7 = useState(0),
      _useState8 = _slicedToArray(_useState7, 2),
      sheetCurrentPosition = _useState8[0],
      setSheetCurrentPosition = _useState8[1];

  var clampPosition = function clampPosition(position) {
    return clamp(position, 0, MAX_SHEET_HEIGHT);
  };

  useEffect(getInitialSheetPosition, [initialPos, full]);
  useEffect(syncDisplayState, [display]);
  useEffect(attachInputFocusListeners, []);
  useEffect(setMounted, []);

  function getInitialSheetPosition() {
    var _innerWrapperElement$;

    var hasInitialPosition = initialPos !== 0;
    var sheetContentHeight = ((_innerWrapperElement$ = innerWrapperElement.current) === null || _innerWrapperElement$ === void 0 ? void 0 : _innerWrapperElement$.scrollHeight) || 0;
    var initialPositionDeductor = hasInitialPosition ? initialPos : sheetContentHeight;
    var initialPosition = clampPosition(MAX_SHEET_HEIGHT - initialPositionDeductor);
    var isFullOfContent = initialPosition === 0;
    var sheetPosition = full || isFullOfContent ? 0 : initialPosition;
    var halfSheetHeight = MAX_SHEET_HEIGHT / 2;
    var isAlmostFull = initialPosition <= DRAG_THRESHOLD;
    initialSheetPosition.current = isAlmostFull ? halfSheetHeight : initialPosition;
    initialSheetContentHeight.current = sheetContentHeight;
    setSheetCurrentPosition(sheetPosition);
    setContentHeight();

    if (full || isAlmostFull) {
      maximizeSheet();
    }
  }

  function syncDisplayState() {
    setDisplay(display);
    display && setTimeout(handleSheetTransitionDuration, 400);
  }

  function handleSheetTransitionDuration() {
    var _innerWrapperElement$2;

    var sheetElement = (_innerWrapperElement$2 = innerWrapperElement.current) === null || _innerWrapperElement$2 === void 0 ? void 0 : _innerWrapperElement$2.parentElement;

    if (sheetElement) {
      sheetElement.style.transitionDuration = isDragging ? '0ms' : durationT4;
    }
  }

  function setContentHeight() {
    var hasInitialPosition = initialPos !== 0;

    if (!full && !hasInitialPosition && !dynamicContent && !withKnob) {
      if (innerWrapperElement.current) {
        innerWrapperElement.current.style.height = "".concat(initialSheetContentHeight.current, "px");
      }
    }
  }

  function attachInputFocusListeners() {
    var wrapper = innerWrapperElement.current;
    var hasInputElementChildren = (wrapper === null || wrapper === void 0 ? void 0 : wrapper.querySelectorAll('input').length) !== 0;

    function handleInputFocus(event) {
      var target = event.target,
          type = event.type;
      var isFocusEvent = type === 'focusin';
      var isBlurEvent = type === 'focusout';

      function handleFocusEvent() {
        setSheetCurrentPosition(0);
      }

      function handleBlurEvent() {
        if (!isFull.current) {
          setSheetCurrentPosition(initialSheetPosition.current);
        }
      }

      if (isEditableElement(target)) {
        hasInputFocus.current = isFocusEvent;

        if (isAndroid && !full) {
          isFocusEvent && handleFocusEvent();
          isBlurEvent && handleBlurEvent();
        }
      }
    }

    if (!hasMounted.current) {
      if (wrapper && hasInputElementChildren) {
        wrapper.addEventListener('focusin', handleInputFocus);
        wrapper.addEventListener('focusout', handleInputFocus);
      }
    }

    return function () {
      if (wrapper && hasInputElementChildren) {
        wrapper.removeEventListener('focusin', handleInputFocus);
        wrapper.addEventListener('focusout', handleInputFocus);
      }
    };
  }

  function setMounted() {
    hasMounted.current = true;
  }

  function minimizeSheet() {
    setSheetCurrentPosition(initialSheetPosition.current);
    setMaximized(false);
    isFull.current = false;
    onMinimize && onMinimize();
  }

  function maximizeSheet() {
    setSheetCurrentPosition(0);
    setMaximized(true);
    isFull.current = true;
    onMaximize && onMaximize();
  }

  function closeSheet() {
    if (onClose && !hasInputFocus.current) {
      onClose();
    } else {
      minimizeSheet();
    }
  }

  function handleTouchStart(event) {
    var _innerWrapperElement$3, _innerWrapperElement$4;

    var _getTapPosition = getTapPosition(event),
        tapPosition = _getTapPosition.clientY;

    var sheetTopOffset = ((_innerWrapperElement$3 = innerWrapperElement.current) === null || _innerWrapperElement$3 === void 0 ? void 0 : _innerWrapperElement$3.getBoundingClientRect().top) || 0;
    var sheetContent = (_innerWrapperElement$4 = innerWrapperElement.current) === null || _innerWrapperElement$4 === void 0 ? void 0 : _innerWrapperElement$4.querySelector(".".concat(CLASSNAMES.content));
    var hasNoContentScroll = (sheetContent === null || sheetContent === void 0 ? void 0 : sheetContent.scrollTop) === 0;
    var isEditableElements = isEditableElement(event.target);
    var isButtonElement = event.target.nodeName === 'BUTTON';
    sheetLastPosition.current = sheetCurrentPosition;
    tapGapFromHeader.current = tapPosition - sheetTopOffset;

    if (hasNoContentScroll && !isEditableElements && !isButtonElement) {
      var _innerWrapperElement$5;

      setDragging(true);

      if ((_innerWrapperElement$5 = innerWrapperElement.current) !== null && _innerWrapperElement$5 !== void 0 && _innerWrapperElement$5.parentElement) {
        innerWrapperElement.current.parentElement.style.transitionDuration = '0ms';
      }

      onDragStart && onDragStart();
    }
  }

  function handleTouchMove(event) {
    var _getTapPosition2 = getTapPosition(event),
        tapPosition = _getTapPosition2.clientY;

    var sheetPosition = clampPosition(tapPosition - tapGapFromHeader.current);

    if (isDragging) {
      setSheetCurrentPosition(sheetPosition);
      onDrag && onDrag();
    }
  }

  function handleTouchEnd() {
    var _innerWrapperElement$6;

    if ((_innerWrapperElement$6 = innerWrapperElement.current) !== null && _innerWrapperElement$6 !== void 0 && _innerWrapperElement$6.parentElement) {
      innerWrapperElement.current.parentElement.style.transitionDuration = durationT4;
    }

    if (isDragging) {
      handleDragEnd();
    }

    setDragging(false);
  }

  function handleDragEnd() {
    var dragOffset = sheetLastPosition.current - sheetCurrentPosition;
    var isNotSimpleTap = dragOffset !== 0;
    var hasDraggedUp = dragOffset > DRAG_THRESHOLD;
    var hasDraggedDown = dragOffset < -DRAG_THRESHOLD;
    var hasDraggedDownFar = dragOffset < -CLOSE_TRIGGER_THRESHOLD;

    if (isNotSimpleTap) {
      switch (true) {
        case hasDraggedDownFar:
          closeSheet();
          break;

        case hasDraggedDown:
          isMaximized ? minimizeSheet() : closeSheet();
          break;

        case hasDraggedUp:
          maximizeSheet();
          break;

        default:
          isMaximized ? maximizeSheet() : minimizeSheet();
      }

      if (onDragEnd) {
        onDragEnd();
      }
    }
  }

  function handleActionClick() {
    if (onActionClick) {
      onActionClick();
    }
  }

  var sheetTapEvents = {
    onTouchStart: handleTouchStart,
    onTouchMove: handleTouchMove,
    onTouchEnd: handleTouchEnd,
    onMouseDown: handleTouchStart,
    onMouseMove: handleTouchMove,
    onMouseUp: handleTouchEnd,
    onMouseLeave: handleTouchEnd
  };
  var sheetStyle = withKnob ? {
    transform: "translate3d(0, ".concat(sheetCurrentPosition, "px, 0)")
  } : {};
  var sheetEventProps = withKnob ? sheetTapEvents : {};

  var sheetProps = _objectSpread({
    full: full,
    initialPos: initialPos,
    isDisplay: isDisplay,
    isMaximized: isMaximized,
    withKnob: withKnob,
    withClose: withClose,
    style: sheetStyle
  }, sheetEventProps);

  var wrapperProps = _objectSpread({
    isDisplay: isDisplay
  }, otherProps);

  var headerProps = {
    withKnob: withKnob,
    withClose: withClose
  };
  var contentProps = {
    padding: padding,
    withKnob: withKnob,
    isMaximized: isMaximized,
    onScroll: onScroll
  };
  return React.createElement(Wrapper, _extends({
    "aria-label": typeof title === 'string' ? title : undefined,
    className: cx(CLASSNAMES.wrapper, className),
    role: "dialog",
    "aria-modal": "true",
    "data-unify": "BottomSheetV2"
  }, wrapperProps), React.createElement(Sheet, _extends({
    className: CLASSNAMES.sheet
  }, sheetProps, {
    "data-unf": "unf-bottomsheet"
  }), React.createElement(InnerWrapper, {
    className: CLASSNAMES.innerWrapper,
    innerRef: innerWrapperElement
  }, (withClose || withKnob) && React.createElement(Header, _extends({
    className: CLASSNAMES.header
  }, headerProps), withKnob ? React.createElement(DragHandler, {
    className: CLASSNAMES.dragHandler,
    "data-unf": "unf-bottomsheet__drag-handler"
  }) : React.createElement(Close, _extends({
    "data-unf": "unf-bottomsheet__close",
    "aria-label": BUTTON_LABELS.closeButton[String(lang)],
    color: NN900,
    size: 22,
    onClick: closeSheet,
    className: CLASSNAMES.closeButton
  }, closeProps)), title && React.createElement(Title, _extends({
    className: CLASSNAMES.title,
    "data-unf": "unf-bottomsheet__title"
  }, titleProps), title), actionText && React.createElement(Link, {
    className: CLASSNAMES.actionText,
    "data-unf": "unf-bottomsheet__action-text",
    onClick: handleActionClick
  }, actionText)), React.createElement(Content, _extends({
    className: CLASSNAMES.content,
    "data-unf": "unf-bottomsheet__content-wrapper"
  }, contentProps), children))));
};

function Title(_ref2) {
  var children = _ref2.children,
      className = _ref2.className,
      titleProps = _objectWithoutProperties(_ref2, _excluded2);

  if (typeof children === 'string') {
    return React.createElement(Typography, _extends({
      color: NN900,
      className: className,
      main: true,
      tag: 3,
      margin: "0"
    }, titleProps), children);
  } else if (React.isValidElement(children)) {
    return React.createElement("div", {
      className: className
    }, children);
  }

  return null;
}

var wrapperElement = wrapper(BaseBottomSheetV2);
export default wrapperElement;