import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["alternate", "block", "children", "className", "disabled", "filled", "floating", "ghost", "image", "imagePosition", "inverted", "large", "loading", "main", "micro", "padding", "primary", "secondary", "secondaryGreen", "secondaryTransaction", "small", "tabIndex", "text", "transaction", "type", "onClick"];
import React, { Children, useRef } from 'react';
import { cx } from 'emotion';
import { NN0, NN0L, GN500, GN700, NN100 } from 'unify-token/colors';
import { noop } from "../../build/Providers/common/functions/noop";
import Floating from "../../build/Floating";
import LoadingCircle from "../../build/Providers/common/components/LoadingCircle";
import Ripple from "../../build/Providers/common/components/Ripple";
import Container, { ChildrenContainer, ChildrenWrapper } from "./style";

var Button = function Button(_ref) {
  var alternate = _ref.alternate,
      _ref$block = _ref.block,
      block = _ref$block === void 0 ? false : _ref$block,
      children = _ref.children,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$filled = _ref.filled,
      filled = _ref$filled === void 0 ? false : _ref$filled,
      _ref$floating = _ref.floating,
      floating = _ref$floating === void 0 ? false : _ref$floating,
      _ref$ghost = _ref.ghost,
      ghost = _ref$ghost === void 0 ? false : _ref$ghost,
      _ref$image = _ref.image,
      image = _ref$image === void 0 ? undefined : _ref$image,
      _ref$imagePosition = _ref.imagePosition,
      imagePosition = _ref$imagePosition === void 0 ? 'left' : _ref$imagePosition,
      _ref$inverted = _ref.inverted,
      inverted = _ref$inverted === void 0 ? false : _ref$inverted,
      _ref$large = _ref.large,
      large = _ref$large === void 0 ? false : _ref$large,
      _ref$loading = _ref.loading,
      loading = _ref$loading === void 0 ? false : _ref$loading,
      _ref$main = _ref.main,
      main = _ref$main === void 0 ? false : _ref$main,
      _ref$micro = _ref.micro,
      micro = _ref$micro === void 0 ? false : _ref$micro,
      padding = _ref.padding,
      _ref$primary = _ref.primary,
      primary = _ref$primary === void 0 ? false : _ref$primary,
      _ref$secondary = _ref.secondary,
      secondary = _ref$secondary === void 0 ? false : _ref$secondary,
      _ref$secondaryGreen = _ref.secondaryGreen,
      secondaryGreen = _ref$secondaryGreen === void 0 ? false : _ref$secondaryGreen,
      _ref$secondaryTransac = _ref.secondaryTransaction,
      secondaryTransaction = _ref$secondaryTransac === void 0 ? false : _ref$secondaryTransac,
      _ref$small = _ref.small,
      small = _ref$small === void 0 ? false : _ref$small,
      _ref$tabIndex = _ref.tabIndex,
      tabIndex = _ref$tabIndex === void 0 ? 0 : _ref$tabIndex,
      _ref$text = _ref.text,
      text = _ref$text === void 0 ? false : _ref$text,
      _ref$transaction = _ref.transaction,
      transaction = _ref$transaction === void 0 ? false : _ref$transaction,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'button' : _ref$type,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? noop : _ref$onClick,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var buttonClasses = function buttonClasses() {
    return cx('unf-btn', 'unf-btn--animate', {
      'unf-btn--filled': filled,
      'unf-btn--transaction': transaction,
      'unf-btn--primary': primary,
      'unf-btn--secondary': secondary,
      'unf-btn--secondaryGreen': secondaryGreen,
      'unf-btn--secondaryTransaction': secondaryTransaction,
      'unf-btn--disabled': disabled,
      'unf-btn--large': large || floating,
      'unf-btn--small': small,
      'unf-btn--block': block
    }, className);
  };

  var rippleRef = useRef(null);

  var handleClick = function handleClick(e) {
    !loading && onClick(e);
  };

  var handleMouseDown = function handleMouseDown(e) {
    if (rippleRef.current) {
      rippleRef.current.trigger(e);
    }
  };

  var handleLoadingColor = function handleLoadingColor() {
    var color = '';

    switch (true) {
      case primary || filled || transaction && !ghost:
        color = NN0;
        break;

      case inverted:
        color = NN0L;
        break;

      case ghost || text || ghost || transaction:
        color = GN500;
        break;

      default:
        color = 'rgba(0, 0, 0, 0.38)';
    }

    return color;
  };

  var handleRippleColor = function handleRippleColor() {
    var color = '';

    switch (true) {
      case disabled:
        color = 'none';
        break;

      case filled:
        color = GN700;
        break;

      default:
        color = NN100;
    }

    return color;
  };

  var renderChildren = function renderChildren() {
    return Children.map(children, function (child) {
      if (typeof child === 'string' || typeof child === 'number') {
        return React.createElement("span", {
          className: ChildrenWrapper
        }, child);
      }

      return child;
    });
  };

  var renderButton = function renderButton() {
    var buttonProps = {
      block: block,
      small: small,
      micro: micro,
      large: large,
      floating: floating,
      alternate: alternate,
      filled: filled,
      ghost: ghost,
      inverted: inverted,
      main: main,
      padding: padding,
      primary: primary,
      secondary: secondary,
      secondaryGreen: secondaryGreen,
      secondaryTransaction: secondaryTransaction,
      text: text,
      transaction: transaction
    };
    return React.createElement(Container, _extends({
      "data-unify": "Button",
      className: buttonClasses(),
      disabled: disabled || loading,
      image: image,
      imagePosition: imagePosition,
      loading: loading,
      type: type,
      onClick: handleClick,
      onMouseDown: handleMouseDown
    }, buttonProps, otherProps), React.createElement(Ripple, {
      ref: rippleRef,
      color: handleRippleColor()
    }), !loading && image && React.createElement("img", {
      alt: typeof children === 'string' ? children.toString() : '',
      src: image,
      crossOrigin: "anonymous"
    }), React.createElement("div", {
      className: ChildrenContainer({
        block: block,
        image: image,
        imagePosition: imagePosition,
        loading: loading
      })
    }, renderChildren()), React.createElement(LoadingCircle, {
      display: loading,
      color: handleLoadingColor()
    }));
  };

  return floating ? React.createElement(Floating, null, renderButton()) : renderButton();
};

export default Button;