import styled, { css } from 'react-emotion';
import { GN500, GN600, NN0, NN100, NN300, NN400, NN600 } from 'unify-token/colors';
import { fontSizeLv2, fontSizeLv3, fontSizeLv4, fontWeightExtraBold, lineHeightLv2, lineHeightLv3, lineHeightLv4 } from 'unify-token/build/v2/typographies';
import { durationDefault, easeDefault, durationT1, easeOut } from 'unify-token/build/v2/motions';
import { colorWhiteAlways, focusStyle } from "../../build/Providers/common/style";

var handleFontSize = function handleFontSize(_ref) {
  var large = _ref.large,
      small = _ref.small,
      micro = _ref.micro;

  switch (true) {
    case large:
      return fontSizeLv4;

    case small || micro:
      return fontSizeLv2;

    default:
      return fontSizeLv3;
  }
};

var handleLineHeight = function handleLineHeight(_ref2) {
  var large = _ref2.large,
      small = _ref2.small,
      micro = _ref2.micro;

  switch (true) {
    case large:
      return lineHeightLv4;

    case small || micro:
      return lineHeightLv2;

    default:
      return lineHeightLv3;
  }
};

var handleHeight = function handleHeight(_ref3) {
  var small = _ref3.small,
      micro = _ref3.micro,
      large = _ref3.large,
      floating = _ref3.floating;

  switch (true) {
    case large || floating && large:
      return '48px';

    case small:
      return '32px';

    case micro:
      return '24px';

    default:
      return '40px';
  }
};

var handleColor = function handleColor(_ref4) {
  var alternate = _ref4.alternate,
      disabled = _ref4.disabled,
      filled = _ref4.filled,
      ghost = _ref4.ghost,
      inverted = _ref4.inverted,
      loading = _ref4.loading,
      main = _ref4.main,
      primary = _ref4.primary,
      secondary = _ref4.secondary,
      secondaryGreen = _ref4.secondaryGreen,
      secondaryTransaction = _ref4.secondaryTransaction,
      transaction = _ref4.transaction;

  switch (true) {
    case disabled && !loading:
      return NN400;

    case ghost && alternate || secondary:
      return NN600;

    case ghost && inverted:
      return colorWhiteAlways;

    case secondaryGreen || ghost && main || secondaryTransaction || ghost && transaction:
      return GN500;

    case primary || filled || transaction:
      return colorWhiteAlways;

    default:
      return NN600;
  }
};

var handleBackground = function handleBackground(_ref5) {
  var disabled = _ref5.disabled,
      filled = _ref5.filled,
      ghost = _ref5.ghost,
      loading = _ref5.loading,
      main = _ref5.main,
      primary = _ref5.primary,
      transaction = _ref5.transaction,
      inverted = _ref5.inverted;

  switch (true) {
    case disabled && !ghost && !loading:
      return NN100;

    case ghost && inverted:
      return 'transparent';

    case primary || filled && main || transaction:
      return GN500;

    default:
      return NN0;
  }
};

var handleBorder = function handleBorder(_ref6) {
  var alternate = _ref6.alternate,
      disabled = _ref6.disabled,
      ghost = _ref6.ghost,
      inverted = _ref6.inverted,
      loading = _ref6.loading,
      main = _ref6.main,
      secondary = _ref6.secondary,
      secondaryGreen = _ref6.secondaryGreen,
      secondaryTransaction = _ref6.secondaryTransaction,
      transaction = _ref6.transaction;

  switch (true) {
    case disabled && !ghost && !loading:
      return 'none';

    case disabled && ghost && !loading:
      return "solid 1px ".concat(NN100);

    case ghost && inverted:
      return "1px solid ".concat(colorWhiteAlways);

    case secondary || ghost && alternate:
      return "1px solid ".concat(NN300);

    case secondaryGreen || ghost && main || secondaryTransaction || ghost && transaction:
      return "1px solid ".concat(GN500);

    default:
      return 'none';
  }
};

var handleBackgroundColorActive = function handleBackgroundColorActive(_ref7) {
  var disabled = _ref7.disabled,
      primary = _ref7.primary,
      transaction = _ref7.transaction,
      ghost = _ref7.ghost,
      filled = _ref7.filled;

  switch (true) {
    case disabled || ghost:
      return 'none';

    case filled || transaction || primary:
      return GN600;

    default:
      return 'none';
  }
};

var handleBorderActive = function handleBorderActive(_ref8) {
  var ghost = _ref8.ghost,
      alternate = _ref8.alternate,
      inverted = _ref8.inverted,
      disabled = _ref8.disabled;

  switch (true) {
    case alternate && !disabled:
      return "border: solid 1px ".concat(NN400, ";");

    case ghost && !inverted && !disabled:
      return "border: solid 1px ".concat(GN600, ";");
  }
};

var _ref9 = "label:unf-btn;width:";
var _ref10 = ";height:";
var _ref11 = ";color:";
var _ref12 = ";font-size:";
var _ref13 = ";font-weight:";
var _ref14 = ";line-height:";
var _ref15 = ";text-overflow:ellipsis;white-space:nowrap;outline:none;background-position:center;border-radius:8px;display:";
var _ref16 = ";justify-content:center;align-items:center;overflow:hidden;position:relative;padding:";
var _ref17 = ";transition:background ";
var _ref18 = ",border ";
var _ref19 = ",color ";
var _ref20 = ";";
var _ref21 = ";&::before{content:'.';max-width:0;width:0;opacity:0;visibility:hidden;}";

var BasicStyle = function BasicStyle(props) {
  return css(_ref9, props.block ? '100%' : 'auto', _ref10, handleHeight(props), _ref11, handleColor(props), _ref12, handleFontSize(props), _ref13, fontWeightExtraBold, _ref14, handleLineHeight(props), _ref15, props.block ? 'flex' : 'inline-flex', _ref16, props.padding ? props.padding : '0 16px', _ref17, durationDefault, _ref18, durationDefault, _ref19, durationDefault, _ref20, focusStyle, _ref21);
};

var _ref23 = "min-width:0;display:inline-flex;align-items:center;position:relative;bottom:";
var _ref24 = ";opacity:";
var _ref25 = ";margin-right:";
var _ref26 = ";margin-left:";
var _ref27 = ";transition:opacity ";
var _ref28 = " ";
var _ref29 = ",bottom ";
var _ref30 = " ";
var _ref31 = ";> svg,> img{flex-shrink:0;}> .unf-icon{margin-left:8px;margin-right:8px;&:first-child{margin-left:0;}&:last-child{margin-right:0;}}";
export var ChildrenContainer = function ChildrenContainer(_ref22) {
  var block = _ref22.block,
      image = _ref22.image,
      imagePosition = _ref22.imagePosition,
      loading = _ref22.loading;
  return css(_ref23, loading ? '10px' : 0, _ref24, loading ? 0 : 1, _ref25, !block && image && imagePosition === 'right' && '24px', _ref26, !block && image && imagePosition === 'left' && '24px', _ref27, durationDefault, _ref28, easeDefault, _ref29, durationDefault, _ref30, easeDefault, _ref31);
};
export var ChildrenWrapper = css("white-space:pre;&:last-of-type{overflow:hidden;text-overflow:ellipsis;flex-shrink:1;}");
var Container = styled('button', {
  target: "evxom8o0"
})(BasicStyle, ";background:", handleBackground, ";border:", handleBorder, ";font-family:inherit;transition:background ", durationT1, " ", easeOut, ";&:active{background-color:", handleBackgroundColorActive, ";", handleBorderActive, ";background-size:100%;transition:background 0ms,border 0ms,color 0ms;}> img{height:16px;right:", function (props) {
  return props.imagePosition === 'right' && '16px';
}, ";left:", function (props) {
  return props.imagePosition === 'left' && '16px';
}, ";position:absolute;top:50%;transform:translateY(-50%);}");
export var Text = styled('div', {
  target: "evxom8o1"
})(BasicStyle, ";> span{outline:none;}");
export default Container;