/// <reference types="react" />
declare type ButtonBaseProps = Omit<React.ComponentPropsWithoutRef<'button'>, 'css'>;
interface UnifyButtonProps {
    /**
     * To Apply alternate Button design on ghost variant
     */
    alternate?: boolean;
    /**
     * To make Button width flex to container width
     */
    block?: boolean;
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     * To apply disabled Button design
     */
    disabled?: boolean;
    /**
     * To apply filled Button design
     */
    filled?: boolean;
    /**
     * To apply floating Button design
     */
    floating?: boolean;
    /**
     * To apply ghost Button design
     */
    ghost?: boolean;
    /**
     * To provide image url
     */
    image?: string;
    /**
     * Set image position on right or left.
     */
    imagePosition?: string;
    /**
     * To apply inverted Button design
     */
    inverted?: boolean;
    /**
     * To apply large Button size design
     */
    large?: boolean;
    /**
     * To determine loading state of Button
     */
    loading?: boolean;
    /**
     * To apply main Button design
     */
    main?: boolean;
    /**
     * To apply micro Button size design
     */
    micro?: boolean;
    /**
     * To specify custom padding on Button
     */
    padding?: string;
    /**
     * To apply primary Button design ( DEPRECATED SOON )
     */
    primary?: boolean;
    /**
     * To apply secondary Button design ( DEPRECATED SOON )
     */
    secondary?: boolean;
    /**
     * To apply secondaryGreen Button design ( DEPRECATED SOON )
     */
    secondaryGreen?: boolean;
    /**
     * To apply secondaryTransaction Button design ( DEPRECATED SOON )
     */
    secondaryTransaction?: boolean;
    /**
     * To apply small Button size design
     */
    small?: boolean;
    /**
     * To specify tabIndex attribute on Button
     */
    tabIndex?: number;
    /**
     * To apply text Button design
     */
    text?: boolean;
    /**
     * To apply transaction Button design
     */
    transaction?: boolean;
    /**
     * To apply Buttons type
     */
    type?: 'button' | 'submit' | 'reset';
    /**
     * To pass callback when clicked | params: `e`: event
     */
    onClick?: (e: React.MouseEvent<HTMLButtonElement>) => void;
}
export declare type ButtonProps = UnifyButtonProps & Omit<ButtonBaseProps, keyof UnifyButtonProps>;
export {};
