import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _typeof from "@babel/runtime/helpers/typeof";
import { useEffect, useState } from 'react';
var canUseDOM = (typeof document === "undefined" ? "undefined" : _typeof(document)) === 'object';
export var hasDarkColorLoaded = function hasDarkColorLoaded() {
  if (canUseDOM) {
    var rootStyle = getComputedStyle(document.documentElement);
    return rootStyle.getPropertyValue('--NN0') !== '';
  }

  return false;
};
export var mediaQuery = function mediaQuery(query) {
  var hasMatchMedia = canUseDOM && 'matchMedia' in window;

  if (hasMatchMedia) {
    var mediaQueryList = matchMedia(query);
    return {
      matches: mediaQueryList.matches,
      addEventListener: function addEventListener(eventName, callback) {
        try {
          mediaQueryList.addEventListener(eventName, callback);
        } catch (err) {
          try {
            mediaQueryList.addListener(callback);
          } catch (err) {
            console.error(err);
          }
        }
      },
      removeEventListener: function removeEventListener(eventName, callback) {
        try {
          mediaQueryList.removeEventListener(eventName, callback);
        } catch (err) {
          try {
            mediaQueryList.removeListener(callback);
          } catch (err) {
            console.error(err);
          }
        }
      }
    };
  }

  return {
    matches: false,
    addEventListener: function addEventListener() {},
    removeEventListener: function removeEventListener() {}
  };
};
export var useDarkMode = function useDarkMode() {
  var _useState = useState(hasDarkColorLoaded()),
      _useState2 = _slicedToArray(_useState, 2),
      isDarkMode = _useState2[0],
      setDarkMode = _useState2[1];

  useEffect(function () {
    var colorSchemeQuery = '(prefers-color-scheme: dark)';

    function handleChange() {
      var isNativeDark = this.matches;
      var hasDarkColor = hasDarkColorLoaded();
      setDarkMode(isNativeDark && hasDarkColor);
    }

    mediaQuery(colorSchemeQuery).addEventListener('change', handleChange);
    return function () {
      mediaQuery(colorSchemeQuery).removeEventListener('change', handleChange);
    };
  }, []);
  return isDarkMode;
};