import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["actionText", "active", "children", "className", "container", "disabled", "hasActiveIcon", "hasBorder", "id", "margin", "padding", "subheader", "touchAnimation", "onActionClick", "onClick", "onTouchEnd", "onTouchMove", "onTouchStart"];
import React, { useRef, useState } from 'react';
import { NN200, GN500, NN700 } from 'unify-token/colors';
import { spacingLv4 } from 'unify-token/build/v2/spacings';
import CheckBig from 'unify-icons/system/CheckBig';
import { easeInOut } from 'unify-token/build/v2/motions';
import Ripple from "../../build/Providers/common/components/Ripple";
import { useDarkMode } from "./_utils";
import { Action, CheckIconContainer, Container, Header, SubHeader } from "./style";

var Card = function Card(_ref) {
  var actionText = _ref.actionText,
      _ref$active = _ref.active,
      active = _ref$active === void 0 ? false : _ref$active,
      children = _ref.children,
      className = _ref.className,
      _ref$container = _ref.container,
      container = _ref$container === void 0 ? false : _ref$container,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$hasActiveIcon = _ref.hasActiveIcon,
      hasActiveIcon = _ref$hasActiveIcon === void 0 ? false : _ref$hasActiveIcon,
      _ref$hasBorder = _ref.hasBorder,
      hasBorder = _ref$hasBorder === void 0 ? false : _ref$hasBorder,
      id = _ref.id,
      margin = _ref.margin,
      _ref$padding = _ref.padding,
      padding = _ref$padding === void 0 ? spacingLv4 : _ref$padding,
      subheader = _ref.subheader,
      _ref$touchAnimation = _ref.touchAnimation,
      touchAnimation = _ref$touchAnimation === void 0 ? 'none' : _ref$touchAnimation,
      onActionClick = _ref.onActionClick,
      onClick = _ref.onClick,
      onTouchEnd = _ref.onTouchEnd,
      onTouchMove = _ref.onTouchMove,
      onTouchStart = _ref.onTouchStart,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      touch = _useState2[0],
      setTouch = _useState2[1];

  var containerRef = useRef(null);
  var isDarkMode = useDarkMode();
  var touchable = touchAnimation !== 'none' && !container && !disabled;
  var handleRipple = useRef(null);

  var handleClick = function handleClick(e) {
    if (!disabled) {
      onClick && onClick(e);
    }
  };

  var handleTouchStart = function handleTouchStart(e) {
    if (touchable) {
      var target = e.target;

      var isParentClickable = function isParentClickable(node) {
        var clickableList = ['a', 'button'];
        var isClickable = false;

        for (var i = 0; i < clickableList.length; i++) {
          if (node.closest(clickableList[i])) {
            isClickable = true;
            break;
          }
        }

        return isClickable;
      };

      var targetHasEvent = function targetHasEvent(element) {
        var eventList = ['onClick', 'onMouseDown', 'onTouchStart'];
        var eventKey = Object.keys(element).find(function (item) {
          return item.indexOf('__reactEventHandlers') >= 0;
        });
        return eventList.some(function (key) {
          return eventKey && element[eventKey].hasOwnProperty(key);
        });
      };

      var parentHasEvent = function parentHasEvent(node) {
        var eventList = ['onClick', 'onMouseDown', 'onTouchStart'];
        var nodeParentEvent = false;
        var nodeParent = node.parentNode;

        var _loop = function _loop(i) {
          var reactEvents = Object.keys(nodeParent).find(function (item) {
            return item.indexOf('__reactEventHandlers') >= 0;
          });

          if (reactEvents) {
            var parentEvents = eventList.some(function (key) {
              return nodeParent && nodeParent[reactEvents].hasOwnProperty(key);
            });

            if (nodeParent === containerRef.current) {
              nodeParentEvent = false;
              return "break";
            }

            if (parentEvents) {
              nodeParentEvent = parentEvents;
              return "break";
            }

            nodeParent = nodeParent ? nodeParent.parentNode : null;
          }
        };

        for (var i = 0;; i++) {
          var _ret = _loop(i);

          if (_ret === "break") break;
        }

        return nodeParentEvent;
      };

      if (target === containerRef.current) {
        setTouch(1);
      } else {
        var tagNames = ['A', 'BUTTON', 'INPUT', 'TEXTAREA', 'SELECT'];

        if (tagNames.includes(target.tagName) || target.getAttribute('href') || target.getAttribute('role') === 'button') {
          return false;
        }

        if (targetHasEvent(target) || isParentClickable(target) || parentHasEvent(target)) {
          return false;
        }

        setTouch(1);
      }

      var rippleElement = handleRipple.current;

      if (['overlay', 'bounce-overlay'].includes(touchAnimation) && rippleElement) {
        rippleElement.triggerTouch(e);
      }

      onTouchStart && onTouchStart(e);
    }

    return null;
  };

  var handleTouchEnd = function handleTouchEnd(e) {
    if (touchable) {
      touch === 1 && setTouch(2);
    }

    onTouchEnd && onTouchEnd(e);
  };

  var handleTouchMove = function handleTouchMove(e) {
    if (touchable) {
      touch === 1 && setTouch(2);
    }

    onTouchMove && onTouchMove(e);
  };

  return React.createElement(Container, _extends({
    innerRef: containerRef,
    active: active,
    className: "unf-card".concat(container ? ' unf-card--container' : '').concat(className ? " ".concat(className) : ''),
    container: container,
    disabled: disabled,
    hasBorder: hasBorder,
    hasIcon: active && hasActiveIcon && !disabled,
    id: id,
    isTouch: touch,
    margin: margin,
    padding: padding,
    touchAnimation: touchAnimation,
    onClick: handleClick,
    onTouchEnd: handleTouchEnd,
    onTouchMove: handleTouchMove,
    onTouchStart: handleTouchStart,
    isDarkMode: isDarkMode,
    "data-unify": "Card"
  }, otherProps), (subheader || actionText && container) && React.createElement(Header, {
    className: "unf-card__header",
    subheader: subheader
  }, subheader && React.createElement(SubHeader, {
    className: "unf-card__subheader"
  }, subheader), actionText && container && React.createElement(Action, {
    className: "unf-card__action",
    onClick: onActionClick
  }, actionText)), children, hasActiveIcon && React.createElement(CheckIconContainer, {
    active: active
  }, React.createElement("div", null, !disabled && React.createElement(CheckBig, {
    color: disabled ? NN200 : GN500
  }))), ['overlay', 'bounce-overlay'].includes(touchAnimation) && React.createElement(Ripple, {
    ref: handleRipple,
    color: NN700,
    opacity: "0.2",
    duration: 300,
    easing: easeInOut
  }));
};

export default Card;