import styled, { keyframes } from 'react-emotion';
import { NN200, NN900, GN50, GN500, NN0, NN50 } from 'unify-token/colors';
import { fontSizeLv2, fontSizeLv4, fontWeightBold, lineHeightLv2 } from 'unify-token/build/v2/typographies';
import { durationT2, easeOut } from 'unify-token/build/v2/motions';

var handleBorderColor = function handleBorderColor(_ref) {
  var active = _ref.active,
      disabled = _ref.disabled,
      hasBorder = _ref.hasBorder;

  if (hasBorder) {
    switch (true) {
      case disabled:
        return NN200;

      case active:
        return GN500;

      default:
        return NN200;
    }
  }
};

var handleBoxShadow = function handleBoxShadow(_ref2) {
  var active = _ref2.active,
      hasBorder = _ref2.hasBorder,
      disabled = _ref2.disabled;

  if (!hasBorder) {
    return active && !disabled ? "0 0 0 1px ".concat(GN500) : "0 1px 4px 0 ".concat(NN200);
  }

  return null;
};

var handleBackgroundColor = function handleBackgroundColor(_ref3) {
  var active = _ref3.active,
      disabled = _ref3.disabled;

  switch (true) {
    case disabled:
      return NN50;

    case active:
      return GN50;

    default:
      return NN0;
  }
};

var handleAnimation = function handleAnimation(isTouch, A1, A2) {
  return "\nanimation-name: ".concat(isTouch === 1 ? A1 : isTouch === 2 && A2, ";\nanimation-timing-function: ").concat(easeOut, ";\nanimation-duration: ").concat(durationT2, ";\nanimation-fill-mode: forwards;\n");
};

var handleMarginContainer = function handleMarginContainer(margin, container) {
  if (margin) {
    return margin;
  } else if (container) {
    return '16px 0';
  } else {
    return '16px';
  }
};

var bounceOne = keyframes("from{transform:scale(1);}to{transform:scale(0.95);}");
var bounceTwo = keyframes("from{transform:scale(0.95);}to{transform:scale(1.0);}");
var COLOR_SHADOW_LIGHT = '0 1px 4px 0 rgba(141, 150, 170, 0.4)';
var COLOR_SHADOW_DARK = 'transparent';
export var Container = styled("section", {
  target: "e17n0lhz0"
})("--color-shadow:", function (_ref4) {
  var isDarkMode = _ref4.isDarkMode;
  return isDarkMode ? COLOR_SHADOW_DARK : COLOR_SHADOW_LIGHT;
}, ";display:block;position:relative;overflow:hidden;background-color:", handleBackgroundColor, ";border:", function (_ref5) {
  var hasBorder = _ref5.hasBorder;
  return hasBorder && '1px solid';
}, ";border-color:", handleBorderColor, ";border-radius:", function (_ref6) {
  var container = _ref6.container;
  return container ? 'initial' : '8px';
}, ";box-shadow:", handleBoxShadow, ";padding:", function (_ref7) {
  var padding = _ref7.padding;
  return padding ? padding : '16px';
}, ";margin:", function (_ref8) {
  var container = _ref8.container,
      margin = _ref8.margin;
  return handleMarginContainer(margin, container);
}, ";transition-property:background-color,border-color,box-shadow;transition-duration:", durationT2, ";transition-timing-function:", easeOut, ";", function (_ref9) {
  var isTouch = _ref9.isTouch,
      touchAnimation = _ref9.touchAnimation;
  return (touchAnimation === 'bounce-overlay' || touchAnimation === 'bounce') && handleAnimation(isTouch, bounceOne, bounceTwo);
}, ";");
export var Header = styled("div", {
  target: "e17n0lhz1"
})("min-width:0;display:flex;justify-content:", function (_ref10) {
  var subheader = _ref10.subheader;
  return !subheader && 'flex-end';
}, ";margin-bottom:16px;");
export var SubHeader = styled("div", {
  target: "e17n0lhz2"
})("color:", NN900, ";font-size:", fontSizeLv4, ";font-weight:", fontWeightBold, ";line-height:", lineHeightLv2, ";white-space:nowrap;text-overflow:ellipsis;overflow:hidden;flex:1;padding-right:8px;");
export var CheckIconContainer = styled("div", {
  target: "e17n0lhz3"
})("height:24px;position:absolute;top:0;right:12px;bottom:0;margin:auto;> div{width:", function (_ref11) {
  var active = _ref11.active;
  return active ? '100%' : '0%';
}, ";overflow:hidden;transition:width ", durationT2, " ", easeOut, ";}");
export var Action = styled("span", {
  target: "e17n0lhz4"
})("color:", GN500, ";font-size:", fontSizeLv2, ";font-weight:600;display:flex;align-items:center;justify-content:center;");