/// <reference types="react" />
declare type CardBaseProps = React.ComponentPropsWithoutRef<'section'>;
export interface UnifyCardProps {
    /**
     * Deprecated - Set the action button text **(only applicable in container mode)**
     */
    actionText?: string;
    /**
     * Set the Card into active state
     */
    active?: boolean;
    /**
     * Set the Card classes
     */
    className?: string;
    /**
     * Set the Card into container mode, remove the default left and right margin, and border radius
     */
    container?: boolean;
    /**
     * Set the Card into disabled state
     */
    disabled?: boolean;
    /**
     * Show active state icon
     */
    hasActiveIcon?: boolean;
    /**
     * Set the Card into using border rather than box-shadow
     */
    hasBorder?: boolean;
    /**
     * Set the Card id
     */
    id?: string;
    /**
     * Set the Card margin
     */
    margin?: string;
    /**
     * Set the Card padding
     */
    padding?: string;
    /**
     * Deprecated - Set the Title of the Card
     */
    subheader?: string;
    /**
     * Set the Card interaction animation when tapped. Available values are `bounce`, `bounce-overlay`, and `overlay`
     */
    touchAnimation?: 'none' | 'bounce' | 'bounce-overlay' | 'overlay';
    /**
     * Deprecated - To pass callback function on right action text
     */
    onActionClick?: (e: React.MouseEvent<HTMLSpanElement>) => void;
    /**
     * Set Card event listener on click
     */
    onClick?: (e: React.MouseEvent<HTMLDivElement>) => void;
    /**
     * Set Card event listener on touch end
     */
    onTouchEnd?: (e: React.TouchEvent<HTMLDivElement>) => void;
    /**
     * Set Card event listener on touch move
     */
    onTouchMove?: (e: React.TouchEvent<HTMLDivElement>) => void;
    /**
     * Set Card event listener on touch start
     */
    onTouchStart?: (e: React.TouchEvent<HTMLDivElement>) => void;
}
export declare type CardProps = UnifyCardProps & Omit<CardBaseProps, keyof UnifyCardProps | 'css'>;
export {};
