import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
var _excluded = ["className", "children", "indicator", "link", "linkText"];
import React, { useEffect, useState, useRef, useCallback } from 'react';
import { durationT3, easeInOut } from 'unify-token/build/v2/motions';
import PageControl from "../../build/PageControl";
import { UnifyCarousel, UnifyCarouselItem, UnifyCarouselTrack, UnifyCarouselLink, UnifyCarouselDiv, UnifyCarouselFooter } from "./style";

var Carousel = function Carousel(props) {
  var autoPlay = props.autoPlay,
      children = props.children,
      className = props.className,
      dataTest = props.dataTest,
      indicator = props.indicator,
      infinite = props.infinite,
      inverted = props.inverted,
      link = props.link,
      linkText = props.linkText,
      padding = props.padding,
      useContainerWidth = props.useContainerWidth,
      width = props.width,
      onChange = props.onChange;
  var firstUpdate = useRef(true);
  var autoPlayInterval = useRef(null);
  var maxWidth = useRef('100vw');
  var xPosition = useRef(0);
  var xPositionTemporary = useRef(0);
  var xDown = useRef(0);
  var trackerRef = useRef(null);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      activeIndex = _useState2[0],
      setActiveIndex = _useState2[1];

  var _useState3 = useState(maxWidth),
      _useState4 = _slicedToArray(_useState3, 2),
      itemWidth = _useState4[0],
      setItemWidth = _useState4[1];

  var containerEl = useRef(null);

  var getOtherProps = function getOtherProps() {
    var className = props.className,
        children = props.children,
        indicator = props.indicator,
        link = props.link,
        linkText = props.linkText,
        otherProps = _objectWithoutProperties(props, _excluded);

    return otherProps;
  };

  var itemWidthRef = function itemWidthRef(element) {
    if (element && useContainerWidth) {
      containerEl.current = element;
      setItemWidth(element.getBoundingClientRect().width);
    }
  };

  var setAutoPlayInterval = useCallback(function () {
    if (autoPlay && Array.isArray(children)) {
      autoPlayInterval.current && clearInterval(autoPlayInterval.current);
      autoPlayInterval.current = setInterval(function () {
        setActiveIndex(function (prevIndex) {
          if (prevIndex === children.length - 1) {
            return 0;
          }

          return prevIndex + 1;
        });
      }, 3500);
    }
  }, [autoPlay, children]);
  var moveItem = useCallback(function () {
    xPosition.current = itemWidth * activeIndex * -1;
    xPositionTemporary.current = xPosition.current;
    trackerRef.current.style.transform = "translateX(".concat(xPosition.current, "px)");

    if (!firstUpdate.current) {
      onChange(activeIndex);
    } else {
      firstUpdate.current = false;
    }
  }, [activeIndex, itemWidth, onChange]);
  useEffect(function () {
    var updateWindowDimensions = function updateWindowDimensions() {
      var newWidth = width ? width : window.innerWidth > maxWidth.current ? maxWidth.current : window.innerWidth;

      if (useContainerWidth) {
        newWidth = containerEl.current.getBoundingClientRect().width;
      }

      requestAnimationFrame(function () {
        setItemWidth(newWidth);
      });
    };

    window.addEventListener('resize', updateWindowDimensions);
    updateWindowDimensions();
    setAutoPlayInterval();
    return function () {
      window.removeEventListener('resize', updateWindowDimensions);
      autoPlayInterval.current && clearInterval(autoPlayInterval.current);
    };
  }, [autoPlay, setAutoPlayInterval, useContainerWidth, width]);
  useEffect(function () {
    trackerRef.current.style.transition = "transform ".concat(durationT3, " ").concat(easeInOut);
  }, [children]);
  useEffect(function () {
    moveItem();
  }, [activeIndex, moveItem]);

  var handleTouchStart = function handleTouchStart(event) {
    xDown.current = event.touches[0].clientX;
    autoPlayInterval.current && clearInterval(autoPlayInterval.current);
  };

  var handleTouchEnd = function handleTouchEnd() {
    trackerRef.current.style.transitionDuration = '240ms';

    if (xPositionTemporary.current > 0) {
      if (infinite) {
        setActiveIndex(children.length - 1);
        setAutoPlayInterval();
      } else {
        setActiveIndex(0);
        setAutoPlayInterval();
      }
    } else if (xPositionTemporary.current * -1 > itemWidth * (children.length - 1)) {
      if (infinite) {
        setActiveIndex(0);
        setAutoPlayInterval();
      } else {
        setActiveIndex(children.length - 1);
        setAutoPlayInterval();
      }
    } else if (xPositionTemporary.current * -1 > itemWidth * activeIndex + 1 + itemWidth / 4) {
      setActiveIndex(function (prevIndex) {
        return prevIndex + 1;
      });
      setAutoPlayInterval();
    } else if (xPositionTemporary.current * -1 < itemWidth * activeIndex - itemWidth / 4) {
      setActiveIndex(function (prevIndex) {
        return prevIndex - 1;
      });
      setAutoPlayInterval();
    } else {
      moveItem();
    }
  };

  var handleTouchMove = function handleTouchMove(event) {
    if (!xDown.current) {
      return;
    }

    var xUp = event.touches[0].clientX;
    var xDiff = xDown.current - xUp;
    var touchToleranceDivider = children.length > 1 && infinite ? 4 : 48;

    if (!(xPosition.current - xDiff > itemWidth / touchToleranceDivider) && (xPosition.current - xDiff) * -1 < itemWidth * (children.length - 1) + itemWidth / touchToleranceDivider) {
      trackerRef.current.style.transform = "translateX(".concat(xPosition.current - xDiff, "px)");
      trackerRef.current.style.transitionDuration = "0";
      xPositionTemporary.current = xPosition.current - xDiff;
    }
  };

  var renderIndicators = function renderIndicators() {
    return React.createElement("div", {
      className: "unf-carousel__indicators",
      "data-testid": dataTest.indicatorsWrapper
    }, React.createElement(PageControl, {
      numberOfPage: children.length,
      currentPage: activeIndex,
      inverted: inverted,
      dataTest: dataTest.indicatorsDot,
      onIndicatorClick: setActiveIndex
    }));
  };

  var renderItems = function renderItems() {
    return Array.isArray(children) ? children.map(function (child, i) {
      return React.createElement(UnifyCarouselItem, {
        key: i,
        padding: padding,
        "data-testid": dataTest.image + i
      }, child);
    }) : React.createElement(UnifyCarouselItem, {
      padding: padding,
      "data-testid": dataTest.image
    }, children);
  };

  var renderLink = function renderLink() {
    return typeof link === 'string' ? React.createElement(UnifyCarouselLink, {
      inverted: inverted,
      href: link,
      "data-testid": dataTest.link
    }, linkText) : React.createElement(UnifyCarouselDiv, {
      inverted: inverted,
      onClick: link,
      "data-testid": dataTest.link
    }, linkText);
  };

  return React.createElement(UnifyCarousel, _extends({
    "data-testid": dataTest.wrapper,
    "data-unf-test": activeIndex,
    className: className
  }, getOtherProps(), {
    innerRef: itemWidthRef,
    "data-unify": "Carousel"
  }), React.createElement(UnifyCarouselTrack, {
    "aria-label": "carousel-track",
    innerRef: trackerRef,
    length: Array.isArray(children) ? children.length : 1,
    onTouchStart: handleTouchStart,
    onTouchMove: handleTouchMove,
    onTouchEnd: handleTouchEnd
  }, renderItems()), React.createElement(UnifyCarouselFooter, {
    className: "unf-carousel__footer",
    padding: padding
  }, indicator && renderIndicators(), linkText && renderLink()));
};

Carousel.defaultProps = {
  autoPlay: false,
  children: null,
  className: '',
  dataTest: {},
  indicator: true,
  infinite: false,
  inverted: false,
  link: '',
  linkText: '',
  padding: '16px',
  useContainerWidth: false,
  width: 0,
  onChange: function onChange() {}
};
export default Carousel;