import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["activeIndex", "adaptiveHeight", "autoPlay", "autoPlaySpeed", "breakPoint", "centerMode", "children", "dataTest", "freeScrolling", "height", "indicatorAlign", "itemAlign", "loop", "showIndicator", "slideToScroll", "slideToShow", "sneakPeekWidth", "useContentWidth", "onSlideChange", "onSwipe"];
import React, { useEffect, useLayoutEffect, useState, useRef, useCallback, Children } from 'react';
import { durationT3, easeInOut } from 'unify-token/build/v2/motions';
import PageControl from "../../build/PageControl";
import { useKeyboardControl } from "../../build/Providers/common/hooks";
import { noop } from "../../build/Providers/common/functions/noop";
import { canUseDOM } from "../../build/Providers/common/functions";
import { CarouselContainer, CarouselContentContainer, CarouselItem } from "./style";
var swipeSensitivity = 1.8;

var CarouselV2 = function CarouselV2(_ref) {
  var _ref$activeIndex = _ref.activeIndex,
      activeIndex = _ref$activeIndex === void 0 ? 0 : _ref$activeIndex,
      _ref$adaptiveHeight = _ref.adaptiveHeight,
      adaptiveHeight = _ref$adaptiveHeight === void 0 ? false : _ref$adaptiveHeight,
      _ref$autoPlay = _ref.autoPlay,
      autoPlay = _ref$autoPlay === void 0 ? false : _ref$autoPlay,
      _ref$autoPlaySpeed = _ref.autoPlaySpeed,
      autoPlaySpeed = _ref$autoPlaySpeed === void 0 ? 2000 : _ref$autoPlaySpeed,
      _ref$breakPoint = _ref.breakPoint,
      breakPoint = _ref$breakPoint === void 0 ? 50 : _ref$breakPoint,
      _ref$centerMode = _ref.centerMode,
      centerMode = _ref$centerMode === void 0 ? false : _ref$centerMode,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? [] : _ref$children,
      _ref$dataTest = _ref.dataTest,
      dataTest = _ref$dataTest === void 0 ? {} : _ref$dataTest,
      _ref$freeScrolling = _ref.freeScrolling,
      freeScrolling = _ref$freeScrolling === void 0 ? false : _ref$freeScrolling,
      height = _ref.height,
      _ref$indicatorAlign = _ref.indicatorAlign,
      indicatorAlign = _ref$indicatorAlign === void 0 ? 'left' : _ref$indicatorAlign,
      _ref$itemAlign = _ref.itemAlign,
      itemAlign = _ref$itemAlign === void 0 ? 'top' : _ref$itemAlign,
      _ref$loop = _ref.loop,
      loop = _ref$loop === void 0 ? 'infinite' : _ref$loop,
      _ref$showIndicator = _ref.showIndicator,
      showIndicator = _ref$showIndicator === void 0 ? false : _ref$showIndicator,
      _ref$slideToScroll = _ref.slideToScroll,
      slideToScroll = _ref$slideToScroll === void 0 ? 1 : _ref$slideToScroll,
      _ref$slideToShow = _ref.slideToShow,
      slideToShow = _ref$slideToShow === void 0 ? 1 : _ref$slideToShow,
      _ref$sneakPeekWidth = _ref.sneakPeekWidth,
      sneakPeekWidth = _ref$sneakPeekWidth === void 0 ? '10px' : _ref$sneakPeekWidth,
      _ref$useContentWidth = _ref.useContentWidth,
      useContentWidth = _ref$useContentWidth === void 0 ? false : _ref$useContentWidth,
      _ref$onSlideChange = _ref.onSlideChange,
      onSlideChange = _ref$onSlideChange === void 0 ? noop : _ref$onSlideChange,
      _ref$onSwipe = _ref.onSwipe,
      onSwipe = _ref$onSwipe === void 0 ? noop : _ref$onSwipe,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var endCarousel;
  var itemCount = Children.toArray(children).length;
  var normalizeItemLocation = useCallback(function (childN) {
    if (childN < 0) {
      childN = (childN % itemCount + itemCount) % itemCount;
    } else if (childN >= itemCount) {
      childN %= itemCount;
    }

    return childN;
  }, [itemCount]);
  var normalizeIndex = useCallback(function (index) {
    var indexLength = Math.ceil(itemCount / slideToScroll);

    if (index < 0) {
      index = (index % indexLength + indexLength) % indexLength;
    } else if (index >= indexLength) {
      index %= indexLength;
    }

    return index;
  }, [itemCount, slideToScroll]);

  var _useState = useState(activeIndex ? normalizeIndex(activeIndex) : 0),
      _useState2 = _slicedToArray(_useState, 2),
      _activeIndex = _useState2[0],
      setActiveIndex = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      xTranslate = _useState4[0],
      setXTranslate = _useState4[1];

  var getInitialPaddingCenter = function getInitialPaddingCenter() {
    if (centerMode) {
      if (!useContentWidth) {
        var sneakpk = sneakPeekWidth;

        if (Number.isInteger(sneakPeekWidth) || !isNaN(parseInt(sneakPeekWidth.slice(-1)))) {
          sneakpk += '%';
        }

        return sneakpk;
      }

      return 0;
    } else {
      return 0;
    }
  };

  var _useState5 = useState(getInitialPaddingCenter()),
      _useState6 = _slicedToArray(_useState5, 2),
      paddingCenter = _useState6[0],
      setPaddingCenter = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      isFocused = _useState8[0],
      setIsFocused = _useState8[1];

  var _useState9 = useState(height),
      _useState10 = _slicedToArray(_useState9, 2),
      adaptiveHeightAmount = _useState10[0],
      setAdaptiveHeightAmount = _useState10[1];

  var containerRef = useRef(null);
  var posHelperRef = useRef(null);
  var activeItemRef = useRef(null);
  var heightDataRef = useRef([]);
  var widthDataRef = useRef([]);
  var x1Ref = useRef(0);
  var x2Ref = useRef(0);
  var maxXTranslateRef = useRef(0);
  var minXTranslateRef = useRef(0);
  var prevOffsetRef = useRef(0);
  var lastIndexRef = useRef(_activeIndex);
  var xCorrectionRef = useRef(0);
  var totalWidthsRef = useRef(0);
  var autoplayTimeoutRef = useRef();
  var animationTimeoutRef = useRef();
  var isAnimatingRef = useRef(false);
  var isDraggingRef = useRef(false);
  var LIST_SIZE_CONSTANT = 4 * slideToScroll < itemCount ? itemCount : 4 * slideToScroll;
  var imageLoadingDataRef = useRef([]);
  var unloadedImageCtRef = useRef(0);
  var firstUpdateRef = useRef(true);
  var infinite = loop === 'infinite';

  var convertPxToPercent = function convertPxToPercent(x) {
    var val = typeof x === 'string' ? parseInt(x) : x;

    if (containerRef.current) {
      return "".concat(val / containerRef.current.offsetWidth * 100);
    } else {
      return '0';
    }
  };

  var getMaxHeight = useCallback(function (startingItemLoc, diff) {
    var maxHeight = 0;
    var i = 0;

    while (i < Math.abs(diff)) {
      var newHeight = void 0;

      if (diff > 0) {
        newHeight = heightDataRef.current[normalizeItemLocation(startingItemLoc + i)];
      } else {
        newHeight = heightDataRef.current[normalizeItemLocation(startingItemLoc - i)];
      }

      maxHeight = maxHeight > newHeight ? maxHeight : newHeight;
      ++i;
    }

    return maxHeight;
  }, [normalizeItemLocation]);
  var getTotalWidths = useCallback(function (startingItemLoc, diff) {
    var total = 0;
    var i = 0;

    while (i < Math.abs(diff)) {
      if (diff > 0) {
        total += widthDataRef.current[normalizeItemLocation(startingItemLoc + i)];
      } else {
        total += widthDataRef.current[normalizeItemLocation(startingItemLoc - i)];
      }

      ++i;
    }

    if (diff > 0) {
      return total;
    } else {
      return -total;
    }
  }, [normalizeItemLocation]);
  var getTotalWidthsByIndexCM = useCallback(function (startingItemLoc, diff) {
    var temp = 0;

    if (diff > 0) {
      temp += getTotalWidths(startingItemLoc, 1) / 2 + getTotalWidths(startingItemLoc + diff * slideToScroll, 1) / 2;
      temp += getTotalWidths(startingItemLoc + 1, diff * slideToScroll - 1);
      return temp;
    } else if (diff < 0) {
      temp += getTotalWidths(startingItemLoc, -1) / 2 + getTotalWidths(startingItemLoc + diff * slideToScroll, -1) / 2;
      temp += getTotalWidths(startingItemLoc - 1, diff * slideToScroll + 1);
      return temp;
    }

    return 0;
  }, [getTotalWidths, slideToScroll]);
  var getIndexOffsetFromXTranslate = useCallback(function (x) {
    var i = 0;
    var xTemp;
    var newOffset;
    xCorrectionRef.current = 0;
    var variableStartLoc = infinite ? LIST_SIZE_CONSTANT : lastIndexRef.current * slideToScroll;

    if (centerMode) {
      if (x < 0) {
        xTemp = Math.abs(x) - getTotalWidthsByIndexCM(variableStartLoc, 1) * breakPoint / 100;

        while (xTemp >= 0) {
          xTemp -= getTotalWidthsByIndexCM(variableStartLoc + i, 1) * (100 - breakPoint) / 100;
          i += slideToScroll;
          xTemp -= getTotalWidthsByIndexCM(variableStartLoc + i, 1) * breakPoint / 100;
          xCorrectionRef.current += -getTotalWidthsByIndexCM(variableStartLoc + i - slideToScroll, 1);

          if (isDraggingRef.current && loop === 'jump' && lastIndexRef.current + Math.floor(i / slideToScroll) >= Math.ceil(itemCount / slideToScroll)) {
            break;
          }
        }
      } else {
        xTemp = Math.abs(x) + getTotalWidthsByIndexCM(variableStartLoc, -1) * breakPoint / 100;

        while (xTemp >= 0) {
          xTemp += getTotalWidthsByIndexCM(variableStartLoc + i, -1) * (100 - breakPoint) / 100;
          i -= slideToScroll;
          xTemp += getTotalWidthsByIndexCM(variableStartLoc + i, -1) * breakPoint / 100;
          xCorrectionRef.current += -getTotalWidthsByIndexCM(variableStartLoc + i + slideToScroll, -1);

          if (isDraggingRef.current && loop === 'jump' && lastIndexRef.current + Math.floor(i / slideToScroll) < 0) {
            break;
          }
        }
      }

      newOffset = Math.floor(i / slideToScroll);
    } else {
      if (x < 0) {
        xTemp = Math.abs(x) - getTotalWidths(variableStartLoc, slideToScroll) * breakPoint / 100;

        while (xTemp >= 0) {
          xTemp -= getTotalWidths(variableStartLoc + i, slideToScroll) * (100 - breakPoint) / 100;
          i += slideToScroll;
          xTemp -= getTotalWidths(variableStartLoc + i, slideToScroll) * breakPoint / 100;
          xCorrectionRef.current += -getTotalWidths(variableStartLoc + i - slideToScroll, slideToScroll);

          if (isDraggingRef.current && loop === 'jump' && lastIndexRef.current + Math.floor(i / slideToScroll) >= Math.ceil(itemCount / slideToScroll)) {
            break;
          }
        }
      } else {
        xTemp = Math.abs(x) - getTotalWidths(variableStartLoc + i - slideToScroll, slideToScroll) * breakPoint / 100;

        while (xTemp >= 0) {
          xTemp -= getTotalWidths(variableStartLoc + i - slideToScroll, slideToScroll) * (100 - breakPoint) / 100;
          i -= slideToScroll;
          xTemp -= getTotalWidths(variableStartLoc + i - slideToScroll, slideToScroll) * breakPoint / 100;
          xCorrectionRef.current += getTotalWidths(variableStartLoc + i, slideToScroll);

          if (isDraggingRef.current && loop === 'jump' && lastIndexRef.current + Math.floor(i / slideToScroll) < 0) {
            break;
          }
        }
      }

      newOffset = Math.floor(i / slideToScroll);
    }

    if (loop === 'jump') {
      if (lastIndexRef.current + newOffset < 0) {
        xCorrectionRef.current = -(totalWidthsRef.current - xCorrectionRef.current);
      } else if (lastIndexRef.current + newOffset >= Math.ceil(itemCount / slideToScroll)) {
        xCorrectionRef.current = totalWidthsRef.current + xCorrectionRef.current;
      }
    }

    return newOffset;
  }, [breakPoint, getTotalWidths, slideToScroll, LIST_SIZE_CONSTANT, infinite, centerMode, getTotalWidthsByIndexCM, itemCount, loop]);
  var updateCarouselHeight = useCallback(function (newIndex) {
    if (adaptiveHeight) {
      var variableStartLoc = infinite ? LIST_SIZE_CONSTANT : lastIndexRef.current * slideToScroll;
      setAdaptiveHeightAmount(getMaxHeight(variableStartLoc + newIndex * slideToScroll, slideToScroll));
    }
  }, [LIST_SIZE_CONSTANT, adaptiveHeight, getMaxHeight, infinite, slideToScroll]);
  var moveCarousel = useCallback(function (xDiff, swipe) {
    setXTranslate(function (prevXTranslate) {
      var newXTranslate = prevXTranslate + xDiff;

      if (isDraggingRef.current && loop === 'none') {
        if (newXTranslate < maxXTranslateRef.current) {
          newXTranslate = maxXTranslateRef.current;
        } else if (newXTranslate > minXTranslateRef.current) {
          newXTranslate = minXTranslateRef.current;
        }
      }

      var newOffset = getIndexOffsetFromXTranslate(newXTranslate);

      if (newOffset !== prevOffsetRef.current) {
        setActiveIndex(function () {
          updateCarouselHeight(newOffset);
          return normalizeIndex(lastIndexRef.current + newOffset);
        });
        typeof onSlideChange === 'function' && onSlideChange(normalizeIndex(lastIndexRef.current + newOffset));

        if (swipe) {
          typeof onSwipe === 'function' && onSwipe(lastIndexRef.current + prevOffsetRef.current, normalizeIndex(lastIndexRef.current + newOffset));
        }
      }

      prevOffsetRef.current = newOffset;
      return newXTranslate;
    });

    if (firstUpdateRef.current) {
      firstUpdateRef.current = false;
    }
  }, [loop, getIndexOffsetFromXTranslate, normalizeIndex, updateCarouselHeight, onSlideChange, onSwipe]);
  var moveCarouselToIndex = useCallback(function (index) {
    var variableStartLoc = infinite ? LIST_SIZE_CONSTANT : lastIndexRef.current * slideToScroll;
    var normalizedI = normalizeIndex(index);

    if (normalizedI !== lastIndexRef.current) {
      var minStep = normalizedI - lastIndexRef.current;
      isAnimatingRef.current = true;

      if (infinite) {
        var altStep = itemCount - Math.abs(minStep);

        if (minStep > 0) {
          altStep *= -1;
        }

        minStep = Math.abs(minStep) <= Math.abs(altStep) ? minStep : altStep;
      }

      if (centerMode) {
        if (minStep > 0) {
          moveCarousel(-getTotalWidthsByIndexCM(variableStartLoc, minStep), false);
        } else {
          moveCarousel(-getTotalWidthsByIndexCM(variableStartLoc, minStep), false);
        }
      } else {
        if (minStep > 0) {
          moveCarousel(-getTotalWidths(variableStartLoc, minStep * slideToScroll), false);
        } else {
          moveCarousel(-getTotalWidths(variableStartLoc - 1, minStep * slideToScroll), false);
        }
      }
    }

    endCarousel();
  }, [centerMode, itemCount, endCarousel, getTotalWidths, getTotalWidthsByIndexCM, infinite, LIST_SIZE_CONSTANT, moveCarousel, normalizeIndex, slideToScroll]);
  var updateHeightData = useCallback(function () {
    if (posHelperRef.current && posHelperRef.current.children && heightDataRef.current) {
      var items = posHelperRef.current.children;
      var tempItemHeights = [];

      for (var i = 0; i < items.length; ++i) {
        tempItemHeights[Number(i)] = items[Number(i)].offsetHeight;
      }

      heightDataRef.current = tempItemHeights;
    }
  }, []);
  var updateLayoutData = useCallback(function () {
    if (posHelperRef.current && posHelperRef.current.children && containerRef.current) {
      var items = posHelperRef.current.children;
      var tempItemWidths = [];
      totalWidthsRef.current = 0;

      if (items) {
        for (var i = 0; i < items.length; ++i) {
          tempItemWidths[Number(i)] = items[Number(i)].offsetWidth;
          totalWidthsRef.current += tempItemWidths[Number(i)];
        }

        widthDataRef.current = tempItemWidths;
        updateHeightData();
        updateCarouselHeight(0);
        var last2 = "".concat(sneakPeekWidth).slice(-2);
        var sneakpk = parseInt(sneakPeekWidth);

        if (!centerMode || useContentWidth || !sneakpk) {
          sneakpk = 0;
        }

        if (infinite) {
          if (useContentWidth) {
            posHelperRef.current.style.transform = "translateX(".concat(convertPxToPercent(-getTotalWidths(0, LIST_SIZE_CONSTANT)), "%)");
          } else {
            if (last2 === 'px') {
              sneakpk = parseInt(convertPxToPercent(sneakpk));
            }

            posHelperRef.current.style.transform = "translateX(-".concat(LIST_SIZE_CONSTANT * (100 - sneakpk * 2) / slideToShow, "%)");
          }
        } else {
          var newIndex = lastIndexRef.current + prevOffsetRef.current;

          if (useContentWidth) {
            posHelperRef.current.style.transform = "translateX(".concat(convertPxToPercent(-getTotalWidths(0, newIndex * slideToScroll)), "%)");
          } else if (last2 === 'px') {
            posHelperRef.current.style.transform = "translateX(-".concat(convertPxToPercent(newIndex * slideToScroll * (containerRef.current.offsetWidth - sneakpk * 2)), "%)");
          } else {
            posHelperRef.current.style.transform = "translateX(-".concat(newIndex * slideToScroll * (100 - sneakpk * 2) / slideToShow, "%)");
          }

          if (loop === 'none') {
            if (centerMode) {
              maxXTranslateRef.current = -getTotalWidthsByIndexCM(lastIndexRef.current * slideToScroll, Math.ceil(itemCount / slideToScroll) - 1 - lastIndexRef.current);
              minXTranslateRef.current = -getTotalWidthsByIndexCM(lastIndexRef.current * slideToScroll, -lastIndexRef.current);
            } else {
              maxXTranslateRef.current = containerRef.current.offsetWidth - getTotalWidths(lastIndexRef.current * slideToScroll, itemCount - lastIndexRef.current * slideToScroll);
              maxXTranslateRef.current = maxXTranslateRef.current > 0 ? 0 : maxXTranslateRef.current;
              minXTranslateRef.current = -(containerRef.current.offsetWidth + getTotalWidths(lastIndexRef.current * slideToScroll, -lastIndexRef.current * slideToScroll));
              minXTranslateRef.current = getTotalWidths(0, lastIndexRef.current * slideToScroll);
            }
          }
        }
      }
    }
  }, [centerMode, itemCount, infinite, LIST_SIZE_CONSTANT, loop, slideToScroll, slideToShow, sneakPeekWidth, useContentWidth, getTotalWidths, getTotalWidthsByIndexCM, updateHeightData, updateCarouselHeight]);
  useLayoutEffect(function () {
    if (!isDraggingRef.current && !isAnimatingRef.current) {
      updateLayoutData();
    }
  }, [updateLayoutData, _activeIndex, useContentWidth, slideToShow, slideToScroll, children, loop, sneakPeekWidth]);
  var showAfterLoaded = useCallback(function (event) {
    var targetElement = event.target || event.srcElement;
    targetElement.style.visibility = '';
  }, []);
  useEffect(function () {
    if (firstUpdateRef.current) {
      var _containerRef$current, _containerRef$current2;

      var slides = (containerRef === null || containerRef === void 0 ? void 0 : (_containerRef$current = containerRef.current) === null || _containerRef$current === void 0 ? void 0 : _containerRef$current.querySelectorAll(':scope > div')) || [];
      unloadedImageCtRef.current = ((_containerRef$current2 = containerRef.current) === null || _containerRef$current2 === void 0 ? void 0 : _containerRef$current2.getElementsByTagName('img').length) || 0;

      for (var i = 0; i < slides.length; ++i) {
        var images = slides[Number(i)].getElementsByTagName('img');
        imageLoadingDataRef.current[Number(i)] = images.length;

        for (var x = 0; x < images.length; ++x) {
          var item = images[Number(x)];

          if (!item.complete) {
            (function () {
              var slideI = i;
              item.style.visibility = 'hidden';
              item.addEventListener('load', function (e) {
                showAfterLoaded(e);
                --imageLoadingDataRef.current[Number(slideI)];
                --unloadedImageCtRef.current;

                if (unloadedImageCtRef.current === 0) {
                  updateHeightData();
                }
              });
            })();
          } else {
            --imageLoadingDataRef.current[Number(i)];
            --unloadedImageCtRef.current;
          }
        }
      }

      if (unloadedImageCtRef.current === 0) {
        updateHeightData();
      }
    }
  }, [showAfterLoaded, children, LIST_SIZE_CONSTANT, updateCarouselHeight, updateHeightData]);
  var adjustForCenterMode = useCallback(function () {
    if (centerMode) {
      var variableStartLoc = infinite ? LIST_SIZE_CONSTANT : lastIndexRef.current * slideToScroll;
      var paddingForCenter = '0';

      if (!useContentWidth) {
        var sneakpk = sneakPeekWidth;

        if (Number.isInteger(sneakPeekWidth) || !isNaN(parseInt(sneakPeekWidth.slice(-1)))) {
          sneakpk += '%';
        }

        paddingForCenter = sneakpk;
      } else {
        var _containerRef$current3;

        var containerWidth = containerRef.current ? (_containerRef$current3 = containerRef.current) === null || _containerRef$current3 === void 0 ? void 0 : _containerRef$current3.offsetWidth : 0;
        paddingForCenter = "".concat(convertPxToPercent((containerWidth - widthDataRef.current[variableStartLoc + prevOffsetRef.current * slideToScroll]) / 2), "%");
      }

      setPaddingCenter(paddingForCenter);
    } else {
      setPaddingCenter('0');
    }
  }, [centerMode, useContentWidth, sneakPeekWidth, slideToScroll, LIST_SIZE_CONSTANT, infinite]);
  useLayoutEffect(function () {
    adjustForCenterMode();
  }, [adjustForCenterMode, activeIndex, loop, centerMode]);
  var startAutoplay = useCallback(function () {
    if (autoPlay && !isDraggingRef.current) {
      stopAutoplay();
      isAnimatingRef.current = false;
      autoplayTimeoutRef.current = setTimeout(function () {
        if (containerRef.current) {
          containerRef.current.style.transition = "transform ".concat(durationT3, " ").concat(easeInOut, " 0s");
        }

        moveCarouselToIndex(lastIndexRef.current + 1);
      }, autoPlaySpeed);
    }
  }, [autoPlay, autoPlaySpeed, moveCarouselToIndex]);
  useEffect(function () {
    if (autoPlay && !isDraggingRef.current) {
      startAutoplay();
    } else {
      stopAutoplay();
    }
  }, [autoPlay, activeIndex, startAutoplay, autoPlaySpeed, centerMode]);
  useEffect(function () {
    return function () {
      stopAutoplay();
      animationTimeoutRef.current && clearTimeout(animationTimeoutRef.current);
    };
  }, []);
  useEffect(function () {
    if (canUseDOM) {
      window.addEventListener('resize', endCarousel);
    }

    return function () {
      window.removeEventListener('resize', endCarousel);
    };
  });

  var stopAutoplay = function stopAutoplay() {
    autoplayTimeoutRef.current && clearTimeout(autoplayTimeoutRef.current);
  };

  useEffect(function () {
    moveCarouselToIndex(activeIndex);
  }, [LIST_SIZE_CONSTANT, activeIndex, getTotalWidths, moveCarouselToIndex, slideToScroll, loop]);
  endCarousel = useCallback(function () {
    if (containerRef.current) {
      containerRef.current.style.transition = "transform ".concat(durationT3, " ").concat(easeInOut, " 0s");
    }

    isAnimatingRef.current = true;
    animationTimeoutRef.current = setTimeout(function () {
      if (containerRef.current) {
        containerRef.current.style.transition = '';
      }

      xCorrectionRef.current = 0;
      lastIndexRef.current = normalizeIndex(lastIndexRef.current + prevOffsetRef.current);
      prevOffsetRef.current = 0;
      updateLayoutData();
      adjustForCenterMode();
      setXTranslate(0);
      isAnimatingRef.current = false;
      startAutoplay();
    }, 300);
  }, [normalizeIndex, updateLayoutData, adjustForCenterMode, startAutoplay]);

  var handleTouchStart = function handleTouchStart(e) {
    if (slideToScroll <= 0) {
      return;
    }

    e.target.addEventListener('touchmove', function (e) {
      handleTouchMove(e);
    });
    e.target.addEventListener('touchend', function (e) {
      handleTouchEnd(e);
    });

    if (containerRef.current) {
      containerRef.current.style.transition = "";
    }

    x1Ref.current = 'touches' in e ? e.touches[0].clientX : e.clientX;
    isDraggingRef.current = true;
    stopAutoplay();
  };

  var handleTouchMove = function handleTouchMove(e) {
    x2Ref.current = 'touches' in e ? e.touches[0].clientX : e.clientX;
    var xDiff = x2Ref.current - x1Ref.current;

    if (xDiff !== 0) {
      moveCarousel(xDiff * swipeSensitivity, true);
      x1Ref.current = x2Ref.current;
    }
  };

  var handleTouchEnd = function handleTouchEnd(e) {
    if (!freeScrolling) {
      setXTranslate(function () {
        var toReturn = xCorrectionRef.current;
        return toReturn;
      });
      endCarousel();
    } else if (autoPlay) {
      startAutoplay();
    }

    isDraggingRef.current = false;
    e.target.removeEventListener('touchmove', function (e) {
      handleTouchMove(e);
    });
    e.target.removeEventListener('touchend', function (e) {
      handleTouchEnd(e);
    });
  };

  var handleIndicatorClick = function handleIndicatorClick(index) {
    if (!isAnimatingRef.current) {
      animationTimeoutRef.current && clearTimeout(animationTimeoutRef.current);
      isAnimatingRef.current = false;
      stopAutoplay();
      moveCarouselToIndex(index);
    }
  };

  var handleMoveCarouselOnKeyDown = function handleMoveCarouselOnKeyDown(e, newActiveIndex) {
    e.preventDefault();
    handleIndicatorClick(newActiveIndex);
  };

  useKeyboardControl({
    ArrowRight: function ArrowRight(e) {
      return handleMoveCarouselOnKeyDown(e, _activeIndex + 1);
    },
    ArrowLeft: function ArrowLeft(e) {
      return handleMoveCarouselOnKeyDown(e, _activeIndex - 1);
    }
  }, isFocused);

  var handleFocus = function handleFocus() {
    stopAutoplay();
    setIsFocused(true);
  };

  var handleBlur = function handleBlur() {
    if (autoPlay && !isDraggingRef.current) {
      startAutoplay();
    }

    setIsFocused(false);
  };

  var indicatorAlignment = function indicatorAlignment() {
    var carAlign = 'flex-start';

    if (indicatorAlign === 'center') {
      carAlign = 'center';
    } else if (indicatorAlign === 'right') {
      carAlign = 'flex-end';
    }

    return carAlign;
  };

  var renderInfiniteItems = function renderInfiniteItems() {
    if (!children) {
      return;
    }

    var a = [];

    for (var i = (lastIndexRef.current + prevOffsetRef.current) * slideToScroll - 1; i >= (lastIndexRef.current + prevOffsetRef.current) * slideToScroll - LIST_SIZE_CONSTANT; --i) {
      var index = normalizeItemLocation(i);
      a.unshift(React.createElement(CarouselItem, {
        key: i,
        useContentWidth: useContentWidth,
        sneakPeekWidth: sneakPeekWidth,
        centerMode: centerMode,
        slideToShow: slideToShow,
        itemAlign: itemAlign,
        role: "group",
        "aria-roledescription": "slide",
        "aria-label": "".concat(index + 1, " of ").concat(itemCount)
      }, itemCount <= 1 ? children : children[Number(index)]));
    }

    for (var _i = (lastIndexRef.current + prevOffsetRef.current) * slideToScroll; _i < (lastIndexRef.current + prevOffsetRef.current) * slideToScroll + slideToScroll + LIST_SIZE_CONSTANT; ++_i) {
      var _index = normalizeItemLocation(_i);

      var activeProps = _i === lastIndexRef.current + prevOffsetRef.current ? {
        innerRef: activeItemRef,
        id: 'unf-carouselitem-active',
        dataTestId: 'unf-carouselitem-active'
      } : {};
      a.push(React.createElement(CarouselItem, _extends({}, activeProps, {
        key: _i,
        useContentWidth: useContentWidth,
        sneakPeekWidth: sneakPeekWidth,
        centerMode: centerMode,
        slideToShow: slideToShow,
        itemAlign: itemAlign,
        role: "group",
        "aria-roledescription": "slide",
        "aria-label": "".concat(_index + 1, " of ").concat(itemCount)
      }), itemCount <= 1 ? children : children[Number(_index)]));
    }

    return React.createElement("div", {
      style: {
        transform: "translateX(\n            ".concat(convertPxToPercent(prevOffsetRef.current >= 0 ? -getTotalWidths(0, LIST_SIZE_CONSTANT) + getTotalWidths(0, prevOffsetRef.current * slideToScroll) : -getTotalWidths(0, LIST_SIZE_CONSTANT) + getTotalWidths(-1, prevOffsetRef.current * slideToScroll)), "%)"),
        display: 'flex',
        height: '100%'
      },
      ref: posHelperRef
    }, a);
  };

  var renderFiniteItems = function renderFiniteItems() {
    if (!children) {
      return;
    }

    var a = [];

    for (var i = 0; i < itemCount; ++i) {
      var index = normalizeItemLocation(i);
      var activeProps = i === lastIndexRef.current + prevOffsetRef.current ? {
        innerRef: activeItemRef,
        id: 'unf-carouselitem-active',
        dataTestId: 'unf-carouselitem-active'
      } : {};
      a.push(React.createElement(CarouselItem, _extends({
        key: i,
        useContentWidth: useContentWidth,
        sneakPeekWidth: sneakPeekWidth,
        centerMode: centerMode,
        slideToShow: slideToShow,
        itemAlign: itemAlign,
        role: "group",
        "aria-roledescription": "slide",
        "aria-label": "".concat(index + 1, " of ").concat(itemCount)
      }, activeProps), children[Number(index)]));
    }

    return React.createElement("div", {
      ref: posHelperRef,
      style: {
        display: 'flex',
        height: '100%'
      }
    }, a);
  };

  var getCarouselHeight = function getCarouselHeight() {
    if (adaptiveHeight) {
      return adaptiveHeightAmount;
    } else if (height) {
      return height;
    } else {
      return 'auto';
    }
  };

  return React.createElement(CarouselContainer, _extends({}, otherProps, {
    "data-unify": "CarouselV2",
    "aria-roledescription": "carousel",
    tabIndex: 0,
    onMouseEnter: function onMouseEnter() {
      return stopAutoplay();
    },
    onMouseLeave: function onMouseLeave() {
      return startAutoplay();
    },
    onFocus: handleFocus,
    onBlur: handleBlur
  }), React.createElement(CarouselContentContainer, {
    onTouchStart: handleTouchStart,
    innerRef: containerRef,
    style: {
      transform: "translate3d(".concat(xTranslate, "px, 0, 0)"),
      left: "".concat(paddingCenter),
      height: getCarouselHeight()
    },
    "aria-live": 'polite',
    "aria-labelledby": 'unf-carouselitem-active'
  }, infinite ? renderInfiniteItems() : renderFiniteItems()), showIndicator && slideToScroll > 0 && React.createElement("div", {
    style: {
      margin: '8px 16px 0 16px',
      display: 'flex',
      justifyContent: indicatorAlignment()
    }
  }, React.createElement(PageControl, _extends({
    currentPage: _activeIndex,
    numberOfPage: Number.isNaN(Math.ceil(itemCount / slideToScroll)) ? 0 : Math.ceil(itemCount / slideToScroll),
    onIndicatorClick: function onIndicatorClick(index) {
      handleIndicatorClick(index);
    }
  }, dataTest ? {
    dataTest: dataTest === null || dataTest === void 0 ? void 0 : dataTest.carouselIndicator
  } : {}))));
};

export default CarouselV2;