import { ComponentPropsWithoutRef } from 'react';
declare type CarouselV2Attributes = ComponentPropsWithoutRef<'section'>;
export declare type CarouselV2IndicatorAlign = 'left' | 'center' | 'right';
export declare type CarouselV2ItemAlign = 'top' | 'middle' | 'bottom';
export declare type CarouselV2Loop = 'infinite' | 'jump' | 'none';
export interface CarouselV2Props extends Omit<CarouselV2Attributes, 'css'> {
    /**
     * To pass activeIndex for this carousel
     * @default 0
     */
    activeIndex?: number;
    /**
     * To make carousel's height adaptive to active item's height
     * @default false
     */
    adaptiveHeight?: boolean;
    /**
     * To enable autoslide for carousel. Autoslide stops when hovered or focused for accessibility purpose.
     * @default false
     */
    autoPlay?: boolean;
    /**
     * To pass autoPlay speed in ms
     * @default 2000
     */
    autoPlaySpeed?: number;
    /**
     * To set percentage of item at which carousel will slide to next page
     * @default 50
     */
    breakPoint?: number;
    /**
     * To center active item of this carousel
     * @default false
     */
    centerMode?: boolean;
    /**
     * To provide datatest-id
     * @default {}
     */
    dataTest?: {
        carouselIndicator?: string;
    };
    /**
     * To disable snap behaviours/allow free scrolling
     * @default false
     */
    freeScrolling?: boolean;
    /**
     * To set carousel's height, if set to 0, carousel's height will depend on activeItem
     */
    height?: number;
    /**
     * To set carousel indicator's alignment
     * @default 'left'
     */
    indicatorAlign?: CarouselV2IndicatorAlign;
    /**
     * To set the vertical alignment of item.
     */
    itemAlign?: CarouselV2ItemAlign;
    /**
     * To set type of Carousel
     * @default 'infinite'
     */
    loop?: CarouselV2Loop;
    /**
     * To show Carousel indicator
     * @default false
     */
    showIndicator?: boolean;
    /**
     * To pass number of items to slide each page change
     * @default 1
     */
    slideToScroll?: number;
    /**
     * To pass number of slides per page, activating `useContentWidth` will disable this
     * @default 1
     */
    slideToShow?: number;
    /**
     * To set sneak peek width (in percentage) for side slides in `centerMode`
     * @default '10px'
     */
    sneakPeekWidth?: string;
    /**
     * To allow variable widths for carousel items
     * @default false
     */
    useContentWidth?: boolean;
    /**
     * To pass callback that triggers when page index changed.
     * @default () => {}
     */
    onSlideChange?: (newIndex: number) => void;
    /**
     * To pass callback that triggers whenever active slide is changed through swipes.
     * @default () => {}
     */
    onSwipe?: (oldIndex: number, newIndex: number) => void;
}
export {};
