import React from 'react';
declare type CheckboxAttributes = React.ComponentPropsWithoutRef<'label'> | React.ComponentPropsWithoutRef<'div'>;
export interface CheckboxProps extends Omit<CheckboxAttributes, 'onChange' | 'onClick' | 'css'> {
    /**
     * To apply checked Checkbox design
     */
    checked?: boolean;
    /**
     * To pass custom className to create custom style
     */
    className?: string;
    /**
     * To apply disabled Checkbox design
     */
    disabled?: boolean;
    /**
     * Checkbox input id
     */
    id?: string;
    /**
     * To apply indeterminate Checkbox icon
     */
    indeterminate?: boolean;
    /**
     * Pass additional props to input element
     */
    inputProps?: Record<string, any>;
    /**
     * Checkbox input name
     */
    name?: string;
    /**
     * Wrapper as label
     */
    useLabel?: boolean;
    /**
     * Checkbox input value
     */
    value?: string;
    /**
     * Set the variant of the Checkbox
     */
    variant?: 'default' | 'inverted';
    /**
     * Action when Checkbox value is changed. `(event) => void;`
     */
    onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
    /**
     * Action when Checkbox is clicked. `(event) => void;`
     */
    onClick?: (e: React.MouseEvent<HTMLInputElement>) => void;
}
export {};
