import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["active", "alternate", "children", "className", "dashed", "disabled", "dropdown", "ellipsis", "image", "icon", "iconSize", "large", "loading", "prependObject", "primary", "shrink", "small", "onClick", "onClose"];
import React from 'react';
import { cx } from 'emotion';
import { ChevronDown, Clear } from 'unify-icons/system';
import { GN500, NN300, NN900 } from 'unify-token/colors';
import { Shrinkable, Content, Container, Addon, AddonIcon, Image } from "./style";

var Chip = function Chip(_ref) {
  var active = _ref.active,
      alternate = _ref.alternate,
      children = _ref.children,
      className = _ref.className,
      dashed = _ref.dashed,
      disabled = _ref.disabled,
      dropdown = _ref.dropdown,
      _ref$ellipsis = _ref.ellipsis,
      ellipsis = _ref$ellipsis === void 0 ? true : _ref$ellipsis,
      _ref$image = _ref.image,
      image = _ref$image === void 0 ? '' : _ref$image,
      _ref$icon = _ref.icon,
      icon = _ref$icon === void 0 ? '' : _ref$icon,
      _ref$iconSize = _ref.iconSize,
      iconSize = _ref$iconSize === void 0 ? 24 : _ref$iconSize,
      large = _ref.large,
      loading = _ref.loading,
      prependObject = _ref.prependObject,
      primary = _ref.primary,
      shrink = _ref.shrink,
      small = _ref.small,
      onClick = _ref.onClick,
      onClose = _ref.onClose,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var classes = cx('unf-chip', {
    'unf-chip--close': typeof onClose === 'function',
    'unf-chip--active': active,
    'unf-chip--disabled': disabled,
    'unf-chip--loading': loading
  }, className);

  var handleRipple = function handleRipple(e) {
    if (e.currentTarget) {
      var target = e.currentTarget;

      if (target.getElementsByClassName('unf-chip-ripple').length > 0) {
        target.removeChild(target.getElementsByClassName('unf-chip-ripple')[0]);
      }

      var circle = document.createElement('div');
      target.appendChild(circle);
      var d = Math.max(target.clientWidth, target.clientHeight);
      circle.style.width = circle.style.height = d + 'px';
      circle.style.left = '0';
      circle.style.top = 0 - d / 2 + target.clientHeight / 2 + 'px';
      circle.classList.add('unf-chip-ripple');
    }
  };

  var handleClick = function handleClick(e) {
    !disabled && onClick && onClick(e);
    handleRipple(e);
  };

  return React.createElement(Container, _extends({
    active: active,
    alternate: alternate,
    "aria-pressed": active,
    className: classes,
    "data-unify": "Chip",
    dashed: dashed,
    disabled: disabled,
    image: image,
    icon: icon,
    large: large,
    loading: loading,
    primary: primary,
    shrink: shrink,
    small: small,
    ellipsis: ellipsis,
    onClick: handleClick,
    onClose: onClose
  }, otherProps), icon && React.createElement(AddonIcon, {
    icon: icon,
    iconSize: iconSize,
    marginRight: 4,
    borderRadius: 4,
    shrink: shrink
  }), prependObject && React.createElement(Addon, {
    shrink: shrink
  }, prependObject), image && React.createElement(Image, {
    src: image,
    large: large,
    shrink: shrink
  }), React.createElement(Shrinkable, {
    shrink: shrink,
    ellipsis: ellipsis
  }, React.createElement(Content, {
    large: large
  }, children), dropdown && React.createElement(ChevronDown, {
    size: large ? 24 : 16,
    color: active || alternate ? GN500 : disabled ? NN300 : NN900,
    style: {
      marginLeft: 4,
      flexShrink: 0,
      zIndex: 1
    }
  })), onClose && !active && !alternate && !disabled && React.createElement(Clear, {
    "aria-label": "chip-close",
    color: NN900,
    style: {
      marginLeft: 4,
      flexShrink: 0,
      zIndex: 1
    },
    size: 16,
    onClick: !disabled ? onClose : undefined
  }));
};

export default Chip;