import React from 'react';
declare type ChipAttributes = React.ComponentPropsWithoutRef<'button'>;
interface ChipBaseProps {
    /**
     * To determine active state of chip
     */
    active?: boolean;
    /**
     * To apply alternate Chip design
     */
    alternate?: boolean;
    /**
     * To specify content on Children
     */
    children?: React.ReactNode;
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     * To apply dashed Chip design
     */
    dashed?: boolean;
    /**
     * To apply disabled Chip design
     */
    disabled?: boolean;
    /**
     * To add dropdown arrow
     */
    dropdown?: boolean;
    /**
     * To apply ellipsis text on Chip
     */
    ellipsis?: boolean;
    /**
     * To provide icon url
     */
    icon?: string;
    /**
     * To provide image url
     */
    image?: string;
    /**
     * To provide icon size. Strictly either 16, 24 or 32
     */
    iconSize?: 16 | 24 | 32 | 40;
    /**
     * To apply large Chip size design
     */
    large?: boolean;
    /**
     * To determine loading state of Button
     */
    loading?: boolean;
    /**
     * To add a component to the leftmost part of the chip
     */
    prependObject?: React.ReactNode;
    /**
     * To apply primary Chip design
     */
    primary?: boolean;
    /**
     * To hide Chip text label
     */
    shrink?: boolean;
    /**
     * To apply small Chip size design
     */
    small?: boolean;
    /**
     * To pass callback when the Chip is clicked. `(event) => void;`
     */
    onClick?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /**
     * To pass callback when the close icon is clicked. `(event) => void;`
     */
    onClose?: (e: React.MouseEvent<HTMLDivElement>) => void;
}
export declare type ChipProps = ChipBaseProps & Omit<ChipAttributes, keyof ChipBaseProps | 'css'>;
export interface AddonIconProps {
    type?: 'close' | 'dropdown';
    borderRadius?: number;
    marginRight?: number;
    marginLeft?: number;
}
export {};
