import _extends from "@babel/runtime/helpers/extends";
import React, { useEffect, useRef, useCallback } from 'react';
import { GN300, GN500, NN0RGB, NN50RGB } from 'unify-token/colors';
import { colorWhiteAlways } from "../../build/Providers/common/style";
import { addClass, hasClass, removeClass } from "../../build/Providers/common/functions";
import { DeterminateContainer, IndeterminateContainer } from "./style";

var toggleClass = function toggleClass(ref) {
  return function (className) {
    var el = ref.current;

    if (el) {
      hasClass(className, el) && removeClass(className, el);
      addClass(className, el);
    }
  };
};

var Circular = function Circular(_ref) {
  var _ref$indeterminate = _ref.indeterminate,
      indeterminate = _ref$indeterminate === void 0 ? false : _ref$indeterminate,
      _ref$loading = _ref.loading,
      loading = _ref$loading === void 0 ? false : _ref$loading,
      progress = _ref.progress,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'large' : _ref$size,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'color' : _ref$variant,
      width = _ref.width;
  var strokeOne = useRef(null);
  var strokeTwo = useRef(null);
  var circumference = 20 * 2 * Math.PI;
  var strokeDashoffset = circumference - (progress ? progress : 0) / 100 * circumference;
  var toggleStrokeOne = toggleClass(strokeOne);
  var toggleStrokeTwo = toggleClass(strokeTwo);
  var animateStrokeOne = useCallback(function () {
    toggleStrokeOne('unf-loader-circular__play');
    strokeTwo.current && removeClass('unf-loader-circular__play', strokeTwo.current);
  }, [toggleStrokeOne]);
  var animateStrokeTwo = useCallback(function () {
    toggleStrokeTwo('unf-loader-circular__play');
    strokeOne.current && removeClass('unf-loader-circular__play', strokeOne.current);
  }, [toggleStrokeTwo]);
  useEffect(function () {
    loading && toggleStrokeTwo('unf-loader-circular__play');
  }, [loading]);
  var determinateProps = {
    cx: 0,
    cy: 0,
    r: 20,
    fill: 'none',
    strokeDasharray: "".concat(circumference, " ").concat(circumference),
    strokeWidth: 4,
    style: {
      strokeDashoffset: strokeDashoffset
    }
  };
  var indeterminateProps = {
    cx: '0',
    cy: '0',
    r: '20',
    fill: 'none',
    strokeWidth: '4'
  };
  return indeterminate ? React.createElement(IndeterminateContainer, {
    domSize: size,
    width: width,
    "data-unify": "LoaderCircular"
  }, React.createElement("svg", {
    viewBox: "-24 -24 48 48"
  }, React.createElement("circle", _extends({
    className: "yellow unf-loader-circular__reverse",
    stroke: variant === 'color' ? GN500 : colorWhiteAlways
  }, indeterminateProps))), React.createElement("svg", {
    viewBox: "-24 -24 48 48"
  }, React.createElement("circle", _extends({
    ref: strokeOne,
    className: "green",
    stroke: variant === 'color' ? GN300 : "rgba(var(--NN1000RGB, ".concat(NN0RGB, "), 0.7)")
  }, indeterminateProps)))) : React.createElement(DeterminateContainer, {
    circumference: circumference,
    domSize: size,
    width: width,
    "data-unify": "LoaderCircular"
  }, React.createElement("svg", {
    viewBox: "-24 -24 48 48"
  }, React.createElement("circle", _extends({}, determinateProps, {
    stroke: variant === 'color' ? "var(--GN700, ".concat(GN300, ")") : "rgba(".concat(NN50RGB, ",0.7)")
  })), !indeterminate && loading && React.createElement(React.Fragment, null, React.createElement("circle", _extends({}, determinateProps, {
    ref: strokeTwo,
    stroke: variant === 'color' ? GN500 : colorWhiteAlways,
    onAnimationEnd: animateStrokeOne
  })), React.createElement("circle", _extends({}, determinateProps, {
    className: "unf-loader-circular__progress",
    ref: strokeOne,
    stroke: variant === 'color' ? GN300 : "rgba(var(--NN1000RGB, ".concat(NN0RGB, "), 0.7)"),
    onAnimationEnd: animateStrokeTwo
  })))));
};

export default Circular;