import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["currentPage", "description", "display", "hasSkip", "highlightOptions", "lang", "numberOfPage", "overlayOptions", "title", "onChange", "onClickSkip", "onClose"];
import React, { useState, useEffect, useRef, useCallback } from 'react';
import { spacingLv3, spacingLv4 } from 'unify-token/build/v2/spacings';
import Card from "../../build/Card";
import PageControl from "../../build/PageControl";
import Delayed from "../../build/Providers/common/components/Delayed";
import PortalWrapper from "../../build/Providers/common/components/PortalWrapper";
import { enableScroll, disableScroll } from "../../build/Providers/common/utilities/scroll";
import Typography from "../../build/Typography";
import getViewport from "../../build/Providers/common/functions/getViewport";
import hasPosition from "../../build/Providers/common/functions/hasPosition";
import { canUseDOM } from "../../build/Providers/common/functions";
import { ActionWrapper, ActionButton, Container, Footer, ActionText } from "./style";
import CoachmarkOverlay, { overlayDefaultProps } from "./CoachmarkOverlay";
var HIGHLIGHT_PADDING = 8;
var COACHMARK_SPACING = 16;
var UNMOUNT_DELAY = 280;
var DISPLAY_SHOW_DELAY = 240;
var DISPLAY_HIDE_DELAY = 40;
var HEAD_MARGIN = "0 0 ".concat(spacingLv3, " 0");
var TEXT_MARGIN = "0 0 ".concat(spacingLv4, " 0");
var DEFAULT_OVERLAY_OPTIONS = {
  clickToClose: true,
  show: true
};
var LANG_COPY = {
  en: {
    skip: 'Skip',
    next: 'Go to the next slide',
    prev: 'Go to the previous slide',
    done: 'I understand',
    overlay: 'Tap to dismiss info'
  },
  id: {
    skip: 'Lewati',
    next: 'Ke slide selanjutnya',
    prev: 'Ke slide sebelumnya',
    done: 'Saya mengerti',
    overlay: 'Ketuk untuk menyingkirkan info'
  }
};

var Coachmark = function Coachmark(_ref) {
  var _ref$currentPage = _ref.currentPage,
      currentPage = _ref$currentPage === void 0 ? 0 : _ref$currentPage,
      description = _ref.description,
      _ref$display = _ref.display,
      display = _ref$display === void 0 ? false : _ref$display,
      _ref$hasSkip = _ref.hasSkip,
      hasSkip = _ref$hasSkip === void 0 ? false : _ref$hasSkip,
      highlightOptions = _ref.highlightOptions,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      numberOfPage = _ref.numberOfPage,
      overlayOptions = _ref.overlayOptions,
      title = _ref.title,
      onChange = _ref.onChange,
      onClickSkip = _ref.onClickSkip,
      onClose = _ref.onClose,
      otherProps2 = _objectWithoutProperties(_ref, _excluded);

  var _totalPage = numberOfPage ? numberOfPage.length : 0;

  var _pageControlStyle = {
    opacity: _totalPage > 1 ? 1 : 0
  };

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      _display = _useState2[0],
      _setIsDisplay = _useState2[1];

  var timeout = useRef();
  useEffect(function () {
    timeout.current = setTimeout(function () {
      _setIsDisplay(display);
    }, display ? DISPLAY_SHOW_DELAY : DISPLAY_HIDE_DELAY);
  }, [display]);
  useEffect(function () {
    return function () {
      timeout.current && clearTimeout(timeout.current);
    };
  }, []);
  useEffect(function () {
    if (canUseDOM) {
      if (display) {
        disableScroll();
      } else {
        enableScroll();
      }

      return function () {
        if (canUseDOM) {
          enableScroll();
        }
      };
    }
  }, [display]);

  var handlePrev = function handlePrev() {
    var newValue;

    if (currentPage === 0) {
      newValue = 0;
    } else {
      newValue = currentPage - 1;
    }

    typeof onChange === 'function' && onChange(newValue);
  };

  var handleNext = useCallback(function () {
    if (currentPage === _totalPage - 1) {
      typeof onClose === 'function' && onClose();
    } else {
      typeof onChange === 'function' && onChange(currentPage + 1);
    }
  }, [currentPage, _totalPage, onClose, onChange]);

  var getWindowDimension = function getWindowDimension() {
    return canUseDOM ? getViewport() : {
      height: 0,
      width: 0
    };
  };

  var _useState3 = useState(getWindowDimension()),
      _useState4 = _slicedToArray(_useState3, 2),
      windowDimension = _useState4[0],
      setWindowDimension = _useState4[1];

  useEffect(function () {
    if (canUseDOM) {
      var handleWindowDimension = function handleWindowDimension() {
        setWindowDimension(getWindowDimension());
      };

      window.addEventListener('resize', handleWindowDimension);
      return function cleanup() {
        window.removeEventListener('resize', handleWindowDimension);
      };
    }

    return undefined;
  }, []);

  var _useState5 = useState(0),
      _useState6 = _slicedToArray(_useState5, 2),
      xPos = _useState6[0],
      setXPos = _useState6[1];

  var _useState7 = useState(0),
      _useState8 = _slicedToArray(_useState7, 2),
      yPos = _useState8[0],
      setYPos = _useState8[1];

  var _useState9 = useState(false),
      _useState10 = _slicedToArray(_useState9, 2),
      reverse = _useState10[0],
      setReverse = _useState10[1];

  var _useState11 = useState(overlayDefaultProps),
      _useState12 = _slicedToArray(_useState11, 2),
      overlayProps = _useState12[0],
      setOverlayProps = _useState12[1];

  var getElCoords = function getElCoords(elem) {
    var box = elem.getBoundingClientRect();
    var body = document.body;
    var docEl = document.documentElement;
    var scrollTop = window.pageYOffset || docEl.scrollTop || body.scrollTop;
    var scrollLeft = window.pageXOffset || docEl.scrollLeft || body.scrollLeft;
    var clientTop = docEl.clientTop || body.clientTop || 0;
    var clientLeft = docEl.clientLeft || body.clientLeft || 0;
    var top = box.top + scrollTop - clientTop;
    var left = box.left + scrollLeft - clientLeft;
    return {
      top: Math.round(top),
      left: Math.round(left),
      height: box.height,
      width: box.width
    };
  };

  var handlePosition = useCallback(function (containerEl) {
    if (canUseDOM && numberOfPage && _display) {
      Boolean(containerEl) && containerEl.focus();
      var containerHeight = containerEl && containerEl.getBoundingClientRect().height;
      var el = document.querySelector(numberOfPage["".concat(currentPage)]);

      if (el) {
        var _ref2 = el && el.getBoundingClientRect(),
            elementTop = _ref2.top;

        var _getElCoords = getElCoords(el),
            left = _getElCoords.left,
            top = _getElCoords.top,
            height = _getElCoords.height,
            width = _getElCoords.width;

        var highlightPadding = highlightOptions && typeof highlightOptions.padding !== 'undefined' ? highlightOptions.padding : HIGHLIGHT_PADDING;

        var _reverse = windowDimension.height - elementTop - height - COACHMARK_SPACING - highlightPadding <= containerHeight ? true : false;

        var newXPos = left - highlightPadding + width / 2;
        var newYPos = _reverse ? top - containerHeight - COACHMARK_SPACING - highlightPadding : height + top + COACHMARK_SPACING + highlightPadding;
        setXPos(newXPos);
        setYPos(newYPos);
        setReverse(_reverse);
        setOverlayProps(function (state) {
          return _objectSpread(_objectSpread({}, state), {}, {
            top: top,
            left: left,
            height: height,
            width: width
          });
        });
        var isFixed = hasPosition(el);

        if (!isFixed) {
          el.scrollIntoView({
            behavior: 'smooth',
            block: 'center'
          });
        }
      } else {
        handleNext();
      }
    }
  }, [currentPage, handleNext, numberOfPage, windowDimension, highlightOptions === null || highlightOptions === void 0 ? void 0 : highlightOptions.padding, _display]);

  var _overlayOptions = _objectSpread(_objectSpread({}, DEFAULT_OVERLAY_OPTIONS), overlayOptions);

  var onOverlayClick = _overlayOptions.clickToClose ? onClose : function () {};
  return React.createElement(PortalWrapper, null, React.createElement(Delayed, {
    mounted: display,
    unmountAfter: UNMOUNT_DELAY
  }, _overlayOptions.show && React.createElement(CoachmarkOverlay, _extends({}, overlayProps, {
    highlightOptions: highlightOptions,
    onClick: onOverlayClick,
    ariaLabel: LANG_COPY["".concat(lang)].overlay
  })), React.createElement(Container, _extends({
    isDisplay: _display,
    xPos: xPos,
    yPos: yPos,
    reverse: reverse,
    innerRef: handlePosition,
    "data-unify": "Coachmark",
    id: "coachmark",
    "aria-modal": "true",
    role: "alertdialog",
    tabIndex: 0
  }, otherProps2), React.createElement(Card, {
    margin: "0 16px"
  }, title && React.createElement(Typography, {
    main: true,
    margin: HEAD_MARGIN,
    tag: 4,
    id: "unf-coachmark__label"
  }, Array.isArray(title) ? title["".concat(currentPage)] : title), React.createElement(Typography, {
    main: true,
    margin: TEXT_MARGIN,
    caption: true,
    id: "unf-coachmark__desc"
  }, Array.isArray(description) ? description["".concat(currentPage)] : description), React.createElement(Footer, null, React.createElement(PageControl, {
    currentPage: currentPage,
    numberOfPage: _totalPage,
    style: _pageControlStyle
  }), React.createElement(ActionWrapper, null, hasSkip && numberOfPage && !(currentPage === numberOfPage.length - 1) && React.createElement(ActionText, {
    onClick: onClickSkip ? onClickSkip : onClose
  }, LANG_COPY["".concat(lang)].skip), _totalPage > 1 && currentPage !== 0 && React.createElement(ActionButton, {
    previous: true,
    onClick: handlePrev,
    "aria-label": LANG_COPY["".concat(lang)].prev
  }), React.createElement(ActionButton, {
    next: true,
    last: currentPage === _totalPage - 1,
    onClick: handleNext,
    "aria-label": currentPage === _totalPage - 1 ? LANG_COPY["".concat(lang)].done : LANG_COPY["".concat(lang)].next
  })))))));
};

export default Coachmark;