import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children", "className", "container", "description", "footer", "hiddenTimeout", "lang", "offsets", "placement", "show", "selector", "title", "timeout", "width", "zIndex", "onClose", "onAnimationEnd"];
import React, { useState, useEffect, useCallback, useRef } from 'react';
import { cx } from 'react-emotion';
import { NN0, NN900, NN950 } from 'unify-token/colors';
import Close from 'unify-icons/system/Close';
import Typography from "../../build/Typography";
import PortalWrapper from "../../build/Providers/common/components/PortalWrapper";
import throttle from "../../build/Providers/common/utilities/throttle";
import { useKeyboardControl } from "../../build/Providers/common/hooks";
import Ripple from "../../build/Providers/common/components/Ripple";
import hasPosition from "../../build/Providers/common/functions/hasPosition";
import getViewport from "../../build/Providers/common/functions/getViewport";
import { canUseDOM } from "../../build/Providers/common/functions";
import { Wrapper, Box, AnimateZoom } from "./style";
var COACHMARK_SPACING = 16;
var ARROW_WIDTH = 28;
var COACHMARK_MARGIN = 8;
var LANG_COPY = {
  id: 'Tutup',
  en: 'Close'
};

var CoachmarkSimple = function CoachmarkSimple(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$container = _ref.container,
      container = _ref$container === void 0 ? 'body' : _ref$container,
      description = _ref.description,
      footer = _ref.footer,
      hiddenTimeout = _ref.hiddenTimeout,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      offsets = _ref.offsets,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? 'bottom' : _ref$placement,
      _ref$show = _ref.show,
      show = _ref$show === void 0 ? false : _ref$show,
      selector = _ref.selector,
      title = _ref.title,
      timeout = _ref.timeout,
      coachmarkWidth = _ref.width,
      _ref$zIndex = _ref.zIndex,
      zIndex = _ref$zIndex === void 0 ? 60 : _ref$zIndex,
      _ref$onClose = _ref.onClose,
      onClose = _ref$onClose === void 0 ? function () {} : _ref$onClose,
      _ref$onAnimationEnd = _ref.onAnimationEnd,
      onAnimationEnd = _ref$onAnimationEnd === void 0 ? function () {} : _ref$onAnimationEnd,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var wrapperRef = useRef(null);

  var _timeout = useRef(null);

  var _hiddenTimeout = useRef(null);

  var closeRef = useRef(null);

  var CoachmarkArrow = function CoachmarkArrow() {
    return React.createElement("svg", {
      className: "unf-coachmark-v2__arrow",
      width: "28",
      height: "8",
      viewBox: "0 0 28 8",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg"
    }, React.createElement("path", {
      d: "M28 0H0H0.35C3.15 0 5.71667 1.11392 7.46667 2.93671L11.2 6.78481C12.7167 8.40506 15.2833 8.40506 16.8 6.78481L20.5333 2.93671C22.2833 1.11392 24.9667 0 27.65 0H28Z",
      fill: NN900
    }));
  };

  var CoachmarkCloseButton = function CoachmarkCloseButton() {
    return React.createElement(Close, {
      size: 16,
      color: NN0
    });
  };

  var handleMouseDown = function handleMouseDown(e) {
    onClose();

    if (closeRef.current) {
      closeRef.current.trigger(e);
    }
  };

  var _useState = useState(show),
      _useState2 = _slicedToArray(_useState, 2),
      shouldRender = _useState2[0],
      setRender = _useState2[1];

  useEffect(function () {
    if (show) {
      setRender(true);
    }
  }, [show]);

  var handleAnimationEnd = function handleAnimationEnd(e) {
    var _wrapperRef$current;

    if (!show) {
      setRender(false);
    }

    wrapperRef === null || wrapperRef === void 0 ? void 0 : (_wrapperRef$current = wrapperRef.current) === null || _wrapperRef$current === void 0 ? void 0 : _wrapperRef$current.focus();
    onAnimationEnd(e);
  };

  var getWindowDimension = function getWindowDimension() {
    return canUseDOM ? getViewport() : {
      height: 0,
      width: 0
    };
  };

  var _useState3 = useState(getWindowDimension()),
      _useState4 = _slicedToArray(_useState3, 2),
      windowDimension = _useState4[0],
      setWindowDimension = _useState4[1];

  var handleWindowDimension = useCallback(function () {
    setWindowDimension(getWindowDimension());
  }, []);
  useEffect(function () {
    if (canUseDOM) {
      window.addEventListener('resize', handleWindowDimension);
      return function cleanup() {
        window.removeEventListener('resize', handleWindowDimension);
      };
    }

    return undefined;
  }, [handleWindowDimension]);

  var _useState5 = useState(0),
      _useState6 = _slicedToArray(_useState5, 2),
      documentHeight = _useState6[0],
      setDocumentHeight = _useState6[1];

  useEffect(function () {
    if (canUseDOM) {
      var parentElement = document.querySelector(container);
      var elementResizeObserver = new MutationObserver(function () {
        parentElement && setDocumentHeight(parentElement.clientHeight);
      });
      var config = {
        childList: true,
        attributes: true,
        subtree: true
      };
      parentElement && elementResizeObserver.observe(parentElement, config);

      if (!show) {
        elementResizeObserver.disconnect();
      }

      return function () {
        elementResizeObserver.disconnect();
      };
    }

    return undefined;
  }, [show]);

  var _useState7 = useState({
    x: 0,
    y: 0,
    height: 0
  }),
      _useState8 = _slicedToArray(_useState7, 2),
      wrapperPosition = _useState8[0],
      setWrapperPosition = _useState8[1];

  var _useState9 = useState(0),
      _useState10 = _slicedToArray(_useState9, 2),
      arrowPosition = _useState10[0],
      setArrowPosition = _useState10[1];

  var _useState11 = useState(false),
      _useState12 = _slicedToArray(_useState11, 2),
      isFixed = _useState12[0],
      setFixed = _useState12[1];

  var getTargetElementPosition = function getTargetElementPosition(elem, _isFixed) {
    var elemRect = elem.getBoundingClientRect();
    var body = document.body;
    var docEl = document.documentElement;
    var scrollTop = _isFixed ? 0 : window.pageYOffset || docEl.scrollTop || body.scrollTop;
    var scrollLeft = _isFixed ? 0 : window.pageXOffset || docEl.scrollLeft || body.scrollLeft;
    var clientTop = docEl.clientTop || body.clientTop || 0;
    var clientLeft = docEl.clientLeft || body.clientLeft || 0;
    var top = elemRect.top + scrollTop - clientTop;
    var left = elemRect.left + scrollLeft - clientLeft;
    return {
      top: Math.round(top),
      left: Math.round(left),
      height: elemRect.height,
      width: elemRect.width
    };
  };

  var handleCoachmarkPosition = useCallback(function (wrapperEl) {
    if (canUseDOM && show) {
      var target = selector && document.querySelector(selector);

      if (target && wrapperEl) {
        var _wrapperEl$getBoundin2;

        wrapperRef.current = wrapperEl;

        var _wrapperEl$getBoundin = wrapperEl === null || wrapperEl === void 0 ? void 0 : (_wrapperEl$getBoundin2 = wrapperEl.getBoundingClientRect) === null || _wrapperEl$getBoundin2 === void 0 ? void 0 : _wrapperEl$getBoundin2.call(wrapperEl),
            wrapperHeight = _wrapperEl$getBoundin.height,
            wrapperWidth = _wrapperEl$getBoundin.width;

        var wrapperWidthCustom;

        if (coachmarkWidth) {
          wrapperWidthCustom = coachmarkWidth;
        } else {
          wrapperWidthCustom = wrapperWidth;
        }

        var _isFixed = hasPosition(target, 'fixed');

        var _getTargetElementPosi = getTargetElementPosition(target, _isFixed),
            left = _getTargetElementPosi.left,
            top = _getTargetElementPosi.top,
            height = _getTargetElementPosi.height,
            width = _getTargetElementPosi.width;

        var newXpos = left + width / 2 - wrapperWidthCustom / 2;
        var newYPos = placement === 'top' ? top - wrapperHeight - COACHMARK_SPACING : height + top + COACHMARK_SPACING;

        if (newXpos + wrapperWidthCustom >= windowDimension.width) {
          newXpos = windowDimension.width - wrapperWidthCustom;
        } else if (newXpos < 0) {
          newXpos = 0;
        }

        if (offsets) {
          if (offsets.x) {
            newXpos += offsets.x;
          }

          if (offsets.y) {
            newYPos += offsets.y;
          }
        }

        var arrowX = left + (width - ARROW_WIDTH) / 2 - newXpos + (offsets && offsets.arrow ? offsets.arrow : 0) - COACHMARK_MARGIN;
        setWrapperPosition({
          x: newXpos,
          y: newYPos,
          height: wrapperHeight
        });
        setArrowPosition(arrowX);
        setFixed(_isFixed);
      }
    }
  }, [show, selector, windowDimension, placement, coachmarkWidth, offsets, documentHeight]);
  useEffect(function () {
    if (timeout && show) {
      _timeout.current = setTimeout(function () {
        onClose();
      }, timeout);
      return function () {
        _timeout.current && clearTimeout(_timeout.current);
      };
    }

    return undefined;
  }, [timeout, show]);

  var _useState13 = useState(0),
      _useState14 = _slicedToArray(_useState13, 2),
      scrollPosition = _useState14[0],
      setScrollPosition = _useState14[1];

  var _useState15 = useState(false),
      _useState16 = _slicedToArray(_useState15, 2),
      closing = _useState16[0],
      setClosing = _useState16[1];

  var _useState17 = useState(true),
      _useState18 = _slicedToArray(_useState17, 2),
      init = _useState18[0],
      setInit = _useState18[1];

  var handleScrollPosition = throttle(function () {
    var body = document.body;
    var docEl = document.documentElement;
    var scrollTop = window.pageYOffset || docEl.scrollTop || body.scrollTop;
    setScrollPosition(scrollTop);
  }, 150);
  useEffect(function () {
    setInit(false);
  }, []);
  useEffect(function () {
    if (canUseDOM && hiddenTimeout) {
      document.addEventListener('scroll', handleScrollPosition);
      return function () {
        document.removeEventListener('scroll', handleScrollPosition);
      };
    }

    return undefined;
  }, [hiddenTimeout, handleScrollPosition]);
  useEffect(function () {
    if (canUseDOM && hiddenTimeout && !init && !isFixed) {
      var windowHeight = window.innerHeight;
      var aboveWindow = wrapperPosition.y - scrollPosition + wrapperPosition.height < 0;
      var belowWindow = wrapperPosition.y - scrollPosition > windowHeight;
      var shouldClose = aboveWindow || belowWindow;

      if (shouldClose) {
        if (!closing) {
          setClosing(true);
          _hiddenTimeout.current = setTimeout(function () {
            onClose();
          }, hiddenTimeout);
        }
      } else if (closing) {
        setClosing(false);
        _hiddenTimeout.current && clearTimeout(_hiddenTimeout.current);
      }
    }
  }, [hiddenTimeout, scrollPosition, wrapperPosition, closing, init, isFixed]);
  useKeyboardControl({
    Escape: function Escape() {
      onClose();
    }
  });
  return React.createElement(React.Fragment, null, shouldRender && React.createElement(PortalWrapper, {
    portalClassName: "unf-coachmark-v2__portal"
  }, React.createElement(Wrapper, _extends({
    className: cx('unf-coachmark-v2__wrapper', className),
    innerRef: handleCoachmarkPosition,
    isFixed: isFixed,
    zIndex: zIndex,
    width: coachmarkWidth,
    hasFooter: Boolean(footer),
    "data-unify": "CoachmarkV2",
    id: "coachmark",
    role: "alertdialog",
    "aria-labelledby": "unf-coachmark__label",
    "aria-describedby": "unf-coachmark__desc",
    tabIndex: 0
  }, otherProps, wrapperPosition), React.createElement(AnimateZoom, {
    className: "unf-coachmark-v2__animate-wrapper",
    show: show,
    transformOrigin: "".concat(arrowPosition + ARROW_WIDTH / 2, "px ").concat(placement === 'top' ? 'bottom' : 'top'),
    placement: placement,
    onAnimationEnd: handleAnimationEnd
  }, React.createElement(Box, {
    arrowPosition: arrowPosition,
    placement: placement,
    hasFooter: Boolean(footer),
    hasTitle: Boolean(title)
  }, React.createElement(CoachmarkArrow, null), React.createElement("div", {
    className: "unf-coachmark-v2__body"
  }, React.createElement("div", {
    className: "unf-coachmark-v2__content"
  }, title && React.createElement(Typography, {
    className: "unf-coachmark-v2__title",
    main: true,
    tag: 5,
    margin: "0",
    id: "unf-coachmark__label"
  }, title), React.createElement("div", {
    className: "unf-coachmark-v2__desc",
    id: "unf-coachmark__desc"
  }, children || description)), React.createElement("div", null, React.createElement("button", {
    className: "unf-coachmark-v2__close-button",
    onClick: onClose,
    onMouseDown: handleMouseDown,
    "aria-label": LANG_COPY[lang]
  }, React.createElement(Ripple, {
    ref: closeRef,
    color: NN950,
    duration: 200
  }), React.createElement(CoachmarkCloseButton, null)))), footer && React.createElement("div", {
    className: "unf-coachmark-v2__footer"
  }, footer))))));
};

export default CoachmarkSimple;