import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useEffect, useState, useRef } from 'react';
import { NN950 } from 'unify-token/colors';
import Ripple from "../../build/Providers/common/components/Ripple";
import { canUseDOM } from "../../build/Providers/common/functions";
import CoachmarkSimple from "./CoachmarkSimple";
import { CoachmarkFooter } from "./style";
var NEXT = 'NEXT';
var PREV = 'PREV';
var LANG_COPY = {
  en: {
    page: 'of',
    prev: 'Back',
    next: 'Next',
    finish: 'Got It'
  },
  id: {
    page: 'dari',
    prev: 'Balik',
    next: 'Lanjut',
    finish: 'Mengerti'
  }
};

var CoachmarkStep = function CoachmarkStep(_ref) {
  var activeIndex = _ref.activeIndex,
      items = _ref.items,
      lang = _ref.lang,
      show = _ref.show,
      showDelay = _ref.showDelay,
      onChange = _ref.onChange,
      timeout = _ref.timeout,
      hiddenTimeout = _ref.hiddenTimeout,
      onClose = _ref.onClose,
      onFinish = _ref.onFinish;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      transitioning = _useState2[0],
      setTransitioning = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      coachmarkShow = _useState4[0],
      setCoachmarkShow = _useState4[1];

  useEffect(function () {
    if (show) {
      setTimeout(function () {
        setCoachmarkShow(true);
      }, showDelay);
    } else {
      setCoachmarkShow(false);
    }
  }, [show]);
  useEffect(function () {
    if (canUseDOM && items && items[activeIndex] && show) {
      var target = document.querySelector(items[activeIndex].selector);
      target === null || target === void 0 ? void 0 : target.scrollIntoView({
        behavior: 'smooth',
        block: 'center'
      });
    }
  }, [show, activeIndex]);
  var nextRef = useRef(null);
  var prevRef = useRef(null);

  var onPrevMouseDown = function onPrevMouseDown(e) {
    if (prevRef.current) {
      prevRef.current.trigger(e);
    }
  };

  var onNextMouseDown = function onNextMouseDown(e) {
    if (nextRef.current) {
      nextRef.current.trigger(e);
    }
  };

  var handleNext = function handleNext(e) {
    if (activeIndex < items.length - 1) {
      onChange(e, activeIndex + 1, NEXT);
      setTransitioning(true);
    } else {
      onFinish(e);
    }
  };

  var handlePrev = function handlePrev(e) {
    setTransitioning(true);
    onChange(e, activeIndex - 1, PREV);
  };

  var handleClose = function handleClose(e) {
    onClose(e, activeIndex);
  };

  var footerComponent = function footerComponent(index) {
    return React.createElement(CoachmarkFooter, {
      className: "unf-coachmark-steps__footer"
    }, React.createElement("div", {
      className: "unf-coachmark-steps__page-info"
    }, "".concat(index + 1, " ").concat(LANG_COPY[lang].page, " ").concat(items.length)), React.createElement("div", {
      className: "unf-coachmark-steps__navigation"
    }, index !== 0 && React.createElement("button", {
      className: "unf-coachmark-steps__prev",
      onClick: handlePrev,
      onMouseDown: onPrevMouseDown
    }, React.createElement(Ripple, {
      ref: prevRef,
      color: NN950,
      duration: 200
    }), React.createElement("span", null, LANG_COPY[lang].prev)), React.createElement("button", {
      className: "unf-coachmark-steps__next",
      onClick: handleNext,
      onMouseDown: onNextMouseDown
    }, React.createElement(Ripple, {
      ref: nextRef,
      color: NN950,
      duration: 200
    }), React.createElement("span", null, index < items.length - 1 ? LANG_COPY[lang].next : LANG_COPY[lang].finish))));
  };

  return React.createElement(React.Fragment, null, items.map(function (itemProps, i) {
    return React.createElement(CoachmarkSimple, _extends({
      key: "unf-coachmark-step-".concat(i)
    }, itemProps, {
      show: activeIndex === i && coachmarkShow && !transitioning,
      timeout: timeout,
      hiddenTimeout: activeIndex === i ? hiddenTimeout : 0,
      onClose: handleClose,
      footer: footerComponent(i),
      onAnimationEnd: function onAnimationEnd() {
        return setTransitioning(false);
      },
      "data-unify": "CoachmarkV2"
    }));
  }));
};

CoachmarkStep.defaultProps = {
  activeIndex: 0,
  items: [],
  lang: 'id',
  show: false,
  showDelay: 0,
  timeout: 0,
  hiddenTimeout: 0,
  onChange: function onChange() {},
  onClose: function onClose() {},
  onFinish: function onFinish() {}
};
export default CoachmarkStep;