/// <reference types="react" />
declare type CoachmarkSimpleBaseProps = React.ComponentPropsWithoutRef<'div'>;
export interface UnifyCoachmarkSimpleProps {
    /**
     * Specify an added className
     */
    className?: string;
    /**
     * Specify Coachmark content / description
     */
    description?: React.ReactNode;
    /**
     * Specify footer content
     */
    footer?: React.ReactNode;
    /**
     * Specify a timeout (in milisecond) to trigger `onClose` function when the Coachmark is out of viewport
     */
    hiddenTimeout?: number;
    /**
     * To adjust Coachmark `x` & `y` and `arrow` positions, see [offsets properties](#offsets-properties)
     */
    offsets?: {
        x: number;
        y: number;
        arrow: number;
    };
    /**
     * Watch clientHeight element of this selector, default value `body`
     */
    container?: string;
    /**
     * Specify CoachmarkStep language
     */
    lang?: string;
    /**
     * Specify Coachmark placement | value: `oneOf(['top', 'bottom'])`
     */
    placement?: string;
    /**
     * Specify the target element's selector
     */
    selector?: string;
    /**
     * To toggle visibility of coachmark
     */
    show: boolean;
    /**
     * Specify a timeout (in milisecond) to trigger `onClose` function
     */
    timeout?: number;
    /**
     * Specify Coachmark Title
     */
    title?: string;
    /**
     * Specify Coachmark width
     */
    width?: number;
    /**
     * Specify Coachmark z-index
     */
    zIndex?: number;
    /**
     * A function to be called when the `animationend` event is triggered | params: `e`: event
     */
    onAnimationEnd?: (e: React.AnimationEvent<HTMLDivElement>) => void;
    /**
     * A function to be called when the `close` event is triggered
     */
    onClose?: (e?: React.MouseEvent<HTMLButtonElement>) => void;
}
export declare type CoachmarkSimpleProps = UnifyCoachmarkSimpleProps & Omit<CoachmarkSimpleBaseProps, keyof UnifyCoachmarkSimpleProps>;
export interface CoachmarkStepProps {
    /**
     * Indicate the current active coachmark item
     */
    activeIndex: number;
    /**
     * Specify timeout (in milisecond) to trigger `onClose` when the CoachmarkStep is out of viewport
     */
    hiddenTimeout?: number;
    /**
     * Specify CoachmarkStep items
     */
    items: CoachmarkSimpleProps[];
    /**
     * Specify CoachmarkStep language
     */
    lang: string;
    /**
     * To toggle visibility of CoachmarkStep
     */
    show: boolean;
    /**
     * Specify delayed time CoachmarkStep to show (in milisecond)
     */
    showDelay?: number;
    /**
     * Specify the timeout (in milisecond) to trigger `onClose` function
     */
    timeout?: number;
    /**
     * A function to be called when the next / prev button is clicked | params: `e`: event, `nextActiveIndex`: next activeIndex, `direction`: `oneOf(['PREV','NEXT'])`
     */
    onChange: (e?: React.MouseEvent<HTMLButtonElement>, nextActiveIndex?: number, direction?: 'NEXT' | 'PREV') => void;
    /**
     * A function to be called when the `close` event is triggered | params: `e`: event, `nextActiveIndex`: next activeIndex
     */
    onClose: (e?: React.MouseEvent<HTMLButtonElement>, nextActiveIndex?: number) => void;
    /**
     * A function to be called when the finish button is clicked | params: `e`: event
     */
    onFinish: (e?: React.MouseEvent<HTMLButtonElement>) => void;
}
export interface AnimateZoomProps {
    transformOrigin: string;
    show: boolean;
    placement: string;
}
export interface WrapperProps {
    isFixed: boolean;
    hasFooter: boolean;
    zIndex: number;
    x: number;
    y: number;
    width?: number;
}
export interface BoxProps extends Partial<WrapperProps> {
    placement: string;
    arrowPosition: number;
    hasTitle: boolean;
}
export {};
