import _typeof from "@babel/runtime/helpers/typeof";
import React from 'react';
import { cx } from 'emotion';
import { datepicker, DateSection, DateSectionWrapper, DateSectionNumber, DateSectionText } from "./_DatepickerCalendarStyle";

var DatepickerWeekDate = function DatepickerWeekDate(_ref) {
  var alternateDate = _ref.alternateDate,
      _ref$currentMonth = _ref.currentMonth,
      currentMonth = _ref$currentMonth === void 0 ? 0 : _ref$currentMonth,
      currentYear = _ref.currentYear,
      disabledDate = _ref.disabledDate,
      enabledDate = _ref.enabledDate,
      _ref$firstDate = _ref.firstDate,
      firstDate = _ref$firstDate === void 0 ? new Date() : _ref$firstDate,
      infoDate = _ref.infoDate,
      maxDate = _ref.maxDate,
      minDate = _ref.minDate,
      onClick = _ref.onClick,
      price = _ref.price,
      secondDate = _ref.secondDate,
      showPrice = _ref.showPrice;

  var getDate = function getDate(day) {
    return new Date(currentYear, currentMonth, day);
  };

  var checkSpecialDate = function checkSpecialDate(typeDate, date) {
    for (var x = 0; x < typeDate.length; x++) {
      if (typeDate[parseInt(x)].specialDate) {
        if (typeDate[parseInt(x)].date.getDate() === date.getDate() && typeDate[parseInt(x)].date.getMonth() === date.getMonth() && typeDate[parseInt(x)].date.getFullYear() === date.getFullYear()) {
          return true;
        }
      } else {
        if (typeDate[parseInt(x)].date.getDate() === date.getDate()) {
          return true;
        }
      }
    }
  };

  var checkTextObj = function checkTextObj(day, hasColor) {
    var date = getDate(day);
    if (!price) return;

    for (var x = 0; x < price.length; x++) {
      var infoVal = parseInt([price[parseInt(x)].date.getFullYear(), price[parseInt(x)].date.getMonth(), price[parseInt(x)].date.getDate()].join(''));
      var checkVal = parseInt([date.getFullYear(), date.getMonth(), date.getDate()].join(''));

      if (infoVal === checkVal) {
        if (hasColor) {
          return price[parseInt(x)].textColor;
        } else {
          return price[parseInt(x)].price;
        }
      }
    }
  };

  var isHoliday = function isHoliday(day) {
    var date = getDate(day);
    return checkSpecialDate(infoDate, date);
  };

  var isEnabled = function isEnabled(day) {
    var date = getDate(day);
    return checkSpecialDate(enabledDate, date);
  };

  var isDisabled = function isDisabled(day) {
    var date = getDate(day);
    return checkSpecialDate(disabledDate, date);
  };

  var isAlternate = function isAlternate(day) {
    var date = getDate(day);
    return checkSpecialDate(alternateDate, date);
  };

  var isTextColor = function isTextColor(day) {
    return checkTextObj(day, true);
  };

  var isTextExist = function isTextExist(day) {
    return checkTextObj(day);
  };

  var handleClick = function handleClick(day, disabled) {
    return function () {
      !disabled && onClick(day);
    };
  };

  var renderGrid = function renderGrid() {
    if (!currentYear) return;
    var firstDay = new Date(currentYear, currentMonth, 0).getDay();
    var daysInMonths = [31, currentYear % 4 === 0 && currentYear % 100 !== 0 || currentYear % 400 === 0 ? 29 : 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
    var monthLength = daysInMonths[parseInt(currentMonth)];
    var firstDateTime = firstDate ? firstDate.getTime() : null;
    var secondDateTime = secondDate ? secondDate.getTime() : null;
    var firstDateDay = firstDate ? firstDate.getDate() : null;
    var secondDateDay = secondDate ? secondDate.getDate() : null;
    var firstDateMonth = firstDate ? firstDate.getMonth() : null;
    var secondDateMonth = secondDate ? secondDate.getMonth() : null;
    var firstDateYear = firstDate ? firstDate.getFullYear() : null;
    var secondDateYear = secondDate ? secondDate.getFullYear() : null;
    var tableBodyHtml = [];
    var day = 1;

    for (var i = 0; i < 6; i++) {
      for (var j = 0; j <= 6; j++) {
        if (day <= monthLength && (i > 0 || j >= firstDay)) {
          var date = new Date(currentYear, currentMonth, day);
          var blockDisabled = minDate && maxDate && (date < minDate || date > maxDate || isDisabled(day));
          var dateClass = cx('date', {
            alternate: isAlternate(day),
            holiday: j === 6 || isHoliday(day),
            today: date.getDate() === new Date().getDate() && date.getMonth() === new Date().getMonth() && currentYear === new Date().getFullYear(),
            active: date.getDate() === firstDateDay && date.getMonth() === firstDateMonth && currentYear === firstDateYear || date.getDate() === secondDateDay && date.getMonth() === secondDateMonth && currentYear === secondDateYear,
            selected: date > firstDate && date < secondDate,
            disabled: date < minDate || date > maxDate || isDisabled(day) || (enabledDate === null || enabledDate === void 0 ? void 0 : enabledDate.length) > 0 && _typeof(enabledDate) === 'object' && !isEnabled(day),
            startDate: firstDateTime !== secondDateTime ? firstDate && secondDate && date.getDate() === firstDateDay && date.getMonth() === firstDateMonth && currentYear === firstDateYear : false,
            endDate: firstDate && secondDate && date.getTime() === secondDateTime,
            sameDate: secondDate && date.getTime() === secondDateTime && date.getTime() === firstDateTime
          });
          tableBodyHtml.push(React.createElement(DateSection, {
            role: "presentation",
            className: dateClass,
            onClick: handleClick(date, blockDisabled),
            key: "".concat(i, "-").concat(j)
          }, React.createElement(DateSectionWrapper, null, React.createElement(DateSectionNumber, {
            className: "date__number"
          }, day), showPrice && React.createElement(DateSectionText, {
            hasColor: isTextColor(day),
            className: "date__text"
          }, isTextExist(day)))));
          day++;
        } else {
          tableBodyHtml.push(React.createElement(DateSection, {
            className: "date",
            key: "".concat(i, "-").concat(j)
          }));
        }
      }

      if (day > monthLength) {
        break;
      }
    }

    return tableBodyHtml;
  };

  return React.createElement("div", {
    className: "".concat(datepicker, "-date")
  }, renderGrid());
};

export default DatepickerWeekDate;