import React, { ComponentPropsWithoutRef } from 'react';
declare type DatepickerCalendarAttributes = ComponentPropsWithoutRef<'div'>;
interface DateField {
    /**
     * Date to be applied The date in every month will be applied by default
     */
    date: Date;
}
interface SpecialDateField {
    /**
     * Set this to true to specifically apply style to the specified date
     * @default false
     */
    specialDate?: boolean;
}
interface InfoDateObject extends SpecialDateField, DateField {
    /**
     * Info text
     */
    text: string;
}
interface PriceDateObject extends DateField {
    /**
     * Price label
     */
    price: number;
    /**
     * To apply custom color on the text
     * @default rgba(49,53,59,0.44)
     */
    textColor?: string;
}
interface AlternateDateObject extends DateField, SpecialDateField {
}
interface DisabledDateObject extends DateField, SpecialDateField {
}
interface EnabledDateObject extends DateField, SpecialDateField {
}
export interface CalendarInfoProps {
    currentMonth?: number;
    currentYear?: number;
    /**
     * To determine custom info by passing Date object
     */
    infoDate?: InfoDateObject[];
    monthsLabel?: string[];
}
export interface DayProps {
    dayLabel: string[];
}
export interface DateProps extends Pick<CalendarInfoProps, 'currentMonth' | 'currentYear' | 'infoDate'> {
    hasColor?: string;
    /**
     * To determine selected alternate date by passing Date object
     */
    alternateDate?: AlternateDateObject[];
    /**
     * To determine custom price by passing Date object
     */
    price?: PriceDateObject[];
    /**
     * To toggle price toolbar
     */
    showPrice?: boolean;
    /**
     * To determine disabled date by passing Date object
     */
    disabledDate?: DisabledDateObject[];
    /**
     * To determine enable date by passing Date object
     */
    enabledDate?: EnabledDateObject[];
    /**
     * To determine selected first date by passing Date object
     */
    firstDate?: Date | null;
    /**
     * To specify maximum range of date displayed
     */
    maxDate?: Date;
    /**
     * To specify minimum range of date displayed
     */
    minDate?: Date;
    /**
     * To determine selected second date by passing date object
     */
    secondDate?: Date | null;
    /**
     * To pass callback when selecting date
     */
    onClick?: (data: Date) => void;
}
export interface MonthProps extends Pick<DayProps, 'dayLabel'>, Pick<CalendarInfoProps, 'monthsLabel' | 'currentMonth' | 'infoDate' | 'currentYear'>, Pick<DateProps, 'alternateDate' | 'firstDate' | 'disabledDate' | 'enabledDate' | 'maxDate' | 'minDate' | 'price' | 'secondDate' | 'showPrice' | 'onClick'> {
    yearLabel?: any;
    /**
     * To pass custom props to nav button next
     */
    buttonNextProps?: object;
    /**
     * To pass custom props to nav button prev
     */
    buttonPrevProps?: object;
}
export interface PanelRangeProps extends Pick<DateProps, 'firstDate' | 'secondDate'> {
    isFocus?: boolean;
    dayLabel: Date;
    display?: boolean;
    /**
     * To specify language of Datepicker
     */
    lang?: string;
    monthLabel: Date;
    /**
     * To specify string in label first date panel range
     */
    titleFirstDate?: string;
    /**
     * To specify string in label second date panel range
     */
    titleSecondDate?: string;
}
export interface PanelInfoProps extends Pick<PanelRangeProps, 'lang'> {
    /**
     * To specify string in legend panelInfo for alternate legend
     */
    alternateTitle?: string;
    /**
     * To specify string in panelInfo for your message info
     */
    messageInfo?: React.ReactNode;
}
export interface CalendarProps extends Omit<DatepickerCalendarAttributes, 'css' | 'onClick'>, Pick<PanelRangeProps, 'titleFirstDate' | 'titleSecondDate' | 'display'>, Pick<PanelInfoProps, 'alternateTitle' | 'lang' | 'messageInfo'>, Pick<MonthProps, 'alternateDate' | 'firstDate' | 'disabledDate' | 'enabledDate' | 'maxDate' | 'minDate' | 'price' | 'secondDate' | 'showPrice' | 'infoDate' | 'onClick'> {
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     * To toggle visibility of info panel
     */
    panelInfo?: boolean;
    /**
     * To toggle visibility of range date panel
     */
    panelRange?: boolean;
    /**
     * To toggle price below each dates ( must be used with price props )
     */
    showPriceToggle?: boolean;
    /**
     * To specify string next to price toggle button
     */
    titlePriceToggle?: string;
    /**
     * To pass callback when selecting second date
     */
    onClickDouble?: (data: Date) => void | React.MouseEventHandler<HTMLDivElement> | null;
}
export {};
