import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useRef, useEffect, useCallback, Fragment } from 'react';
import { noop } from "../../../build/Providers/common/functions/noop";
import ScrollContainer from "./_ScrollContainer";
import { DISABLED_PAD_AMOUNT, fullMonthList, generateYears, disableArrayValues, formatDate, defaultInitialDate, defaultMaxDate, defaultMinDate } from "./utility";

var DatepickerScrollDefault = function DatepickerScrollDefault(_ref) {
  var _ref$format = _ref.format,
      format = _ref$format === void 0 ? 'd-MMMM-yyyy' : _ref$format,
      _ref$initialDate = _ref.initialDate,
      initialDate = _ref$initialDate === void 0 ? defaultInitialDate : _ref$initialDate,
      _ref$maxDate = _ref.maxDate,
      maxDate = _ref$maxDate === void 0 ? defaultMaxDate : _ref$maxDate,
      _ref$minDate = _ref.minDate,
      minDate = _ref$minDate === void 0 ? defaultMinDate : _ref$minDate,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      _ref$setValue = _ref.setValue,
      setValue = _ref$setValue === void 0 ? noop : _ref$setValue,
      _ref$onChangeDate = _ref.onChangeDate,
      onChangeDate = _ref$onChangeDate === void 0 ? noop : _ref$onChangeDate,
      _ref$onChangeMonth = _ref.onChangeMonth,
      onChangeMonth = _ref$onChangeMonth === void 0 ? noop : _ref$onChangeMonth,
      _ref$onChangeYear = _ref.onChangeYear,
      onChangeYear = _ref$onChangeYear === void 0 ? noop : _ref$onChangeYear;

  var _React$useState = React.useState({}),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      updateState = _React$useState2[1];

  var forceUpdate = useCallback(function () {
    return updateState({});
  }, []);

  var _formatDate = formatDate(format),
      dateFormat = _formatDate.dateFormat,
      order = _formatDate.order;

  var dateRef = useRef(initialDate.getDate());
  var monthRef = useRef(initialDate.getMonth());
  var yearRef = useRef(initialDate.getFullYear());

  var _useState = useState(maxDate),
      _useState2 = _slicedToArray(_useState, 2),
      _maxFDate = _useState2[0],
      _setMaxFDate = _useState2[1];

  var _useState3 = useState(minDate),
      _useState4 = _slicedToArray(_useState3, 2),
      _minFDate = _useState4[0],
      _setMinFDate = _useState4[1];

  var _maxDate = _maxFDate.getDate();

  var _maxMonth = _maxFDate.getMonth();

  var _maxYear = _maxFDate.getFullYear();

  var _minDate = _minFDate.getDate();

  var _minMonth = _minFDate.getMonth();

  var _minYear = _minFDate.getFullYear();

  useEffect(function () {
    dateRef.current = initialDate.getDate();
    monthRef.current = initialDate.getMonth();
    yearRef.current = initialDate.getFullYear();
    forceUpdate();
  }, [forceUpdate, initialDate]);
  useEffect(function () {
    _setMaxFDate(maxDate);
  }, [maxDate]);
  useEffect(function () {
    _setMinFDate(minDate);
  }, [minDate]);

  var generateDates = function generateDates(format) {
    var resultArr = [];

    for (var i = 0; i < new Date(yearRef.current, monthRef.current + 1, 0).getDate() + 1; i++) {
      var text = "".concat(i);

      if (format === 'dd') {
        text = text.length === 1 ? "0".concat(text) : text;
      }

      resultArr[Number(i)] = {
        text: text,
        value: Number(i)
      };
    }

    var monthCheck = monthRef.current === _maxMonth && monthRef.current === _minMonth;
    var yearCheck = yearRef.current === _maxYear && yearRef.current === _minYear;

    if (monthCheck && yearCheck) {
      disableArrayValues(resultArr, _minDate, _maxDate);
    } else if (monthRef.current === _maxMonth && yearRef.current === _maxYear) {
      disableArrayValues(resultArr, 0, _maxDate);
    } else if (monthRef.current === _minMonth && yearRef.current === _minYear) {
      disableArrayValues(resultArr, _minDate, resultArr.length);
    }

    resultArr.shift();
    return resultArr;
  };

  var generateMonths = function generateMonths(format) {
    var monthArr = fullMonthList["".concat(lang)];
    var arr = [];

    for (var i in monthArr) {
      var text = '';

      switch (format) {
        case 'M':
          text = "".concat(parseInt(i) + 1);
          break;

        case 'MM':
          text = "".concat(parseInt(i) + 1);
          text = text.length === 1 ? "0".concat(text) : text;
          break;

        case 'MMM':
          text = monthArr[parseInt(i)].substring(0, 3);
          break;

        default:
          text = monthArr[parseInt(i)];
      }

      arr[parseInt(i)] = {
        text: text,
        value: parseInt(i)
      };
    }

    if (yearRef.current === _maxYear && yearRef.current === _minYear) {
      disableArrayValues(arr, _minMonth, _maxMonth);
    } else if (yearRef.current === _maxYear) {
      disableArrayValues(arr, 0, _maxMonth);
    } else if (yearRef.current === _minYear) {
      disableArrayValues(arr, _minMonth, monthArr.length);
    }

    return arr;
  };

  var yearData = generateYears(_minYear, _maxYear);
  var monthData = generateMonths(dateFormat.month);
  var dateData = generateDates(dateFormat.date);

  var onSwitchDate = function onSwitchDate(val) {
    if (val && typeof val.value === 'number') {
      var dateVal = val.value;
      onChangeDate(val.text, dateVal);
      dateRef.current = dateVal;
      setValue(new Date(yearRef.current, monthRef.current, dateVal));
      forceUpdate();
    }
  };

  var onSwitchMonth = function onSwitchMonth(val) {
    if (val && typeof val.value === 'number') {
      var monthVal = val.value;
      onChangeMonth(val.text, monthVal);
      monthRef.current = monthVal;
      setValue(new Date(yearRef.current, monthVal, dateRef.current));
      forceUpdate();
    }
  };

  var onSwitchYear = function onSwitchYear(val) {
    if (val && typeof val.value === 'number') {
      var yearVal = val.value;
      onChangeYear(val.text, yearVal);
      yearRef.current = yearVal;
      setValue(new Date(yearVal, monthRef.current, dateRef.current));
      forceUpdate();
    }
  };

  var generateScrollContainer = function generateScrollContainer(o, width) {
    if (o === 'd') {
      return React.createElement(ScrollContainer, {
        "aria-label": "Date List",
        "aria-valuenow": dateRef.current,
        data: dateData,
        initialIndex: initialDate.getDate() - 1,
        onChangeValue: onSwitchDate,
        width: width,
        key: o
      });
    } else if (o === 'M') {
      return React.createElement(ScrollContainer, {
        "aria-label": "Month List",
        "aria-valuenow": monthRef.current,
        data: monthData,
        initialIndex: initialDate.getMonth(),
        onChangeValue: onSwitchMonth,
        width: width,
        key: o
      });
    } else if (o === 'y') {
      return React.createElement(ScrollContainer, {
        "aria-label": "Year List",
        "aria-valuenow": yearRef.current,
        data: yearData,
        initialIndex: DISABLED_PAD_AMOUNT + initialDate.getFullYear() - minDate.getFullYear(),
        onChangeValue: onSwitchYear,
        width: width,
        key: o
      });
    }

    return null;
  };

  return React.createElement(Fragment, null, order.map(function (o) {
    return generateScrollContainer(o, 100 / order.length);
  }));
};

export default DatepickerScrollDefault;