import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useRef, useEffect, useCallback, Fragment } from 'react';
import { noop } from "../../../build/Providers/common/functions/noop";
import ScrollContainer from "./_ScrollContainer";
import { datepicker_time_colon } from "./_DatepickerScrollStyle";
import { monthList, dayList, disableArrayValues, DISABLED_PAD_AMOUNT, MS_TO_DAY_DIVIDER, defaultInitialDate, defaultMaxDate, defaultMinDate } from "./utility";

var DatepickerScrollTime = function DatepickerScrollTime(_ref) {
  var _ref$initialDate = _ref.initialDate,
      initialDate = _ref$initialDate === void 0 ? defaultInitialDate : _ref$initialDate,
      _ref$maxDate = _ref.maxDate,
      maxDate = _ref$maxDate === void 0 ? defaultMaxDate : _ref$maxDate,
      _ref$minDate = _ref.minDate,
      minDate = _ref$minDate === void 0 ? defaultMinDate : _ref$minDate,
      maxTime = _ref.maxTime,
      minTime = _ref.minTime,
      _ref$minuteInterval = _ref.minuteInterval,
      minuteInterval = _ref$minuteInterval === void 0 ? 1 : _ref$minuteInterval,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'datetime' : _ref$type,
      _ref$setValue = _ref.setValue,
      setValue = _ref$setValue === void 0 ? noop : _ref$setValue,
      _ref$onChangeDate = _ref.onChangeDate,
      onChangeDate = _ref$onChangeDate === void 0 ? noop : _ref$onChangeDate,
      _ref$onChangeHour = _ref.onChangeHour,
      onChangeHour = _ref$onChangeHour === void 0 ? noop : _ref$onChangeHour,
      _ref$onChangeMinute = _ref.onChangeMinute,
      onChangeMinute = _ref$onChangeMinute === void 0 ? noop : _ref$onChangeMinute;

  var _useState = useState({}),
      _useState2 = _slicedToArray(_useState, 2),
      updateState = _useState2[1];

  var forceUpdate = useCallback(function () {
    return updateState({});
  }, []);
  var dateRef = useRef(new Date(initialDate.getFullYear(), initialDate.getMonth(), initialDate.getDate()));
  var hourRef = useRef(initialDate.getHours());
  var minuteRef = useRef(initialDate.getMinutes());

  var _useState3 = useState(maxDate),
      _useState4 = _slicedToArray(_useState3, 2),
      _maxFDate = _useState4[0],
      _setMaxFDate = _useState4[1];

  var _useState5 = useState(minDate),
      _useState6 = _slicedToArray(_useState5, 2),
      _minFDate = _useState6[0],
      _setMinFDate = _useState6[1];

  var _maxDate = new Date(_maxFDate.getFullYear(), _maxFDate.getMonth(), _maxFDate.getDate());

  var _maxHour = _maxFDate.getHours();

  var _maxMinute = _maxFDate.getMinutes();

  var _minDate = new Date(_minFDate.getFullYear(), _minFDate.getMonth(), _minFDate.getDate());

  var _minHour = _minFDate.getHours();

  var _minMinute = _minFDate.getMinutes();

  useEffect(function () {
    _setMaxFDate(maxDate);
  }, [maxDate]);
  useEffect(function () {
    _setMinFDate(minDate);
  }, [minDate]);

  var formatDate = function formatDate(dateObj) {
    return "".concat(dayList["".concat(lang)][dateObj.getDay()], ", ").concat(dateObj.getDate(), " ").concat(monthList["".concat(lang)][dateObj.getMonth()], " ").concat(dateObj.getFullYear());
  };

  var generateDates = function generateDates() {
    var i = new Date(minDate.getFullYear(), minDate.getMonth(), minDate.getDate());
    i.setDate(i.getDate() - DISABLED_PAD_AMOUNT);
    var arr = [];

    for (var x = 0; x < DISABLED_PAD_AMOUNT; ++x) {
      arr.push({
        text: formatDate(i),
        value: new Date(i),
        disabled: true
      });
      i.setDate(i.getDate() + 1);
    }

    while (i.getTime() < maxDate.getTime()) {
      if (i.toDateString() === new Date().toDateString()) {
        arr.push({
          text: lang === 'en' ? 'Today' : 'Hari ini',
          value: new Date(i)
        });
      } else {
        arr.push({
          text: formatDate(i),
          value: new Date(i)
        });
      }

      i.setDate(i.getDate() + 1);
    }

    for (var _x = 0; _x < DISABLED_PAD_AMOUNT; ++_x) {
      arr.push({
        text: formatDate(i),
        value: new Date(i),
        disabled: true
      });
      i.setDate(i.getDate() + 1);
    }

    return arr;
  };

  var generateHours = function generateHours() {
    var arr = [];

    for (var x = 0; x < 24; ++x) {
      var temp = "".concat(x);

      if (x < 10) {
        temp = "0".concat(temp);
      }

      arr[Number(x)] = {
        text: temp,
        value: x
      };
    }

    if (minTime && maxTime) {
      disableArrayValues(arr, minTime.getHours(), maxTime.getHours());
    } else if (dateRef.current.getTime() === _maxDate.getTime() && dateRef.current.getTime() === _minDate.getTime()) {
      disableArrayValues(arr, _minHour, _maxHour);
    } else if (dateRef.current.getTime() === _maxDate.getTime()) {
      disableArrayValues(arr, 0, _maxHour);
    } else if (dateRef.current.getTime() === _minDate.getTime()) {
      disableArrayValues(arr, _minHour, 24);
    }

    return arr;
  };

  var generateMinutes = function generateMinutes() {
    var arr = [];

    for (var x = 0; x < 60 / minuteInterval; ++x) {
      var minuteVal = x * minuteInterval;
      var temp = "".concat(minuteVal);

      if (minuteVal < 10) {
        temp = "0".concat(temp);
      }

      arr[Number(x)] = {
        text: temp,
        value: minuteVal
      };
    }

    if (minTime && maxTime) {
      var _maxAvailableHour = maxTime.getHours();

      var _maxAvailableMinute = maxTime.getMinutes();

      var _minAvailableHour = minTime.getHours();

      var _minAvailableMinute = minTime.getMinutes();

      var hourCheck = hourRef.current === _maxAvailableHour && hourRef.current === _minAvailableHour;

      if (hourCheck) {
        disableArrayValues(arr, _minAvailableMinute, _maxAvailableMinute);
      } else if (hourRef.current === _maxAvailableHour) {
        disableArrayValues(arr, 0, _maxAvailableMinute);
      } else if (hourRef.current === _minAvailableHour) {
        disableArrayValues(arr, _minAvailableMinute, 60);
      }
    } else {
      var dateCheck = dateRef.current.getTime() === _maxDate.getTime() && dateRef.current.getTime() === _minDate.getTime();

      var _hourCheck = hourRef.current === _maxHour && hourRef.current === _minHour;

      if (_hourCheck && dateCheck) {
        disableArrayValues(arr, _minMinute, _maxMinute);
      } else if (hourRef.current === _maxHour && dateRef.current.getTime() === _maxDate.getTime()) {
        disableArrayValues(arr, 0, _maxMinute);
      } else if (hourRef.current === _minHour && dateRef.current.getTime() === _minDate.getTime()) {
        disableArrayValues(arr, _minMinute, 60);
      }
    }

    return arr;
  };

  var dateData = generateDates();
  var hourData = generateHours();
  var minuteData = generateMinutes();

  var onSwitchDate = function onSwitchDate(val) {
    if (val && val.value instanceof Date) {
      var dateVal = val.value;
      onChangeDate(val.text, dateVal);
      dateRef.current = dateVal;
      var newVal = new Date(dateVal);
      newVal.setHours(hourRef.current);
      newVal.setMinutes(minuteRef.current);
      setValue(newVal);
      forceUpdate();
    }
  };

  var onSwitchHour = function onSwitchHour(val) {
    if (val && typeof val.value === 'number') {
      var hourVal = val.value;
      onChangeHour(val.text, hourVal);
      hourRef.current = hourVal;
      var newVal = new Date(dateRef.current);
      newVal.setHours(hourVal);
      newVal.setMinutes(minuteRef.current);
      setValue(newVal);
      forceUpdate();
    }
  };

  var onSwitchMinute = function onSwitchMinute(val) {
    if (val && typeof val.value === 'number') {
      var minuteVal = val.value;
      onChangeMinute(val.text, minuteVal);
      minuteRef.current = minuteVal;
      var newVal = new Date(dateRef.current);
      newVal.setHours(hourRef.current);
      newVal.setMinutes(minuteVal);
      setValue(newVal);
      forceUpdate();
    }
  };

  return React.createElement(Fragment, null, type === 'datetime' && React.createElement(ScrollContainer, {
    "aria-label": "Date List",
    "aria-valuenow": dateRef.current,
    width: 50,
    id: "date",
    data: dateData,
    textAlign: "right",
    initialIndex: DISABLED_PAD_AMOUNT + Math.floor(Math.abs(new Date(initialDate.getFullYear(), initialDate.getMonth(), initialDate.getDate()).valueOf() - _minDate.valueOf()) / MS_TO_DAY_DIVIDER),
    onChangeValue: onSwitchDate
  }), React.createElement(ScrollContainer, {
    "aria-label": "Hour List",
    "aria-valuenow": hourRef.current,
    width: type === 'datetime' ? 25 : 35,
    id: "hour",
    data: hourData,
    initialIndex: initialDate.getHours(),
    onChangeValue: onSwitchHour
  }), React.createElement("span", {
    className: datepicker_time_colon
  }, ":"), React.createElement(ScrollContainer, {
    "aria-label": "Minute List",
    "aria-valuenow": minuteRef.current,
    width: type === 'datetime' ? 25 : 35,
    id: "minute",
    data: minuteData,
    initialIndex: Math.ceil(initialDate.getMinutes() / minuteInterval),
    onChangeValue: onSwitchMinute
  }));
};

export default DatepickerScrollTime;