import _extends from "@babel/runtime/helpers/extends";
import _typeof from "@babel/runtime/helpers/typeof";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["data", "initialIndex", "textAlign", "width", "onChangeValue"];
import React, { useState, useRef, useEffect, useCallback, Fragment } from 'react';
import { noop } from "../../../build/Providers/common/functions/noop";
import { scroll_container_row, datepicker_scroll_scroll_container } from "./_DatepickerScrollStyle";
import { ROW_HEIGHT, CONTAINER_HEIGHT, ACCELERATION_COEFF, FRICTION_COEFF, MIN_ABS_VELOCITY, RENDER_INTERVAL, LIST_SIZE_CONSTANT, Y_ORIGIN } from "./utility";

var ScrollContainer = function ScrollContainer(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === void 0 ? [] : _ref$data,
      _ref$initialIndex = _ref.initialIndex,
      initialIndex = _ref$initialIndex === void 0 ? 0 : _ref$initialIndex,
      textAlign = _ref.textAlign,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? 33 : _ref$width,
      _ref$onChangeValue = _ref.onChangeValue,
      onChangeValue = _ref$onChangeValue === void 0 ? noop : _ref$onChangeValue,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(initialIndex),
      _useState2 = _slicedToArray(_useState, 2),
      _activeIndex = _useState2[0],
      setActiveIndex = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      offset = _useState4[0],
      setOffset = _useState4[1];

  var _useState5 = useState(Y_ORIGIN),
      _useState6 = _slicedToArray(_useState5, 2),
      yTranslate = _useState6[0],
      setYTranslate = _useState6[1];

  var containerRef = useRef(null);
  var intervalRef = useRef();
  var ariaLabelRef = useRef(null);
  var y1Ref = useRef(0);
  var y2Ref = useRef(0);
  var t1Ref = useRef(0);
  var t2Ref = useRef(0);
  var offsetRef = useRef(0);
  var velocityRef = useRef(0);
  var tempActiveIndexRef = useRef(_activeIndex);
  var isScrollingRef = useRef(false);
  var isDraggingRef = useRef(false);
  var prevInitialIndexRef = useRef(initialIndex);
  useEffect(function () {
    prevInitialIndexRef.current = initialIndex;
  }, [initialIndex]);
  var prevInitialIndex = prevInitialIndexRef.current;
  var normalizeIndex = useCallback(function (index) {
    if (index < 0) {
      index = (index % data.length + data.length) % data.length;
    } else if (index >= data.length) {
      index %= data.length;
    }

    return index;
  }, [data.length]);
  var isDataDisabledAt = useCallback(function (index) {
    return _typeof(data[Number(index)]) === 'object' && data[Number(index)].disabled;
  }, [data]);
  var firstAvailableIndex = useCallback(function () {
    for (var i in data) {
      if (!isDataDisabledAt(i)) {
        return parseInt(i);
      }
    }

    return 0;
  }, [data, isDataDisabledAt]);
  var lastAvailableIndex = useCallback(function () {
    for (var i = 1; i <= data.length; ++i) {
      var index = normalizeIndex(-i);

      if (!isDataDisabledAt(index)) {
        return Number(index);
      }
    }

    return 0;
  }, [data, isDataDisabledAt, normalizeIndex]);
  var stopScroll = useCallback(function () {
    isScrollingRef.current = false;
    setActiveIndex(function (lastActiveIndex) {
      if (!isDataDisabledAt(lastActiveIndex)) {
        var newValue = data["".concat(lastActiveIndex)];

        if (lastActiveIndex !== tempActiveIndexRef.current) {
          onChangeValue(newValue, lastActiveIndex);
        }

        tempActiveIndexRef.current = lastActiveIndex;
        return lastActiveIndex;
      } else {
        return tempActiveIndexRef.current;
      }
    });
    setYTranslate(Y_ORIGIN);
    setOffset(0);
    offsetRef.current = 0;
  }, [data, isDataDisabledAt, onChangeValue]);
  useEffect(function () {
    return function () {
      intervalRef.current && clearInterval(intervalRef.current);
    };
  }, []);

  var handleTouchStart = function handleTouchStart(e) {
    intervalRef.current && clearInterval(intervalRef.current);
    y1Ref.current = 'touches' in e ? e.touches[0].clientY : e.clientY;
    t1Ref.current = e.timeStamp;
    isScrollingRef.current = true;
    isDraggingRef.current = true;
  };

  var handleTouchMove = useCallback(function (e) {
    if (isDraggingRef.current) {
      y2Ref.current = e.touches ? e.touches[0].clientY : e.clientY;
      t2Ref.current = e.timeStamp;
      var yDiff = y2Ref.current - y1Ref.current;
      setYTranslate(function (prevY) {
        var newY = prevY + yDiff;
        var newOffset = getOffsetFromYTranslate(newY);

        if (newOffset !== offsetRef.current) {
          if ((data.length === 2 || data.length === 3) && (tempActiveIndexRef.current + newOffset >= data.length || tempActiveIndexRef.current + newOffset < 0)) {
            return prevY;
          } else {
            setOffset(newOffset);
            offsetRef.current = newOffset;
            setActiveIndex(function () {
              return normalizeIndex(tempActiveIndexRef.current + newOffset);
            });
          }
        }

        return newY;
      });

      if (t2Ref.current !== t1Ref.current) {
        var inertialVelocity = yDiff / ((t2Ref.current - t1Ref.current) / 1000) * ACCELERATION_COEFF;
        velocityRef.current = inertialVelocity;
        y1Ref.current = y2Ref.current;
        t1Ref.current = t2Ref.current;
      }
    }
  }, [data.length, normalizeIndex]);
  var handleTouchEnd = useCallback(function (e) {
    if ((e.timeStamp - t2Ref.current) / 1000 <= 100 && Math.abs(velocityRef.current) > MIN_ABS_VELOCITY) {
      var momentumScroll = function momentumScroll() {
        intervalRef.current = setInterval(function () {
          if (Math.abs(velocityRef.current) <= MIN_ABS_VELOCITY) {
            stopScroll();
            intervalRef.current && clearInterval(intervalRef.current);
          } else {
            setYTranslate(function (prevY) {
              var newY = prevY + velocityRef.current * 0.9 * RENDER_INTERVAL / 1000;
              var newOffset = getOffsetFromYTranslate(newY);

              if (newOffset !== offsetRef.current) {
                setOffset(newOffset);
                offsetRef.current = newOffset;
                setActiveIndex(function () {
                  return normalizeIndex(tempActiveIndexRef.current + newOffset);
                });
              }

              velocityRef.current *= FRICTION_COEFF;
              return newY;
            });
          }
        }, RENDER_INTERVAL);
      };

      momentumScroll();
    } else {
      stopScroll();
    }

    isDraggingRef.current = false;
  }, [stopScroll, normalizeIndex]);
  useEffect(function () {
    document.addEventListener('mousemove', handleTouchMove);
    document.addEventListener('mouseup', handleTouchEnd);
    return function () {
      document.removeEventListener('mousemove', handleTouchMove);
      document.removeEventListener('mouseup', handleTouchEnd);
    };
  }, [handleTouchEnd, handleTouchMove, data]);
  useEffect(function () {
    if (prevInitialIndex !== initialIndex) {
      tempActiveIndexRef.current = initialIndex;
      setActiveIndex(initialIndex);
      setYTranslate(Y_ORIGIN);
      onChangeValue(data["".concat(initialIndex)], initialIndex);
    }
  }, [data, initialIndex, onChangeValue, prevInitialIndex]);
  useEffect(function () {
    if (!isScrollingRef.current && (_activeIndex > data.length - 1 || isDataDisabledAt(_activeIndex))) {
      var _firstAvailableIndex = function _firstAvailableIndex() {
        for (var index in data) {
          if (!isDataDisabledAt(index)) {
            return parseInt(index);
          }
        }

        return 0;
      };

      var newIndex = _firstAvailableIndex();

      tempActiveIndexRef.current = newIndex;
      setActiveIndex(newIndex);
      setYTranslate(Y_ORIGIN);
      onChangeValue(data[Number(newIndex)], newIndex);
    }
  }, [_activeIndex, data, data.length, isDataDisabledAt, onChangeValue]);
  useEffect(function () {
    return function () {
      intervalRef.current && clearInterval(intervalRef.current);
    };
  }, []);
  useEffect(function () {
    document.addEventListener('mousemove', handleTouchMove);
    document.addEventListener('mouseup', handleTouchEnd);
    return function () {
      document.removeEventListener('mousemove', handleTouchMove);
      document.removeEventListener('mouseup', handleTouchEnd);
    };
  }, [handleTouchEnd, handleTouchMove, data]);

  var getOffsetFromYTranslate = function getOffsetFromYTranslate(y) {
    var newOffset = (-y + (CONTAINER_HEIGHT - ROW_HEIGHT) / 2) / ROW_HEIGHT;
    newOffset = Math.round(newOffset);
    return newOffset;
  };

  var renderInfiniteItems = function renderInfiniteItems() {
    var a = [];
    var keyI = 0;

    for (var i = offset - LIST_SIZE_CONSTANT; i <= offset + LIST_SIZE_CONSTANT; ++i) {
      var index = normalizeIndex(tempActiveIndexRef.current + i);
      a.push(React.createElement("div", {
        style: {
          top: "".concat(i * 30, "px")
        },
        className: scroll_container_row(index === _activeIndex, isDataDisabledAt(index)),
        key: keyI++,
        "aria-hidden": i !== offset ? 'true' : undefined,
        "aria-valuetext": i === offset ? "".concat(data[Number(index)].text.toString()) : undefined,
        "aria-disabled": isDataDisabledAt(index) ? 'true' : undefined
      }, data[Number(index)].text.toString()));
    }

    return a;
  };

  var renderFiniteItems = function renderFiniteItems() {
    var a = [];
    var keyI = 0;

    for (var i = -tempActiveIndexRef.current; i < data.length - tempActiveIndexRef.current; ++i) {
      var index = normalizeIndex(tempActiveIndexRef.current + i);
      a.push(React.createElement("div", {
        style: {
          top: "".concat(i * 30, "px")
        },
        className: scroll_container_row(index === _activeIndex, isDataDisabledAt(index)),
        key: keyI++
      }, data[Number(index)].text.toString()));
    }

    return a;
  };

  var scrollEventListener = data.length > 1 ? {
    onTouchStart: handleTouchStart,
    onTouchMove: handleTouchMove,
    onTouchEnd: handleTouchEnd,
    onMouseDown: handleTouchStart
  } : {};
  var activeData = data[Number(_activeIndex)] ? data[Number(_activeIndex)] : undefined;
  var ariaProperties = data.length > 1 ? {
    'aria-valuemin': firstAvailableIndex(),
    'aria-valuemax': lastAvailableIndex(),
    'aria-valuetext': activeData === null || activeData === void 0 ? void 0 : activeData.text,
    'aria-label': "Current value is ".concat(activeData === null || activeData === void 0 ? void 0 : activeData.text, ". Scroll this region to change value")
  } : {};
  return React.createElement(Fragment, null, data.length >= 1 && data.length <= 3 ? React.createElement("div", _extends({}, otherProps, {
    role: "spinbutton",
    className: datepicker_scroll_scroll_container,
    style: {
      transform: "translate3d(0, ".concat(yTranslate, "px, 0)"),
      width: width ? "".concat(width, "%") : '33%',
      display: width <= 0 ? 'none' : 'inline-block',
      textAlign: textAlign ? textAlign : 'center'
    },
    tabIndex: 0,
    draggable: true
  }, scrollEventListener, ariaProperties), renderFiniteItems()) : React.createElement("div", _extends({}, otherProps, {
    role: "spinbutton",
    className: datepicker_scroll_scroll_container,
    style: {
      transform: "translate3d(0, ".concat(yTranslate, "px, 0)"),
      width: width ? "".concat(width, "%") : '33%',
      display: width <= 0 ? 'none' : 'inline-block',
      textAlign: textAlign ? textAlign : 'center'
    },
    ref: containerRef,
    tabIndex: 0,
    draggable: true
  }, scrollEventListener, ariaProperties), renderInfiniteItems()), React.createElement("div", {
    id: "datepickerScrollAria",
    "aria-live": "polite",
    ref: ariaLabelRef,
    style: {
      width: '0',
      height: '0',
      overflow: 'hidden',
      position: 'absolute'
    }
  }, "".concat(activeData === null || activeData === void 0 ? void 0 : activeData.text, " ").concat(activeData !== null && activeData !== void 0 && activeData.disabled ? 'disabled value' : '')));
};

export default ScrollContainer;