import { ComponentPropsWithoutRef, MouseEvent } from 'react';
export interface ItemData {
    text: string;
    value: number | Date;
    disabled?: boolean;
}
export declare type DatepickerScrollType = 'date' | 'datetime' | 'time';
declare type DatepickerScrollAttributes = ComponentPropsWithoutRef<'div'>;
export interface DatepickerScrollProps extends Omit<DatepickerScrollAttributes, 'css' | 'onClick'> {
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     *  To select content to display inside of datepickerScroll.
     */
    content?: DatepickerScrollType;
    /**
     * To specify description in the sheet under title before datepicker
     */
    description?: string;
    /**
     * To set initial selected date & time of datepickerScroll
     * @default new Date()
     */
    initialDate?: Date;
    /**
     * To specify language of Datepicker
     * @default 'id'
     */
    lang?: string;
    /**
     * To specify the maximum date (also time for timepicker/datetimepicker) that this datepickerScroll takes into account, accepts Date object
     * @default new Date(new Date().getFullYear(), 11, 31)
     */
    maxDate?: Date;
    /**
     * To specify the minimum date (also time for timepicker/datetimepicker) that this datepickerScroll takes into account, accepts Date object
     * @default new Date(1900, 1, 1)
     */
    minDate?: Date;
    /**
     * To set type of content to display
     * @default 'date'
     */
    type?: DatepickerScrollType;
    /**
     * To set value that will be returned when used click button
     * @default () => {}
     */
    setValue?: (newVal: Date) => void;
    /**
     * To pass function that gets called on clicking 'Confirm' button
     */
    onClick?: (dateValue: Date, event: MouseEvent<HTMLButtonElement>) => void;
}
export interface DatepickerScrollDefaultProps extends DatepickerScrollProps {
    /**
     * To set the content of datepicker
     * @default 'd-MMMM-yyyy'
     */
    format?: string;
    /**
     * To pass function that gets called on date change
     * @default () => {}
     */
    onChangeDate?: (newValText: string, newVal: number) => void;
    /**
     * To pass function that gets called on month change
     * @default () => {}
     */
    onChangeMonth?: (newValText: string, newVal: number) => void;
    /**
     * To pass function that gets called on year change
     * @default () => {}
     */
    onChangeYear?: (newValText: string, newVal: number) => void;
}
export interface DatepickerScrollTimeProps extends DatepickerScrollProps {
    /**
     * To set initial selected date of datepickerScroll
     */
    initialDate: Date;
    /**
     * To set max time for this datepickerScroll, accepts Date object. This overrides the time behavior of maxDate. Both min and maxDate need to be present in order for this to work.
     */
    maxTime?: Date;
    /**
     * To set min time for this datepickerScroll, accepts Date object. This overrides the time behavior of minDate. Both min and maxDate need to be present in order for this to work.
     */
    minTime?: Date;
    /**
     * To set the interval of value shown under minute section
     * @default 1
     */
    minuteInterval?: number;
    /**
     * To pass function that gets called on date change
     */
    onChangeDate?: (newValText: string, newVal: Date) => void;
    /**
     * To pass function that gets called on hour change
     */
    onChangeHour?: (newValText: string, newVal: number) => void;
    /**
     * To pass function that gets called on minute change
     */
    onChangeMinute?: (newValText: string, newVal: number) => void;
}
export interface ScrollContainerProps {
    /**
     * To customize class
     */
    className?: string;
    /**
     * Array of string values populated in scroll container
     * @default []
     */
    data?: ItemData[];
    id?: string;
    /**
     * Initial active index of scroll container
     * @default 0
     */
    initialIndex?: number;
    /**
     * text alignment
     */
    textAlign?: 'left' | 'right' | 'center';
    /**
     * Width of container
     * @default 33
     */
    width?: number;
    /**
     * Function that gets called on value change
     * @default () => {}
     */
    onChangeValue?: (newValue: ItemData, index: number) => void;
}
export {};
