import React from 'react';
import { ButtonProps } from '../../build/Button/type';
declare type DialogAttributes = React.ComponentPropsWithoutRef<'div'>;
export interface ModProps {
    mod?: ModStyleProps;
}
interface ModStyleProps {
    display?: boolean;
    error?: boolean;
    height?: number | string;
    minWidth?: string;
    padding?: string;
    translateY?: number | string;
    zIndex?: number;
}
export interface DialogProps extends Omit<DialogAttributes, 'css'> {
    /**
     * To add user defined props on primary button
     */
    actionPrimaryProps?: ButtonProps;
    /**
     * To specify string of primary button text
     */
    actionPrimaryText?: string;
    /**
     * To provide border on secondary button
     */
    actionSecondaryBorder?: boolean;
    /**
     * To add user defined props on secondary button
     */
    actionSecondaryProps?: ButtonProps;
    /**
     * To specify string of secondary button text
     */
    actionSecondaryText?: string;
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     * To add user defined props on description
     */
    descriptionProps?: object;
    /**
     * To toggle visibility on Dialog
     */
    display?: boolean;
    /**
     * To provide icon's url
     */
    icon?: string;
    /**
     * To provide illustration's url
     */
    illustration?: string;
    /**
     * To toggle loading props on primary action button
     */
    loadingPrimary?: boolean;
    /**
     * To toggle loading props on secondary action button
     */
    loadingSecondary?: boolean;
    /**
     * To apply vertical button positioning
     */
    longAction?: boolean;
    /**
     * To specify title in Dialog
     */
    title?: string;
    /**
     * To add user defined props on title
     */
    titleProps?: object;
    /**
     * To pass callback when prumary button is clicked
     */
    onActionPrimaryClick?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /**
     * To pass callback when secondary button is clicked
     */
    onActionSecondaryClick?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /**
     * To pass callback when Dialog is closed
     */
    onClose?: (e: React.MouseEvent<HTMLDivElement>) => void;
}
export {};
