import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _typeof from "@babel/runtime/helpers/typeof";
var _excluded = ["anchor", "children", "color", "entryPoint", "expandable", "size", "enableScrollInteraction", "onClick"];
import React, { useEffect, useRef, useState, forwardRef, Children } from 'react';
import throttle from "../../build/Providers/common/utilities/throttle";
import { getElementYPosition, isInViewport, smoothScrollTo } from "./_utils";
import { ActionButton as StyledActionButton } from "./style";
var canUseDOM = (typeof window === "undefined" ? "undefined" : _typeof(window)) === 'object';
var ActionButton = forwardRef(function (_ref, ref) {
  var anchor = _ref.anchor,
      children = _ref.children,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'white' : _ref$color,
      _ref$entryPoint = _ref.entryPoint,
      entryPoint = _ref$entryPoint === void 0 ? 0 : _ref$entryPoint,
      _ref$expandable = _ref.expandable,
      expandable = _ref$expandable === void 0 ? false : _ref$expandable,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'small' : _ref$size,
      _ref$enableScrollInte = _ref.enableScrollInteraction,
      enableScrollInteraction = _ref$enableScrollInte === void 0 ? true : _ref$enableScrollInte,
      onClick = _ref.onClick,
      etc = _objectWithoutProperties(_ref, _excluded);

  var reAppearTimeout = useRef();
  var hasVisibleAnchorElement = useRef(false);
  var isScrollAboveEntryPoint = useRef(canUseDOM && window.scrollY < entryPoint);
  var prevScrollPosition = useRef(0);

  var _useState = useState(isScrollAboveEntryPoint.current),
      _useState2 = _slicedToArray(_useState, 2),
      isButtonHidden = _useState2[0],
      setButtonHidden = _useState2[1];

  var hasAnchor = typeof anchor === 'number' || _typeof(anchor) === 'object';
  var isRefAnchor = hasAnchor && _typeof(anchor) === 'object' && Object.prototype.hasOwnProperty.call(anchor, 'current');
  var isBackToTopAnchor = anchor === 0;

  var handleClickButton = function handleClickButton(e) {
    if (hasAnchor) {
      var anchorPosition = isRefAnchor ? getElementYPosition(anchor) : Number(anchor);
      smoothScrollTo(0, anchorPosition);

      if (isBackToTopAnchor) {
        reAppearTimeout.current && window.clearTimeout(reAppearTimeout.current);
        setButtonHidden(true);
      }
    }

    onClick && onClick(e);
  };

  var renderChildren = Children.map(children, function (child) {
    var isTextNode = typeof child === 'string' && child !== '';
    return isTextNode ? React.createElement("span", null, child) : child;
  });
  useEffect(function () {
    var handleScroll = throttle(function () {
      var currentScrollPosition = window.scrollY || 0;
      var isScrollingDown = currentScrollPosition > prevScrollPosition.current;
      isScrollAboveEntryPoint.current = currentScrollPosition < entryPoint;
      hasVisibleAnchorElement.current = isRefAnchor && isInViewport(anchor);

      if (isScrollingDown || hasVisibleAnchorElement.current || isScrollAboveEntryPoint.current) {
        setButtonHidden(true);
      }

      if (!hasVisibleAnchorElement.current && !isScrollAboveEntryPoint.current) {
        reAppearTimeout.current && window.clearTimeout(reAppearTimeout.current);
        reAppearTimeout.current = window.setTimeout(function () {
          !hasVisibleAnchorElement.current && setButtonHidden(false);
        }, 200);
      }

      prevScrollPosition.current = currentScrollPosition;
    }, 100);

    if (enableScrollInteraction) {
      canUseDOM && window.addEventListener('scroll', handleScroll);
    }

    return function () {
      if (canUseDOM) {
        window.removeEventListener('scroll', handleScroll);
        reAppearTimeout.current && window.clearTimeout(reAppearTimeout.current);
      }
    };
  }, [anchor, entryPoint, isBackToTopAnchor, isButtonHidden, isRefAnchor, enableScrollInteraction]);
  return React.createElement(StyledActionButton, _extends({
    animateOnEnter: enableScrollInteraction,
    isHidden: isButtonHidden,
    color: color,
    expandable: expandable,
    innerRef: ref,
    size: size,
    "data-unify": "FAB-Button",
    onClick: handleClickButton
  }, etc), renderChildren);
});
ActionButton.displayName = 'ActionButton';
export default ActionButton;