import React, { ComponentPropsWithoutRef } from 'react';
declare type ImageAttributes = ComponentPropsWithoutRef<'div'>;
export declare type ImageRatio = '1:1' | '2:1' | '3:2' | '3:1' | '4:1';
export interface ImageProps extends Omit<ImageAttributes, 'css'> {
    /**
     * To set image alt
     */
    alt?: string;
    /**
     * To set the radius of the image, only works in 'product' mode
     * @default '8px'
     */
    borderRadius?: string;
    /**
     * To enable image reloading when image fails to load, otherwise static broken image will be used
     * @default false
     */
    hasReloadOnError?: boolean;
    /**
     * To render product type of Image
     * @default false
     */
    product?: boolean;
    /**
     * To specify image ratio
     * @default '1:1'
     */
    ratio?: ImageRatio;
    /**
     * To enable shimmer loading, otherwise static grey background will be used. Please disable this if there is a performance issue.
     * @default true
     */
    shimmerLoading?: boolean;
    /**
     * To set the size of image. Can accept either pre-defined value, or custom value. Pre-defined values are 'micro' | 'small' | 'medium' | 'large' | 'extra large',
     * @default ''
     */
    size?: string;
    /**
     * To specify image source. Leave this blank to display as placeholder.
     * @default ''
     */
    src?: string;
    /**
     * To render user type of image
     * @default false
     */
    user?: boolean;
    /**
     * To pass callback when image fails to load
     * @default () => {}
     */
    onError?: (e: React.SyntheticEvent<HTMLImageElement>) => void;
    /**
     * To pass callback when reload button is clicked (image fails to load)
     * @default () => {}
     */
    onClickReload?: (e: React.MouseEvent<HTMLDivElement>) => void;
}
export {};
