import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["activeIndex", "children", "onNext", "onPrev", "onSlideChange", "onSwipe"];
import React, { useEffect, useState } from 'react';
import { canUseDOM } from "../../build/Providers/common/functions";
import { Slider, SliderItem, SliderTrack } from "./LightboxSlider.style";

var LightboxSlider = function LightboxSlider(props) {
  var activeIndex = props.activeIndex,
      children = props.children,
      onNext = props.onNext,
      onPrev = props.onPrev,
      onSlideChange = props.onSlideChange,
      onSwipe = props.onSwipe,
      otherProps = _objectWithoutProperties(props, _excluded);

  var _useState = useState(activeIndex),
      _useState2 = _slicedToArray(_useState, 2),
      currentSlide = _useState2[0],
      setCurrentSlide = _useState2[1];

  var _useState3 = useState(null),
      _useState4 = _slicedToArray(_useState3, 2),
      touchPosition = _useState4[0],
      setTouchPosition = _useState4[1];

  useEffect(function () {
    setCurrentSlide(activeIndex);
  }, [activeIndex]);

  var useWindowSize = function useWindowSize() {
    var _useState5 = useState({
      width: undefined,
      height: undefined
    }),
        _useState6 = _slicedToArray(_useState5, 2),
        windowSize = _useState6[0],
        setWindowSize = _useState6[1];

    useEffect(function () {
      var handleResize = function handleResize() {
        if (canUseDOM) {
          setWindowSize({
            width: window.innerWidth,
            height: window.innerHeight
          });
        }
      };

      if (canUseDOM) {
        window.addEventListener('resize', handleResize);
      }

      handleResize();
      return function () {
        return window.removeEventListener('resize', handleResize);
      };
    }, []);
    return windowSize;
  };

  var screenSize = useWindowSize();
  var initialTranslate = currentSlide * -screenSize.width;

  var handleTouchStart = function handleTouchStart(e) {
    var touchDown = {
      x: e.touches[0].clientX,
      y: e.touches[0].clientY
    };
    setTouchPosition(touchDown);
  };

  var handleTouchMove = function handleTouchMove(e) {
    if (e.targetTouches.length === 1) {
      var touchDown = touchPosition;

      if (touchDown === null) {
        return null;
      }

      var currentTouch = {
        x: e.touches[0].clientX,
        y: e.touches[0].clientY
      };
      var diffX = touchDown.x - currentTouch.x;
      var diffY = touchDown.y - currentTouch.y;

      if (Math.abs(diffX) > Math.abs(diffY) && diffX > 5) {
        if (currentSlide < children.length - 1) {
          setCurrentSlide(function (prevState) {
            return prevState + 1;
          });
          onNext(currentSlide + 1);
        }
      } else if (Math.abs(diffX) > Math.abs(diffY) && diffX < 5) {
        if (currentSlide > 0) {
          setCurrentSlide(function (prevState) {
            return prevState - 1;
          });
          onPrev(currentSlide - 1);
        }
      }

      setTouchPosition(null);
      onSwipe();
    }
  };

  useEffect(function () {
    onSlideChange(currentSlide);
  }, [currentSlide]);

  var renderItems = function renderItems() {
    return children.map(function (items, index) {
      return React.createElement("div", {
        key: index,
        className: "".concat(SliderItem, " ").concat(activeIndex === index ? 'active' : null)
      }, items);
    });
  };

  return React.createElement("div", {
    className: Slider
  }, React.createElement("div", _extends({
    className: SliderTrack,
    onTouchStart: handleTouchStart,
    onTouchMove: handleTouchMove,
    style: {
      transform: "translate3d(".concat(initialTranslate, "px, 0, 0)")
    }
  }, otherProps), renderItems()));
};

LightboxSlider.defaultProps = {
  onNext: function onNext() {},
  onPrev: function onPrev() {},
  onSlideChange: function onSlideChange() {},
  onSwipe: function onSwipe() {}
};
export default LightboxSlider;