import React from 'react';
export interface LightboxProps {
    /**
     * To set active index of Lightbox
     */
    activeIndex?: number;
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     * To provide data-testid
     */
    dataTest?: DataTest;
    /**
     * To toggle visibility of Lightbox
     */
    display?: boolean;
    /**
     * To apply Lightbox Header design with action icon on the right side
     */
    headerActions?: React.ReactNode;
    /**
     * To specify content of Lightbox Header
     */
    headerContent?: React.ReactNode;
    /**
     * To determine Lightbox item
     */
    items?: ItemsProps[];
    /**
     * To determine loading state
     */
    loading?: boolean;
    /**
     * To show image not found state
     */
    noImage?: boolean;
    /**
     * To show video not found state
     */
    noVideo?: boolean;
    /**
     * To specify overlay content of Lightbox
     */
    overlayContent?: React.ReactNode;
    /**
     * To set subtitle text for Lightbox Header
     */
    subTitle?: string;
    /**
     * To set title text for Lightbox Header
     */
    title?: string;
    /**
     * To set total items manually in counter section
     */
    totalItems?: number;
    /**
     * To apply Lightbox with counter design
     */
    withCounter?: boolean;
    /**
     * To apply Lightbox with thumbnail design
     */
    withThumbnail?: boolean;
    /**
     * To set a callback function when user click back icon
     */
    onClickBack?: string | ((e: React.MouseEvent<HTMLButtonElement>) => void) | ((videoCurrentTime: number) => void);
    /**
     * To set a callback function when Thumbnail is clicked
     */
    onClickThumbnail?: (activeIndex: number) => void;
    /**
     * To set a callback function when Lightbox Slider going to next slide
     */
    onNext?: (activeIndex: number) => void;
    /**
     * To set a callback function when Lightbox Slider going to previous slide
     */
    onPrev?: (activeIndex: number) => void;
    /**
     * To set a callback function when activeIndex is changed
     */
    onSlideChange?: (activeIndex: number) => void;
}
export interface ItemsProps {
    alt?: string;
    autoPlay?: boolean;
    content?: React.ReactNode;
    muted?: boolean;
    type?: string;
    url?: string;
    videoPoster?: string;
    onEnded?: () => void;
    onPause?: () => void;
    onPlay?: (videoCurrentTime: number) => void;
    onVolumeChange?: () => void;
}
interface DataTest {
    iconBack?: string;
    imageThumbnail?: string;
    itemSlider?: string;
    textCounter?: string;
}
declare const Lightbox: {
    (props: LightboxProps): JSX.Element;
    propTypes: {
        activeIndex: import("prop-types").Requireable<number>;
        className: import("prop-types").Requireable<string>;
        dataTest: import("prop-types").Requireable<object>;
        display: import("prop-types").Requireable<boolean>;
        headerActions: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        headerContent: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        items: import("prop-types").Requireable<import("prop-types").InferProps<{
            alt: import("prop-types").Requireable<string>;
            autoPlay: import("prop-types").Requireable<boolean>;
            content: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
            muted: import("prop-types").Requireable<boolean>;
            type: import("prop-types").Requireable<string>;
            url: import("prop-types").Requireable<string>;
            videoPoster: import("prop-types").Requireable<string>;
            onEnded: import("prop-types").Requireable<(...args: any[]) => any>;
            onPause: import("prop-types").Requireable<(...args: any[]) => any>;
            onPlay: import("prop-types").Requireable<(...args: any[]) => any>;
            onVolumeChange: import("prop-types").Requireable<(...args: any[]) => any>;
        }>[]>;
        loading: import("prop-types").Requireable<boolean>;
        noImage: import("prop-types").Requireable<boolean>;
        noVideo: import("prop-types").Requireable<boolean>;
        overlayContent: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        subTitle: import("prop-types").Requireable<string>;
        title: import("prop-types").Requireable<string>;
        totalItems: import("prop-types").Requireable<number>;
        withCounter: import("prop-types").Requireable<boolean>;
        withThumbnail: import("prop-types").Requireable<boolean>;
        onClickBack: import("prop-types").Requireable<string | ((...args: any[]) => any)>;
        onClickThumbnail: import("prop-types").Requireable<(...args: any[]) => any>;
        onNext: import("prop-types").Requireable<(...args: any[]) => any>;
        onPrev: import("prop-types").Requireable<(...args: any[]) => any>;
        onSlideChange: import("prop-types").Requireable<(...args: any[]) => any>;
    };
    defaultProps: {
        activeIndex: number;
        dataTest: {};
        display: boolean;
        items: any[];
        loading: boolean;
        noImage: boolean;
        noVideo: boolean;
    };
};
export default Lightbox;
