import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["items", "activeIndex", "className", "top", "zIndex", "children", "onChange"];
import React, { useState, useEffect, useRef, useCallback } from 'react';
import { cx } from 'react-emotion';
import throttle from "../../build/Providers/common/utilities/throttle";
import { useKeyboardControl } from "../../build/Providers/common/hooks";
import { canUseDOM } from "../../build/Providers/common/functions";
import TabPaneItem from "./TabPaneItem";
import Content from "./TabContent";
import { _megaTab } from "./styles";

var MegaTab = function MegaTab(props) {
  var _props$items = props.items,
      items = _props$items === void 0 ? [] : _props$items,
      _props$activeIndex = props.activeIndex,
      activeIndex = _props$activeIndex === void 0 ? 0 : _props$activeIndex,
      className = props.className,
      _props$top = props.top,
      top = _props$top === void 0 ? 48 : _props$top,
      _props$zIndex = props.zIndex,
      zIndex = _props$zIndex === void 0 ? 41 : _props$zIndex,
      children = props.children,
      onChange = props.onChange,
      otherProps = _objectWithoutProperties(props, _excluded);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isPinned = _useState2[0],
      setIsPinned = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      isShrinked = _useState4[0],
      setIsShrinked = _useState4[1];

  var megaTabRef = useRef(null);
  var tabScrollRef = useRef(null);
  var timeout = useRef();
  var handleHorizontalScroll = useCallback(function () {
    if (canUseDOM) {
      var _tabScrollRef$current;

      var el = document.querySelector("[data-key=\"megaTab__pane__item-".concat(activeIndex, "\"]"));
      el && ((_tabScrollRef$current = tabScrollRef.current) === null || _tabScrollRef$current === void 0 ? void 0 : _tabScrollRef$current.scrollTo({
        left: el.offsetLeft - 20,
        top: 0,
        behavior: 'smooth'
      }));
    }
  }, [activeIndex]);
  useEffect(function () {
    handleHorizontalScroll();
  }, [handleHorizontalScroll]);
  useEffect(function () {
    if (canUseDOM) {
      var handleHorizontalScrollThrottled = throttle(handleHorizontalScroll, 1000);

      var handleScroll = function handleScroll() {
        var _megaTabRef$current;

        var wrapperRect = (_megaTabRef$current = megaTabRef.current) === null || _megaTabRef$current === void 0 ? void 0 : _megaTabRef$current.getBoundingClientRect();

        if (!isPinned && wrapperRect) {
          if (wrapperRect.y <= top) {
            setIsPinned(true);
          } else if (wrapperRect.y > top) {
            setIsPinned(false);
          }
        }

        if (isPinned) {
          clearTimeout(timeout.current);
          setIsShrinked(true);
          handleHorizontalScrollThrottled();
          timeout.current = setTimeout(function () {
            setIsShrinked(false);
          }, 1000);
        } else {
          setIsShrinked(false);
        }
      };

      document.addEventListener('scroll', handleScroll);
      return function () {
        return document.removeEventListener('scroll', handleScroll);
      };
    }
  }, [isPinned, top, handleHorizontalScroll]);

  var _useState5 = useState(activeIndex),
      _useState6 = _slicedToArray(_useState5, 2),
      focusIndex = _useState6[0],
      setFocusIndex = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      isFocussed = _useState8[0],
      setIsFocussed = _useState8[1];

  var focussedEl = useRef(null);
  useEffect(function () {
    setFocusIndex(activeIndex);
  }, [activeIndex]);
  useEffect(function () {
    if (canUseDOM && isFocussed && focusIndex) {
      var _focussedEl$current;

      focussedEl.current = document.querySelectorAll(".megaTab__pane__item")[focusIndex];
      (_focussedEl$current = focussedEl.current) === null || _focussedEl$current === void 0 ? void 0 : _focussedEl$current.focus();
    }
  }, [focusIndex]);
  useKeyboardControl({
    ArrowLeft: function ArrowLeft(e) {
      e.preventDefault();
      var prevFocus;

      if (focusIndex === 0) {
        prevFocus = items.length - 1;
      } else {
        prevFocus = focusIndex - 1;
      }

      setFocusIndex(prevFocus);
    },
    ArrowRight: function ArrowRight(e) {
      e.preventDefault();
      var nextFocus;

      if (focusIndex === items.length - 1) {
        nextFocus = 0;
      } else {
        nextFocus = focusIndex + 1;
      }

      setFocusIndex(nextFocus);
    },
    tab: function tab() {
      if (document.activeElement !== focussedEl.current) {
        setIsFocussed(false);
      }
    }
  }, isFocussed);

  var handleTabItemFocus = function handleTabItemFocus() {
    setIsFocussed(true);
  };

  var handleItemClick = function handleItemClick(e, index) {
    onChange && onChange(e, index);
  };

  var renderContent = function renderContent() {
    var childArray = React.Children.toArray(children);
    return childArray["".concat(activeIndex)];
  };

  return items.length > 0 && React.createElement(React.Fragment, null, React.createElement("div", _extends({}, otherProps, {
    "data-unify": "MegaTab",
    ref: megaTabRef,
    className: cx('megaTab__pane', _megaTab(top, zIndex), className),
    role: "tablist"
  }), React.createElement("div", {
    className: cx('megaTab__pane__placeholder', isPinned ? 'is-pinned' : '', isShrinked ? 'is-shrinked' : '')
  }, React.createElement("div", {
    ref: tabScrollRef,
    className: "megaTab__pane__nav"
  }, items.map(function (itemProps, i) {
    return React.createElement(TabPaneItem, _extends({}, itemProps, {
      key: i,
      eventKey: i,
      isActive: activeIndex === i,
      "aria-selected": activeIndex === i,
      isShrinked: isShrinked,
      role: "tab",
      onClick: handleItemClick,
      onFocus: handleTabItemFocus
    }));
  })))), renderContent());
};

export default Object.assign(MegaTab, {
  Content: Content
});