import _extends from "@babel/runtime/helpers/extends";
import _typeof from "@babel/runtime/helpers/typeof";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useEffect, useRef, useState } from 'react';
import { cx } from 'emotion';
import ArrowBack from 'unify-icons/system/ArrowBack';
import { NN0L, NN500 } from 'unify-token/colors';
import Typography from "../../build/Typography";
import { canUseDOM } from "../../build/Providers/common/functions";
import { Burger, Container, Content, ContentWrapper, Heading, Spacer, Stepper, Subtitle, TitleWrapper, Wrapper } from "./style";

var NavBar = function NavBar(_ref) {
  var _ref$backProps = _ref.backProps,
      backProps = _ref$backProps === void 0 ? {} : _ref$backProps,
      children = _ref.children,
      className = _ref.className,
      content = _ref.content,
      _ref$fixed = _ref.fixed,
      fixed = _ref$fixed === void 0 ? false : _ref$fixed,
      heading = _ref.heading,
      _ref$hideSubtitle = _ref.hideSubtitle,
      hideSubtitle = _ref$hideSubtitle === void 0 ? false : _ref$hideSubtitle,
      _ref$hideTitle = _ref.hideTitle,
      hideTitle = _ref$hideTitle === void 0 ? false : _ref$hideTitle,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      main = _ref.main,
      _ref$noShadow = _ref.noShadow,
      noShadow = _ref$noShadow === void 0 ? false : _ref$noShadow,
      numberOfStep = _ref.numberOfStep,
      selectable = _ref.selectable,
      _ref$shadow = _ref.shadow,
      shadow = _ref$shadow === void 0 ? true : _ref$shadow,
      _ref$step = _ref.step,
      step = _ref$step === void 0 ? -1 : _ref$step,
      subTitle = _ref.subTitle,
      _ref$tag = _ref.tag,
      tag = _ref$tag === void 0 ? 1 : _ref$tag,
      title = _ref.title,
      _ref$transparent = _ref.transparent,
      transparent = _ref$transparent === void 0 ? false : _ref$transparent,
      onBack = _ref.onBack,
      onBurgerClick = _ref.onBurgerClick,
      onClick = _ref.onClick,
      onTransparentChange = _ref.onTransparentChange;
  var navElement = useRef();
  var scrollEventLoaded = useRef(false);

  var _useState = useState(transparent),
      _useState2 = _slicedToArray(_useState, 2),
      isTransparent = _useState2[0],
      setTransparent = _useState2[1];

  var ARIA_LABEL = {
    en: 'Back to previous page',
    id: 'kembali ke laman sebelumnya'
  };
  useEffect(function () {
    var handleScroll = function handleScroll() {
      var _navElement$current;

      var scrolled = window.pageYOffset;
      var navHeight = ((_navElement$current = navElement.current) === null || _navElement$current === void 0 ? void 0 : _navElement$current.offsetHeight) || 0;

      if (typeof transparent === 'boolean') {
        if (scrolled > navHeight) {
          setTransparent(false);
        } else {
          setTransparent(true);
        }
      } else if (_typeof(transparent) === 'object') {
        if (transparent.persist) {
          setTransparent(true);
        } else {
          if (!transparent.offset) {
            return;
          }

          if (scrolled > transparent.offset) {
            setTransparent(false);
          } else {
            setTransparent(true);
          }
        }
      }
    };

    if (canUseDOM) {
      if (scrollEventLoaded.current !== true) {
        transparent && window.addEventListener('scroll', handleScroll);
        scrollEventLoaded.current = true;
      }
    }

    return function () {
      if (canUseDOM) {
        transparent && window.removeEventListener('scroll', handleScroll);
      }
    };
  }, [transparent]);
  useEffect(function () {
    setTransparent(transparent);
  }, [transparent]);
  useEffect(function () {
    if (onTransparentChange) {
      onTransparentChange(Boolean(isTransparent));
    }
  }, [isTransparent, onTransparentChange]);

  var renderNavButton = function renderNavButton() {
    return main && Boolean(onBurgerClick) ? React.createElement(Burger, {
      className: "unf-navbar__menu",
      "data-testid": "btnHeaderSideBar",
      transparent: isTransparent,
      "aria-label": "navbar-menu",
      role: "button",
      onClick: onBurgerClick
    }) : renderBack();
  };

  var renderNavBarContent = function renderNavBarContent() {
    return React.createElement(React.Fragment, null, main && !title && content ? React.createElement(Content, {
      className: "unf-navbar__title"
    }, content) : React.createElement(Content, {
      className: "unf-navbar__title"
    }, React.createElement(Heading, {
      transparent: isTransparent,
      withPadding: !main && !onBack
    }, Boolean(selectable) && React.createElement(React.Fragment, null, React.createElement(Typography, {
      "aria-label": "Selectable",
      className: "unf-navbar__title--selectable",
      margin: onBack ? '0' : '0 0 0 16px',
      caption: true,
      onClick: function onClick(e) {
        selectable.onClick && selectable.onClick(e);
      }
    }, selectable.value)), title && !hideTitle && React.createElement(Typography, {
      heading: heading,
      className: "unf-navbar__title--heading",
      tag: tag
    }, title)), subTitle && !hideSubtitle && React.createElement(Subtitle, {
      withPadding: !onBack,
      transparent: isTransparent
    }, subTitle)), children);
  };

  var renderNavBar = function renderNavBar() {
    var mainClass = cx('unf-navbar-wrapper', 'unf-navbar-wrapper--main', {
      'unf-navbar-wrapper--fixed': fixed,
      'unf-navbar-wrapper--transparent': Boolean(isTransparent)
    });
    var navbarClass = cx('unf-navbar', {
      isTransparent: 'unf-navbar--transparent',
      'unf-navbar--no-shadow': !shadow
    }, className);
    return React.createElement(Wrapper, {
      className: mainClass,
      fixed: fixed,
      innerRef: navElement,
      transparent: isTransparent
    }, React.createElement(ContentWrapper, {
      className: navbarClass,
      main: main,
      transparent: isTransparent,
      shadow: shadow,
      noShadow: noShadow
    }, renderNavButton(), onClick ? React.createElement("div", {
      className: TitleWrapper,
      onClick: onClick,
      role: "presentation"
    }, renderNavBarContent()) : renderNavBarContent()), !transparent && step >= 0 && numberOfStep && React.createElement(Stepper, {
      "aria-label": "Step ".concat(step, " from ").concat(numberOfStep),
      step: step,
      numberOfStep: numberOfStep
    }));
  };

  var renderBack = function renderBack() {
    if (!onBack) {
      return null;
    }

    var handleBack = function handleBack(e) {
      if (canUseDOM) {
        if (typeof onBack === 'function') {
          onBack(e);
        } else {
          window.history.back();
        }
      }
    };

    var isLink = typeof onBack === 'string';
    return isLink ? React.createElement("a", _extends({
      className: "unf-navbar__back",
      "aria-label": ARIA_LABEL[String(lang)],
      href: onBack
    }, backProps), React.createElement(ArrowBack, {
      color: isTransparent ? NN0L : NN500
    })) : React.createElement("button", _extends({
      className: "unf-navbar__back",
      "aria-label": ARIA_LABEL[String(lang)],
      onClick: handleBack
    }, backProps), React.createElement(ArrowBack, {
      color: isTransparent ? NN0L : NN500
    }));
  };

  var renderSpacer = function renderSpacer() {
    var spacerClass = cx('unf-navbar-wrapper-spacer', {
      hasStepper: Boolean(step) && Boolean(numberOfStep)
    });

    if (fixed || main) {
      return React.createElement(Spacer, {
        className: spacerClass,
        transparent: isTransparent,
        fixed: fixed
      });
    }

    return null;
  };

  return React.createElement(Container, {
    role: "navigation",
    className: 'unf-navbar-container',
    "data-unify": "NavBar"
  }, renderNavBar(), renderSpacer());
};

export default NavBar;