import React from 'react';
declare type NavBarAttributes = React.ComponentPropsWithoutRef<'nav'>;
export interface ModStyleProps {
    withPadding?: boolean;
}
export interface NavBarProps extends Omit<NavBarAttributes, 'css'> {
    /**
     * To pass additional props to back button
     * @default {}
     */
    backProps?: object;
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     * To specify action on left side of NavBar
     */
    content?: React.ReactNode;
    /**
     * To apply fixed position of NavBar
     * @default false
     */
    fixed?: boolean;
    /**
     * To change html tag different than it's size appearance
     */
    heading?: number;
    /**
     * To hide subtitle
     * @default false
     */
    hideSubtitle?: boolean;
    /**
     * To hide title
     * @@default false
     */
    hideTitle?: boolean;
    /**
     * To specify the language of this component
     * @default 'id'
     */
    lang?: string;
    /**
     * To apply main NavBar design
     */
    main?: boolean;
    /**
     * To remove shadow below NavBar
     * @@default false
     */
    noShadow?: boolean;
    /**
     * To set total number of steps
     */
    numberOfStep?: number;
    selectable?: {
        value?: React.ReactNode;
        onClick?: (e: React.MouseEvent<HTMLHeadingElement | HTMLParagraphElement | HTMLAnchorElement>) => void;
    };
    /**
     * Deprecated - Remove it soon, use noShadow instead
     * @default true
     */
    shadow?: boolean;
    /**
     * To set current step
     * @default -1
     */
    step?: number;
    /**
     * To set text for NavBar subtitle
     */
    subTitle?: string;
    /**
     * To determine title tag
     * @default 1
     */
    tag?: number;
    /**
     * To set text for NavBar title
     */
    title?: string;
    /**
     * To apply transparent NavBar design
     * @default false
     */
    transparent?: boolean | {
        persist?: boolean;
        offset?: number;
    };
    /**
     * To pass callback when back button is clicked
     */
    onBack?: string | ((e: React.MouseEvent<HTMLButtonElement>) => void);
    /**
     * To pass callback when burger button is clicked
     */
    onBurgerClick?: (e: React.MouseEvent<HTMLButtonElement | HTMLDivElement>) => void;
    /**
     * To pass callback and enable clickable area on a child element
     */
    onClick?: (e: React.MouseEvent<HTMLDivElement>) => void;
    /**
     * To pass callback when NavBar is changed from transparent into non-transparent
     */
    onTransparentChange?: (e: React.MouseEvent<HTMLDivElement> | any) => void;
}
export {};
