import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["value", "focus", "type", "darkMode", "pinMode"],
    _excluded2 = ["darkMode", "disabled", "error", "length", "value", "onChange", "numberOnly", "pinMode", "shouldAutoFocus"];
import React, { useState, useEffect, useRef } from 'react';
import { cx } from 'react-emotion';
import wrapperStyle from "./style";
var BACKSPACE = 8;
var LEFT_ARROW = 37;
var RIGHT_ARROW = 39;
var DELETE = 46;
var SPACEBAR = 32;

var SingleInput = function SingleInput(props) {
  var value = props.value,
      focus = props.focus,
      type = props.type,
      darkMode = props.darkMode,
      pinMode = props.pinMode,
      rest = _objectWithoutProperties(props, _excluded);

  var inputRef = useRef();

  var _useState = useState(type),
      _useState2 = _slicedToArray(_useState, 2),
      _type = _useState2[0],
      _setType = _useState2[1];

  useEffect(function () {
    var input = inputRef.current;

    if (input && focus) {
      input.focus();
    }
  }, [focus]);
  useEffect(function () {
    if (pinMode) {
      _setType(type);

      setTimeout(function () {
        _setType('password');
      }, 500);
    } else {
      _setType(type);
    }
  }, [value, type]);
  return React.createElement("input", _extends({
    ref: inputRef,
    onClick: function onClick(e) {
      e.target.select();
    },
    className: cx('unf-otp-field__input', darkMode ? 'unf-otp-field__input--dark' : ''),
    maxLength: "1",
    value: value,
    type: _type
  }, rest));
};

SingleInput.defaultProps = {
  value: ''
};

var OTPField = function OTPField(props) {
  var darkMode = props.darkMode,
      disabled = props.disabled,
      error = props.error,
      length = props.length,
      value = props.value,
      onChange = props.onChange,
      numberOnly = props.numberOnly,
      pinMode = props.pinMode,
      shouldAutoFocus = props.shouldAutoFocus,
      rest = _objectWithoutProperties(props, _excluded2);

  var _useState3 = useState(-1),
      _useState4 = _slicedToArray(_useState3, 2),
      activeInput = _useState4[0],
      setActive = _useState4[1];

  useEffect(function () {
    if (shouldAutoFocus) {
      setActive(0);
    }
  }, [shouldAutoFocus]);

  var getValue = function getValue() {
    return value ? value.toString().split('') : [];
  };

  var handleChange = function handleChange(val, e) {
    var _value = val.join('');

    onChange(_value, e);
  };

  var isInputValueValid = function isInputValueValid(value) {
    var isTypeValid = numberOnly ? !isNaN(parseInt(value, 10)) : typeof value === 'string';
    return isTypeValid && value.trim().length === 1;
  };

  var handleFocus = function handleFocus(e, index) {
    setActive(index);
    e.target.select();
  };

  var focusInput = function focusInput(input) {
    var _activeInput = Math.max(Math.min(length - 1, input), 0);

    setActive(_activeInput);
  };

  var focusNextInput = function focusNextInput() {
    var valueLength = getValue().length;

    if (valueLength < activeInput) {
      focusInput(valueLength + 1);
    } else {
      focusInput(activeInput + 1);
    }
  };

  var focusPrevInput = function focusPrevInput() {
    var valueLength = getValue().length;

    if (valueLength < activeInput) {
      focusInput(valueLength - 1);
    } else {
      focusInput(activeInput - 1);
    }
  };

  var changeCodeAtFocus = function changeCodeAtFocus(value, e) {
    var otp = getValue();
    otp[activeInput] = value;
    handleChange(otp, e);
  };

  var handleOnPaste = function handleOnPaste(e) {
    e.preventDefault();
    var pastedData = e.clipboardData.getData('text/plain').slice(0, length).split('');
    handleChange(pastedData, e);
  };

  var handleOnChange = function handleOnChange(e) {
    var value = e.target.value;

    if (isInputValueValid(value)) {
      changeCodeAtFocus(value, e);
    }
  };

  var handleOnKeyDown = function handleOnKeyDown(e) {
    switch (true) {
      case e.keyCode === BACKSPACE || e.key === 'Backspace':
        e.preventDefault();
        changeCodeAtFocus('', e);
        focusPrevInput();
        break;

      case e.keyCode === DELETE || e.key === 'Delete':
        e.preventDefault();
        changeCodeAtFocus('', e);
        break;

      case e.keyCode === LEFT_ARROW || e.key === 'ArrowLeft':
        e.preventDefault();
        focusPrevInput();
        break;

      case e.keyCode === RIGHT_ARROW || e.key === 'ArrowRight':
        e.preventDefault();
        focusNextInput();
        break;

      case e.keyCode === SPACEBAR || e.key === ' ' || e.key === 'Spacebar' || e.key === 'Space':
        e.preventDefault();
        break;
    }
  };

  var handleOnInput = function handleOnInput(e) {
    if (isInputValueValid(e.target.value)) {
      focusNextInput();
    } else {
      if (!numberOnly) {
        var nativeEvent = e.nativeEvent;

        if (nativeEvent.data === null && nativeEvent.inputType === 'deleteContentBackward') {
          e.preventDefault();
          changeCodeAtFocus('', e);
          focusPrevInput();
        }
      }
    }
  };

  var renderInputs = function renderInputs() {
    var otp = getValue();
    var inputs = [];

    var _loop = function _loop(i) {
      inputs.push(React.createElement(SingleInput, {
        "data-unify": "OTPField",
        key: i,
        focus: activeInput === i,
        value: otp && otp[i],
        onChange: handleOnChange,
        onKeyDown: handleOnKeyDown,
        onInput: handleOnInput,
        onPaste: handleOnPaste,
        onFocus: function onFocus(e) {
          return handleFocus(e, i);
        },
        onBlur: function onBlur() {
          return setActive(-1);
        },
        disabled: disabled,
        error: error,
        numberOnly: numberOnly,
        pinMode: pinMode,
        type: numberOnly ? 'tel' : 'text',
        placeholder: pinMode ? '•' : '',
        darkMode: darkMode,
        "aria-label": rest['aria-label'] ? "".concat(rest['aria-label'], ". Character ").concat(i + 1) : null
      }));
    };

    for (var i = 0; i < length; i++) {
      _loop(i);
    }

    return inputs;
  };

  var handleUnderline = function handleUnderline() {
    switch (true) {
      case disabled:
        return '';

      case error:
        return 'unf-otp-field__underline--error';

      case activeInput !== -1:
        return 'unf-otp-field__underline--active';

      default:
        return '';
    }
  };

  return React.createElement("div", _extends({
    className: wrapperStyle,
    "data-unify": "OTPField"
  }, rest), React.createElement("div", {
    className: "unf-otp-field__input-group"
  }, renderInputs()), React.createElement("div", {
    className: cx('unf-otp-field__underline', handleUnderline())
  }));
};

OTPField.defaultProps = {
  value: ''
};
export default OTPField;