import _extends from "@babel/runtime/helpers/extends";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["activeColor", "baseColor", "currentPage", "dataTest", "inverted", "lang", "numberOfPage", "timed", "variant", "onIndicatorClick"];
import React, { useRef, useEffect, forwardRef } from 'react';
import { activeColors, baseColors, Container, Item } from "./style";
import WrapperScroll from "./WrapperScroll";
var LANG_COPY = {
  en: 'Go to slide ',
  id: 'Ke slide '
};
var PageControl = forwardRef(function (_ref, ref) {
  var activeColor = _ref.activeColor,
      baseColor = _ref.baseColor,
      _ref$currentPage = _ref.currentPage,
      currentPage = _ref$currentPage === void 0 ? 0 : _ref$currentPage,
      dataTest = _ref.dataTest,
      _ref$inverted = _ref.inverted,
      inverted = _ref$inverted === void 0 ? false : _ref$inverted,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      numberOfPage = _ref.numberOfPage,
      _ref$timed = _ref.timed,
      timed = _ref$timed === void 0 ? false : _ref$timed,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'green' : _ref$variant,
      onIndicatorClick = _ref.onIndicatorClick,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var itemRef = useRef(null);
  var content = typeof numberOfPage === 'number' ? _toConsumableArray(Array(numberOfPage).fill(null)) : numberOfPage;
  var theActiveColor = activeColor ? activeColor : activeColors[String(variant)];
  var theBaseColor = baseColor ? baseColor : baseColors[String(variant)];
  useEffect(function () {
    if (inverted) {
      console.warn('[Unify PageControl] Deprecation Warning: Props `inverted` will be deprecated soon. Please use props `variant="white"` instead.');
    }
  }, [inverted]);

  var renderItems = function renderItems() {
    var tempActiveColor = inverted ? activeColors.white : theActiveColor;
    var tempBaseColor = inverted ? baseColors.white : theBaseColor;
    var contentLength = typeof numberOfPage === 'number' ? numberOfPage : numberOfPage.length;
    var renderItems = content.map(function (_, i) {
      return React.createElement(Item, _extends({
        active: currentPage === i,
        activeColor: tempActiveColor,
        activeSecond: currentPage > i,
        "aria-current": currentPage === i,
        baseColor: tempBaseColor,
        currentPage: currentPage,
        index: i,
        innerRef: currentPage === i ? itemRef : undefined,
        inverted: inverted,
        key: i,
        last: i === contentLength - 1,
        length: content.length,
        timed: timed,
        onClick: function onClick() {
          typeof onIndicatorClick === 'function' ? onIndicatorClick(i) : undefined;
        }
      }, dataTest ? {
        'data-testid': dataTest + i
      } : {}), "".concat(LANG_COPY[lang]).concat(i + 1));
    });

    if (timed) {
      return renderItems;
    } else {
      return React.createElement(WrapperScroll, {
        length: content.length,
        active: currentPage,
        id: "scroll-test"
      }, renderItems);
    }
  };

  return React.createElement(Container, _extends({
    innerRef: ref,
    "aria-label": "unf-pagecontrol",
    "data-unify": "PageControl",
    numberOfPage: numberOfPage
  }, otherProps), renderItems());
});
PageControl.displayName = 'PageControl';
export default PageControl;