import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["activeProps", "activeIndex", "baseURL", "items", "itemProps", "lang", "nextProps", "pageParamName", "prevProps", "onChange", "onClickItem", "onClickNext", "onClickPrev"];
import React, { useEffect, useState, useRef } from 'react';
import { ChevronRight } from 'unify-icons/system';
import { NN300, NN900 } from 'unify-token/colors';
import { Container, Item, ItemButton, ItemContainer, NavButton, NavItem } from "./style";
import { clamp, getBaseItems, getMappableItems, omitURLParam } from "./utils";

var Pagination = function Pagination(_ref) {
  var activeProps = _ref.activeProps,
      _ref$activeIndex = _ref.activeIndex,
      activeIndex = _ref$activeIndex === void 0 ? 0 : _ref$activeIndex,
      _ref$baseURL = _ref.baseURL,
      baseURL = _ref$baseURL === void 0 ? '' : _ref$baseURL,
      _ref$items = _ref.items,
      items = _ref$items === void 0 ? [] : _ref$items,
      itemProps = _ref.itemProps,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      nextProps = _ref.nextProps,
      _ref$pageParamName = _ref.pageParamName,
      pageParamName = _ref$pageParamName === void 0 ? 'page' : _ref$pageParamName,
      prevProps = _ref.prevProps,
      onChange = _ref.onChange,
      onClickItem = _ref.onClickItem,
      onClickNext = _ref.onClickNext,
      onClickPrev = _ref.onClickPrev,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var totalItems = Array.isArray(items) ? items.length : items;
  var hasItems = totalItems && totalItems > 1;
  var maxItemIndex = totalItems && totalItems - 1 || 0;

  var clampIndex = function clampIndex(index) {
    return clamp(index, 0, maxItemIndex);
  };

  var activeItemElement = useRef(null);

  var _useState = useState(clampIndex(activeIndex)),
      _useState2 = _slicedToArray(_useState, 2),
      currentIndex = _useState2[0],
      currentIndexSet = _useState2[1];

  var currentPage = currentIndex + 1;
  var hasBaseURL = baseURL !== '';
  var atStartIndex = currentIndex === 0;
  var atEndIndex = currentIndex === totalItems - 1;
  var ariaLabels = {
    id: {
      prevButton: 'Laman sebelumnya',
      nextButton: 'Laman berikutnya',
      container: 'Navigasi laman'
    },
    en: {
      prevButton: 'Previous page',
      nextButton: 'Next page',
      container: 'Page navigation'
    }
  };

  var syncActiveIndex = function syncActiveIndex() {
    var clampedIndex = clampIndex(activeIndex);

    if (clampedIndex !== currentIndex) {
      currentIndexSet(clampedIndex);

      if (onChange) {
        onChange({
          currentIndex: clampedIndex,
          currentPage: clampedIndex + 1,
          previousPage: currentIndex + 1,
          totalPage: totalItems
        });
      }
    }
  };

  useEffect(syncActiveIndex, [activeIndex, items]);

  var gotoPage = function gotoPage(index) {
    currentIndexSet(index);

    if (onChange) {
      onChange({
        currentIndex: index,
        currentPage: clampIndex(index + 1),
        previousPage: currentIndex + 1,
        totalPage: totalItems
      });
    }
  };

  var handleItemClick = function handleItemClick(index, event) {
    event.preventDefault();
    var currentPage = index + 1;
    gotoPage(index);

    if (onClickItem) {
      onClickItem(currentPage, event);
    }
  };

  var handleNextClick = function handleNextClick(event) {
    event.preventDefault();

    if (atEndIndex) {
      return;
    }

    var index = clampIndex(currentIndex + 1);
    gotoPage(index);

    if (onClickNext) {
      onClickNext(event);
    }
  };

  var handlePrevClick = function handlePrevClick(event) {
    event.preventDefault();

    if (atStartIndex) {
      return;
    }

    var index = clampIndex(currentIndex - 1);
    gotoPage(index);

    if (onClickPrev) {
      onClickPrev(event);
    }
  };

  var renderItems = function renderItems() {
    var baseItems = getBaseItems(items);
    var mappableItems = getMappableItems(baseItems, currentIndex);
    var renderedItems = mappableItems.map(function (item, id) {
      var hiddenItemLabel = '...';
      var isHiddenItem = item === -1;
      var itemLabel = isHiddenItem ? hiddenItemLabel : Number(item).toLocaleString(lang);
      var itemIndex = item - 1;
      var isCurrentIndex = itemIndex === currentIndex;
      var itemURL = getItemURLForPage();
      var isButtonItem = isHiddenItem || !hasBaseURL;
      var ItemTag = isButtonItem ? ItemButton : Item;
      var hrefProp = isButtonItem ? {} : {
        href: itemURL
      };
      var additionalProps = isCurrentIndex ? activeProps : itemProps;

      var additionalItemProps = _objectSpread(_objectSpread({}, hrefProp), additionalProps);

      var ariaLabel = {
        en: "".concat(isCurrentIndex ? 'Current page, ' : '', "Page ").concat(item),
        id: "".concat(isCurrentIndex ? 'Laman saat ini, ' : '', "Laman ").concat(item)
      };

      function getItemURLForPage() {
        var isStartPage = item === 1;
        var url = "".concat(baseURL).concat(item);

        if (hasBaseURL) {
          if (isStartPage) {
            return omitURLParam(url, pageParamName);
          }

          return url;
        }

        return baseURL;
      }

      return React.createElement("li", {
        key: "page-".concat(item, "-").concat(id)
      }, React.createElement(ItemTag, _extends({
        active: isCurrentIndex,
        "aria-label": ariaLabel[String(lang)],
        "aria-current": isCurrentIndex,
        "data-unf": "pagination-item",
        disabled: isHiddenItem,
        innerRef: isCurrentIndex ? activeItemElement : null,
        onClick: function onClick(event) {
          return handleItemClick(itemIndex, event);
        }
      }, additionalItemProps), itemLabel));
    });
    return renderedItems;
  };

  var getPrevURL = function getPrevURL() {
    if (hasBaseURL && !atStartIndex) {
      var url = "".concat(baseURL).concat(currentPage - 1);
      return {
        href: currentPage === 2 ? omitURLParam(url, pageParamName) : url
      };
    }

    return {};
  };

  var getNextURL = function getNextURL() {
    if (hasBaseURL && !atEndIndex) {
      var url = "".concat(baseURL).concat(currentPage + 1);
      return {
        href: url
      };
    }

    return {};
  };

  var PrevButton = atStartIndex || !hasBaseURL ? NavButton : NavItem;
  var NextButton = atEndIndex || !hasBaseURL ? NavButton : NavItem;
  var prevHrefProp = getPrevURL();
  var nextHrefProp = getNextURL();
  return hasItems ? React.createElement("nav", _extends({
    className: Container,
    "aria-label": ariaLabels[String(lang)].container
  }, otherProps, {
    "data-unify": "Pagination"
  }), React.createElement("ul", {
    className: ItemContainer
  }, React.createElement("li", null, React.createElement(PrevButton, _extends({
    "aria-label": ariaLabels[String(lang)].prevButton,
    disabled: atStartIndex,
    prev: true,
    onClick: handlePrevClick
  }, prevHrefProp, prevProps), React.createElement(ChevronRight, {
    rotation: 180,
    color: atStartIndex ? NN300 : NN900
  }))), renderItems(), React.createElement("li", null, React.createElement(NextButton, _extends({
    "aria-label": ariaLabels[String(lang)].nextButton,
    disabled: atEndIndex,
    next: true,
    onClick: handleNextClick
  }, nextHrefProp, nextProps), React.createElement(ChevronRight, {
    color: atEndIndex ? NN300 : NN900
  }))))) : null;
};

export default Pagination;