import React from 'react';
interface ItemChangeProps {
    currentIndex?: number;
    currentPage?: number;
    previousPage?: number;
    totalPage?: number;
}
declare type PaginationAttributes = React.ComponentProps<'div'>;
declare type ItemProps = React.ComponentPropsWithoutRef<'button'> | React.ComponentPropsWithoutRef<'a'>;
export interface PaginationBaseProps {
    /**
     * Set active pagination item by 0-based index
     */
    activeIndex?: number;
    /**
     * Insert additional props to active pagination item
     */
    activeProps?: ItemProps;
    /**
     * Set base URL for pagination item links
     */
    baseURL?: string;
    /**
     * Insert additional props to non-active pagination item
     */
    itemProps?: ItemProps;
    /**
     * Set number of pagination items
     */
    items?: number[] | number;
    /**
     * To specify a11y label language
     */
    lang?: string;
    /**
     * Insert additional props to next button
     */
    nextProps?: ItemProps;
    /**
     * Determine name of page URL parameter
     */
    pageParamName?: string;
    /**
     * Insert additional props to prev button
     */
    prevProps?: ItemProps;
    /**
     * Set a callback function if active pagination item change. `({ currentIndex, currentPage, previousPage, totalPage, }) => void;`
     */
    onChange?: (itemChange: ItemChangeProps) => void;
    /**
     * Set a callback function if user click on item. `(currentPage, event) => void;`
     */
    onClickItem?: (currentPage: number, e: React.MouseEvent<HTMLButtonElement | HTMLAnchorElement>) => void;
    /**
     * Set a callback function if user click next button. `(event) => void;`
     */
    onClickNext?: (e: React.MouseEvent<HTMLButtonElement | HTMLAnchorElement>) => void;
    /**
     * Set a callback function if user click prev button. `(event) => void;`
     */
    onClickPrev?: (e: React.MouseEvent<HTMLButtonElement | HTMLAnchorElement>) => void;
}
export declare type PaginationProps = PaginationBaseProps & Omit<PaginationAttributes, keyof PaginationBaseProps>;
export {};
