import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
export function clamp(number) {
  var min = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  var max = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 10;

  if (number > max) {
    return max;
  } else if (number < min) {
    return min;
  }

  return number;
}
export function getPageRange(itemArray, from, to) {
  if (Array.isArray(itemArray)) {
    if (from !== to) {
      return itemArray.slice(from, to + 1);
    }

    return [from + 1];
  }

  return [];
}
export function omitURLParam(url, paramName) {
  try {
    var searchURL = new URL(url);
    var hasPageParam = searchURL.searchParams.has(paramName);

    if (hasPageParam) {
      searchURL.searchParams["delete"](paramName);
      return searchURL.toString();
    }

    return url;
  } catch (err) {
    console.warn('Oops, it looks like URL provided is invalid.', err);
    return url;
  }
}
export function getBaseItems(items) {
  var isNumber = typeof items === 'number';
  var isArray = Array.isArray(items);

  switch (true) {
    case isNumber:
      {
        var arrayItems = [];

        for (var i = 0; i < items; i++) {
          arrayItems.push(i + 1);
        }

        return arrayItems;
      }

    case isArray:
      return Array.isArray(items) ? items : [];

    default:
      return [];
  }
}
export function getMappableItems(baseItems, currentIndex) {
  var totalPageItem = baseItems.length;
  var maxPageItem = 5;
  var nearEdgeItems = 3;
  var activePageNeighbor = 0;

  function getMidItemsArray() {
    var isNearStart = currentIndex < nearEdgeItems;
    var isNearEnd = currentIndex >= totalPageItem - nearEdgeItems;
    var nearStartItemArray = baseItems.slice(0, nearEdgeItems);
    var nearEndItemArray = baseItems.slice(-nearEdgeItems);

    if (isNearStart) {
      return [].concat(_toConsumableArray(nearStartItemArray), [-1]);
    } else if (isNearEnd) {
      return [-1].concat(_toConsumableArray(nearEndItemArray));
    }

    var fromIndex = currentIndex - activePageNeighbor;
    var toIndex = currentIndex + activePageNeighbor;
    var midItemArray = getPageRange(baseItems, fromIndex, toIndex);
    return [-1].concat(_toConsumableArray(midItemArray), [-1]);
  }

  if (totalPageItem > maxPageItem) {
    var firstItem = 1;
    var lastItem = baseItems[totalPageItem - 1];

    var excludeFirstLast = function excludeFirstLast(item) {
      return item !== firstItem && item !== lastItem;
    };

    var midItems = getMidItemsArray().filter(excludeFirstLast);
    return [firstItem].concat(_toConsumableArray(midItems), [lastItem]);
  }

  return baseItems || [];
}