import _extends from "@babel/runtime/helpers/extends";
import _typeof from "@babel/runtime/helpers/typeof";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["backgroundColor", "color", "full", "indicator", "info", "margin", "padding", "sideIndicator", "size", "value", "onChange"];
import React, { useState, useEffect, useRef, createRef, isValidElement } from 'react';
import { NN600, NN950 } from 'unify-token/colors';
import Typography from "../../build/Typography";
import { addClass, debounce, removeClass } from "../../build/Providers/common/functions";
import { Bar, BarContainer, BarWrapper, Container, Content, IndicatorContainer, Indicator, InfoWrapper, Pointer, SideIndicator, IndicatorWrapper } from "./style";
var DEBOUNCE_TIMEOUT = 280;

var ProgressBar = function ProgressBar(_ref) {
  var backgroundColor = _ref.backgroundColor,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'green' : _ref$color,
      full = _ref.full,
      indicator = _ref.indicator,
      info = _ref.info,
      margin = _ref.margin,
      padding = _ref.padding,
      sideIndicator = _ref.sideIndicator,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? 0 : _ref$value,
      onChange = _ref.onChange,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var hasIndicator = indicator && indicator.length > 0;

  var _useState = useState(value),
      _useState2 = _slicedToArray(_useState, 2),
      progressValue = _useState2[0],
      setProgressValue = _useState2[1];

  var prevProgressValue = useRef(value);
  var containerRef = useRef(null);
  var barWrapperRef = useRef(null);
  var indicatorContainerRef = useRef(null);
  var pointerRefs = useRef(hasIndicator ? indicator.map(function () {
    return createRef();
  }) : null);
  var contentRefs = useRef(hasIndicator ? indicator.map(function () {
    return createRef();
  }) : null);
  useEffect(function () {
    prevProgressValue.current = progressValue;
    setProgressValue(value);
  }, [value]);
  var prevValue = prevProgressValue.current;

  var handleAfterResize = function handleAfterResize() {
    var container = indicatorContainerRef.current;

    if (barWrapperRef.current && containerRef.current && container) {
      var width = barWrapperRef.current.offsetWidth;
      containerRef.current.style.overflowX = '';
      container.style.width = "".concat(width, "px");
    }
  };

  var resetIndicatorWidth = function resetIndicatorWidth() {
    if (indicatorContainerRef.current !== null) {
      var container = indicatorContainerRef.current;
      container.style.width = '';
    }
  };

  var handleEdgeAlignment = function handleEdgeAlignment(type) {
    var _indicatorContainerRe;

    var containerWidth = ((_indicatorContainerRe = indicatorContainerRef.current) === null || _indicatorContainerRe === void 0 ? void 0 : _indicatorContainerRe.offsetWidth) || 1;
    var indicatorWrapper = type === 'pointer' ? pointerRefs.current : contentRefs.current;
    indicator && indicator.map(function (indicatorData, indicatorIndex) {
      var _ref2 = indicatorData,
          position = _ref2.position;

      if (position !== undefined) {
        var wrapper = indicatorWrapper && indicatorWrapper[indicatorIndex].current;

        if (wrapper) {
          var wrapperLeft = wrapper.offsetLeft;
          var item = wrapper.children[0];
          var itemWidth = item.offsetWidth;
          var startBoundary = (wrapperLeft - itemWidth / 2) / containerWidth * 100;
          var endBoundary = (wrapperLeft + itemWidth / 2) / containerWidth * 100;
          startBoundary <= 0 ? addClass('unf-js-pbie-start', wrapper) : removeClass('unf-js-pbie-start', wrapper);
          endBoundary >= 100 ? addClass('unf-js-pbie-end', wrapper) : removeClass('unf-js-pbie-end', wrapper);
        }
      }
    });
  };

  var handleDebounce = debounce(handleAfterResize, DEBOUNCE_TIMEOUT);

  var handleResizeOverflow = function handleResizeOverflow() {
    if (containerRef.current) {
      containerRef.current.style.overflowX = 'hidden';
    }
  };

  useEffect(function () {
    if (sideIndicator) {
      hasIndicator && window.addEventListener('resize', handleResizeOverflow);
      hasIndicator && window.addEventListener('resize', handleDebounce);
    }

    return function () {
      window.removeEventListener('resize', handleResizeOverflow);
      window.removeEventListener('resize', handleDebounce);
    };
  }, [indicator, sideIndicator, handleDebounce, hasIndicator]);
  useEffect(function () {
    if (sideIndicator) {
      hasIndicator && setTimeout(function () {
        return handleAfterResize();
      }, DEBOUNCE_TIMEOUT);
    } else {
      hasIndicator && setTimeout(function () {
        return resetIndicatorWidth();
      }, DEBOUNCE_TIMEOUT);
    }
  }, [margin, padding, sideIndicator]);
  useEffect(function () {
    if (hasIndicator) {
      handleEdgeAlignment('pointer');
      handleEdgeAlignment('content');
    }
  }, [indicator]);
  useEffect(function () {
    onChange && onChange(progressValue, prevValue);
  }, [progressValue]);

  var renderSideIndicator = function renderSideIndicator() {
    var type = _typeof(sideIndicator);

    if (type === 'number') {
      return React.createElement("div", {
        className: SideIndicator
      }, "".concat(sideIndicator, "%"));
    } else if (type === 'string' || isValidElement(sideIndicator)) {
      return React.createElement("div", {
        className: SideIndicator
      }, sideIndicator);
    }

    return null;
  };

  var renderIndicator = function renderIndicator(ref, type) {
    return indicator && indicator.map(function (data, index, array) {
      var sharedProps = {
        index: index,
        array: array
      };
      var _ref3 = data,
          content = _ref3.content,
          _ref3$pointer = _ref3.pointer,
          pointer = _ref3$pointer === void 0 ? true : _ref3$pointer,
          pointerOpacity = _ref3.pointerOpacity,
          position = _ref3.position;
      return React.createElement(Indicator, _extends({
        key: index,
        innerRef: ref.current && ref.current[index],
        position: position
      }, sharedProps), type === 'pointer' ? React.createElement(Pointer, _extends({
        pointer: pointer,
        pointerOpacity: pointerOpacity,
        position: position
      }, sharedProps)) : React.createElement(Content, _extends({
        pointer: pointer,
        position: position
      }, sharedProps), content ? content : React.createElement(Typography, {
        body: "paragraph-3",
        color: NN600,
        margin: "0"
      }, data)));
    });
  };

  var renderInfo = function renderInfo() {
    return info && React.createElement("div", {
      className: InfoWrapper
    }, info.icon && React.createElement("div", {
      className: "unf-pbinfo__icon--wrapper"
    }, React.createElement("img", {
      src: info.icon,
      alt: "Info Icon"
    })), React.createElement("div", null, info.title && React.createElement("div", {
      className: "unf-pbinfo__content--wrapper",
      style: {
        marginBottom: info.subtitle ? '4px' : '0'
      }
    }, React.createElement(Typography, {
      body: "display-2",
      color: NN950,
      margin: "0"
    }, info.title), info.titleIcon && React.createElement("div", {
      className: "unf-pbinfo__content-icon--wrapper"
    }, React.createElement("img", {
      src: info.titleIcon,
      alt: "Info Title Icon"
    }))), info.subtitle && React.createElement("div", {
      className: "unf-pbinfo__content--wrapper"
    }, React.createElement(Typography, {
      body: "paragraph-3",
      color: NN600,
      margin: "0"
    }, info.subtitle), info.subtitleIcon && React.createElement("div", {
      className: "unf-pbinfo__content-icon--wrapper"
    }, React.createElement("img", {
      src: info.subtitleIcon,
      alt: "Info Subtitle Icon"
    })))));
  };

  return React.createElement(Container, _extends({
    innerRef: containerRef,
    "aria-label": "progressbar",
    margin: margin,
    padding: padding,
    "data-unify": "ProgressBar"
  }, otherProps), renderInfo(), React.createElement("div", {
    className: BarContainer
  }, React.createElement(BarWrapper, {
    full: full,
    innerRef: barWrapperRef,
    size: size,
    backgroundColor: backgroundColor
  }, React.createElement(Bar, {
    role: "progressbar",
    "aria-valuenow": progressValue,
    "aria-valuemin": 0,
    "aria-valuemax": 100,
    color: color,
    full: full,
    value: progressValue
  })), sideIndicator && renderSideIndicator()), hasIndicator && React.createElement(IndicatorContainer, {
    sideIndicator: sideIndicator,
    innerRef: indicatorContainerRef
  }, React.createElement("div", {
    className: IndicatorWrapper
  }, renderIndicator(pointerRefs, 'pointer')), React.createElement("div", {
    className: IndicatorWrapper
  }, renderIndicator(contentRefs, 'content'))));
};

export default ProgressBar;