import styled, { css } from 'react-emotion';
import { fontSizeLv2, lineHeightLv3, trackingRAWWide } from 'unify-token/build/v2/typographies';
import { durationDefault, durationT5, easeDefault, easeInOut } from 'unify-token/build/v2/motions';
import { GN400, GN500, NN100, NN600, RN600L, YN300L, YN500L } from 'unify-token/colors';
import styleHandler from "../../build/Providers/common/functions/styleHandler";
var INDICATOR_MARGIN_TOP_MAX = 8;
var INDICATOR_MARGIN_TOP_MIN = 2;
var POINTER_DIMENSION = 6;
var POINTER_MARGIN_BOTTOM = 2;

var handleColor = function handleColor(color) {
  return styleHandler(color, {
    red: "var(--RN400, ".concat(RN600L, ")"),
    green: GN400,
    orange: "var(--YN400, ".concat(YN500L, ")"),
    yellow: "var(--YN700, ".concat(YN300L, ")")
  }, GN500);
};

var handleSize = function handleSize(size) {
  return styleHandler(size, {
    large: '8px',
    medium: '6px',
    small: '4px'
  }, '6px');
};

var handleTranslate = function handleTranslate(index, array, position) {
  var arrayLength = array.length;

  if (position === undefined) {
    if (index === 0) {
      return undefined;
    } else if (index === arrayLength - 1) {
      return 'translateX(-100%)';
    }
  }

  return 'translateX(-50%)';
};

export var Container = styled("div", {
  target: "eozwrve0"
})("label:unf-PB;margin:", function (_ref) {
  var margin = _ref.margin;
  return margin ? margin : undefined;
}, ";padding:", function (_ref2) {
  var padding = _ref2.padding;
  return padding ? padding : undefined;
}, ";");
export var BarContainer = css("label:unf-PBB;display:flex;align-items:center;");
export var BarWrapper = styled("div", {
  target: "eozwrve1"
})("width:100%;border-radius:", function (_ref3) {
  var full = _ref3.full;
  return full ? '0' : '4px';
}, ";overflow:hidden;transition-property:background-color,height;transition-duration:", durationDefault, ";transition-timing-function:", easeDefault, ";height:", function (_ref4) {
  var size = _ref4.size;
  return handleSize(size);
}, ";background-color:", function (_ref5) {
  var backgroundColor = _ref5.backgroundColor;
  return backgroundColor ? backgroundColor : NN100;
}, ";");
export var Bar = styled("div", {
  target: "eozwrve2"
})("height:100%;border-radius:", function (_ref6) {
  var full = _ref6.full;
  return full ? '0 4px 4px 0' : '4px';
}, ";transition-property:width,background-color;transition-duration:", durationT5, ";transition-timing-function:", easeInOut, ";width:", function (_ref7) {
  var value = _ref7.value;
  return value ? value : 0;
}, "%;background-color:", function (_ref8) {
  var color = _ref8.color;
  return handleColor(color);
}, ";");
export var SideIndicator = css("min-width:35px;flex:1 0 auto;font-size:", fontSizeLv2, ";line-height:", lineHeightLv3, ";letter-spacing:", trackingRAWWide, "px;color:", NN600, ";margin-left:8px;");
export var IndicatorContainer = styled("div", {
  target: "eozwrve3"
})("label:unf-PBI;width:100%;margin-top:", function (_ref9) {
  var sideIndicator = _ref9.sideIndicator;
  return sideIndicator ? INDICATOR_MARGIN_TOP_MIN : INDICATOR_MARGIN_TOP_MAX;
}, "px;transition:width 280ms ease;will-change:width;");
export var IndicatorWrapper = css("display:flex;position:relative;& + &{margin-top:", POINTER_MARGIN_BOTTOM, "px;}");
export var Indicator = styled('div', {
  target: "eozwrve4"
})("width:0;display:flex;position:relative;left:", function (_ref10) {
  var index = _ref10.index,
      array = _ref10.array,
      position = _ref10.position;
  return position !== undefined ? "".concat(position, "%") : "".concat(100 / (array.length - 1) * index, "%");
}, ";&.unf-js-pbie-start{left:0%;}&.unf-js-pbie-end{left:100%;}");
export var Pointer = styled("div", {
  target: "eozwrve5"
})("width:", POINTER_DIMENSION, "px;height:", POINTER_DIMENSION, "px;background-color:", NN100, ";border-radius:3px;flex:1 0 6px;will-change:transform;display:", function (_ref11) {
  var pointer = _ref11.pointer;
  return pointer ? undefined : 'none';
}, ";opacity:", function (_ref12) {
  var pointerOpacity = _ref12.pointerOpacity;
  return pointerOpacity;
}, ";transform:", function (_ref13) {
  var index = _ref13.index,
      array = _ref13.array,
      position = _ref13.position;
  return handleTranslate(index, array, position);
}, ";.unf-js-pbie-start &{transform:translateX(0%);}.unf-js-pbie-end &{transform:translateX(-100%);}");
export var Content = styled('div', {
  target: "eozwrve6"
})("color:", NN600, ";font-size:", fontSizeLv2, ";line-height:", lineHeightLv3, ";letter-spacing:", trackingRAWWide, "px;white-space:nowrap;will-change:transform;margin-top:", function (_ref14) {
  var pointer = _ref14.pointer;
  return pointer ? undefined : "-".concat(POINTER_DIMENSION + POINTER_MARGIN_BOTTOM, "px");
}, ";transform:", function (_ref15) {
  var index = _ref15.index,
      array = _ref15.array,
      position = _ref15.position;
  return handleTranslate(index, array, position);
}, ";.unf-js-pbie-start &{transform:translateX(0%);}.unf-js-pbie-end &{transform:translateX(-100%);}");
export var InfoWrapper = css("label:unf-PBInfo;display:flex;align-items:center;gap:8px;margin-bottom:4px;img{width:100%;}.unf-pbinfo__icon--wrapper{height:24px;width:24px;}.unf-pbinfo__content--wrapper{display:flex;align-items:center;gap:4px;.unf-pbinfo__content-icon--wrapper{height:16px;width:16px;}}");