import React from 'react';
declare type ProgressBarAttributes = React.ComponentPropsWithoutRef<'div'>;
export interface ProgressBarBaseProps {
    /**
     * Set the background color of the ProgressBar.
     */
    backgroundColor?: string;
    /**
     * Set the color of the bar.
     */
    color?: string;
    /**
     * To apply full ProgressBar design.
     */
    full?: boolean;
    /**
     * Set the bottom indicator fo the ProgressBar, without any additional settings, it will separate each indicator evenly.
     * You can also customize each individual indicator by passing an *object*.
     */
    indicator?: (string | number | IndicatorProps | React.ReactNode)[];
    /**
     * Set the info content like icon, title, and subtitle for the ProgressBar.
     */
    info?: InfoProps;
    /**
     * Set the margin of the ProgressBar.
     */
    margin?: string;
    /**
     * Set the padding of the ProgressBar.
     */
    padding?: string;
    /**
     * Set the side indicator on the right side of the ProgressBar.
     */
    sideIndicator?: string | number | React.ReactNode;
    /**
     * Set the size of the ProgressBar, you can set the size outside the predefined size by just inputting it.
     */
    size?: string;
    /**
     * Set the current progress of the ProgressBar in percentage.
     */
    value?: number;
    /**
     * Callback whenever the ProgressBar value changed.
     */
    onChange?: (val: number, prevVal: number) => void;
}
export declare type ProgressBarProps = ProgressBarBaseProps & Omit<ProgressBarAttributes, keyof ProgressBarBaseProps | 'css'>;
export interface IndicatorProps {
    content: string | number | React.ReactNode;
    pointer?: boolean;
    pointerOpacity?: number;
    position?: number;
}
export interface InfoProps {
    icon?: string;
    subtitle?: string;
    subtitleIcon?: string;
    title?: string;
    titleIcon?: string;
}
export {};
