import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["show", "spacing", "targetRef", "delay", "children", "placement", "onClickOutside"];
import React, { useEffect, useRef, useState } from 'react';
import { canUseDOM } from "../../../../../build/Providers/common/functions";
import Portal from "../Portal";
import getViewport from "../../functions/getViewport";
import checkFunction from "../../functions/isFunction";
export { default as PopupTrigger } from "./PopupTrigger";
var ALT_PLACEMENT = {
  left: 'right',
  right: 'left',
  top: 'bottom',
  bottom: 'top'
};
var UNMOUNT_DELAY = 120;

var Popup = function Popup(props) {
  var show = props.show,
      spacing = props.spacing,
      targetRef = props.targetRef,
      delay = props.delay,
      children = props.children,
      propsPlacement = props.placement,
      onClickOutside = props.onClickOutside,
      otherProps = _objectWithoutProperties(props, _excluded);

  var popperRef = useRef();

  var _useState = useState(propsPlacement),
      _useState2 = _slicedToArray(_useState, 2),
      placement = _useState2[0],
      setPlacement = _useState2[1];

  var _useState3 = useState({
    left: 0,
    top: 0
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      menuPos = _useState4[0],
      setMenuPos = _useState4[1];

  var _useState5 = useState(''),
      _useState6 = _slicedToArray(_useState5, 2),
      arrowStyle = _useState6[0],
      setArrowStyle = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      display = _useState8[0],
      setDisplay = _useState8[1];

  var timeout = useRef();

  var getMenuPosition = function getMenuPosition() {
    if (canUseDOM) {
      var toggleRect = targetRef.current ? targetRef.current.getBoundingClientRect() : {};
      var menuRect = popperRef.current ? popperRef.current.getBoundingClientRect() : {};
      var viewport = getViewport();

      if (menuRect.height) {
        var _calcMenuPosition = calcMenuPosition(propsPlacement, menuRect, toggleRect, viewport),
            _calcMenuPosition2 = _slicedToArray(_calcMenuPosition, 4),
            top = _calcMenuPosition2[0],
            left = _calcMenuPosition2[1],
            arrowPos = _calcMenuPosition2[2],
            menuPlacement = _calcMenuPosition2[3];

        if (['left', 'right'].includes(placement) && (left <= 0 + window.pageXOffset || left + menuRect.width >= viewport.width + window.pageXOffset) || ['top', 'bottom'].includes(placement) && (top <= 0 + window.pageYOffset || top + menuRect.height >= viewport.height + window.pageYOffset)) {
          var _calcMenuPosition3 = calcMenuPosition(ALT_PLACEMENT[propsPlacement], menuRect, toggleRect, viewport);

          var _calcMenuPosition4 = _slicedToArray(_calcMenuPosition3, 4);

          top = _calcMenuPosition4[0];
          left = _calcMenuPosition4[1];
          arrowPos = _calcMenuPosition4[2];
          menuPlacement = _calcMenuPosition4[3];
        }

        setPlacement(menuPlacement);
        setMenuPos({
          left: left,
          top: top
        });
        setArrowStyle(arrowPos);
      }
    }
  };

  var calcMenuPosition = function calcMenuPosition(placement, menuRect, toggleRect, viewport) {
    var left = leftCalc(placement, toggleRect, menuRect);
    var top = topCalc(placement, toggleRect, menuRect);
    var arrowX = 0;
    var arrowY = 0;

    if (['top', 'bottom'].includes(placement)) {
      if (left + menuRect.width > viewport.width + window.pageXOffset) {
        left = viewport.width + window.pageXOffset - menuRect.width - spacing;

        if (left + menuRect.width < toggleRect.right) {
          left = toggleRect.right - menuRect.width;
        }
      }

      if (left < 0 + window.pageXOffset) {
        left = spacing + window.pageXOffset;

        if (left > toggleRect.left + window.pageXOffset) {
          left = toggleRect.left + window.pageXOffset;
        }
      }

      arrowX = toggleRect.left + toggleRect.width / 2 + window.pageXOffset - (left + menuRect.width / 2);
    }

    if (['left', 'right'].includes(placement)) {
      if (top < 0 + window.pageYOffset) {
        top = spacing + window.pageYOffset;

        if (top > toggleRect.top + window.pageYOffset) {
          top = toggleRect.top + window.pageYOffset;
        }
      }

      if (top + menuRect.height > viewport.height + window.pageYOffset) {
        top = viewport.height + window.pageYOffset - spacing - menuRect.height;

        if (top + menuRect.height < toggleRect.bottom) {
          top = toggleRect.bottom - menuRect.height;
        }
      }

      arrowY = toggleRect.top + toggleRect.height / 2 + window.pageYOffset - (top + menuRect.height / 2);
    }

    var arrowPos = arrowPosition(placement, arrowX, arrowY);
    return [top, left, arrowPos, placement];
  };

  var topCalc = function topCalc(placement, toggleRect, menuRect) {
    if (placement === 'bottom') {
      return toggleRect.bottom ? toggleRect.bottom + spacing + window.pageYOffset : 0;
    } else if (placement === 'top') {
      return toggleRect.top ? toggleRect.top + window.pageYOffset - menuRect.height - spacing : 0;
    } else {
      var middleToggle = toggleRect.top + window.pageYOffset + toggleRect.height / 2;
      return middleToggle - menuRect.height / 2;
    }
  };

  var leftCalc = function leftCalc(placement, toggleRect, menuRect) {
    if (placement === 'left') {
      return toggleRect.left ? toggleRect.left + window.pageXOffset - spacing - menuRect.width : 0;
    } else if (placement === 'right') {
      return toggleRect.right ? toggleRect.right + spacing + window.pageXOffset : 0;
    } else {
      var centerToggle = toggleRect.left + window.pageXOffset + toggleRect.width / 2;
      return centerToggle - menuRect.width / 2;
    }
  };

  var arrowPosition = function arrowPosition(placement) {
    var arrowX = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
    var arrowY = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
    var menuRect = popperRef.current ? popperRef.current.getBoundingClientRect() : {};
    var centerToggle = (menuRect.width - 16 * 2) / 2;
    var middleToggle = menuRect.height / 2;

    if (['left', 'right'].includes(placement)) {
      return "transform: translateY(".concat(middleToggle - 5 + arrowY, "px);");
    } else if (['top', 'bottom'].includes(placement)) {
      return "transform: translateX(".concat(centerToggle - 5 + arrowX, "px);");
    }

    return "";
  };

  var handleResize = function handleResize() {
    if (canUseDOM) {
      window.addEventListener('resize', getMenuPosition);
      return function cleanup() {
        window.removeEventListener('resize', getMenuPosition);
      };
    }
  };

  var handleScroll = function handleScroll() {
    if (canUseDOM) {
      window.addEventListener('scroll', getMenuPosition);
      return function cleanup() {
        window.removeEventListener('scroll', getMenuPosition);
      };
    }
  };

  useEffect(function () {
    if (show) {
      var delayShow = delay.show < 40 ? 40 : delay.show;
      timeout.current = setTimeout(function () {
        setDisplay(true);
      }, delayShow);
    } else {
      timeout.current = setTimeout(function () {
        setDisplay(false);
      }, delay.hide);
    }

    return function () {
      clearTimeout(timeout.current);
    };
  }, [delay.show, delay.hide, show]);
  useEffect(handleResize, []);
  useEffect(handleScroll, []);
  useEffect(getMenuPosition, [display, propsPlacement, spacing]);
  useEffect(function () {
    setPlacement(propsPlacement);
  }, [propsPlacement]);
  useEffect(function () {
    var handleClickOutside = function handleClickOutside(e) {
      if (!show || Boolean(popperRef.current) && Boolean(popperRef.current.contains) && popperRef.current.contains(e.target) || Boolean(targetRef.current) && targetRef.current.contains(e.target)) {
        return false;
      }

      onClickOutside(e);
    };

    if (onClickOutside) {
      document.addEventListener('mousedown', handleClickOutside);
      return function cleanup() {
        document.removeEventListener('mousedown', handleClickOutside);
      };
    }
  }, [onClickOutside, props, show, targetRef]);
  return React.createElement(Portal, {
    mounted: show,
    unmountAfter: delay.hide + UNMOUNT_DELAY
  }, canUseDOM && checkFunction(children) && children(_objectSpread({
    placement: placement,
    ref: popperRef,
    show: display,
    position: menuPos,
    arrowStyle: arrowStyle
  }, otherProps)));
};

Popup.defaultProps = {
  show: false,
  spacing: 12,
  placement: 'bottom',
  children: function children() {
    return {};
  },
  delay: {
    show: 0,
    hide: 0
  },
  targetRef: undefined
};
export default Popup;