import React, { useImperativeHandle, forwardRef, memo, useRef } from 'react';
import { easeInOut } from 'unify-token/build/v2/motions';
import { rippleStyle } from "./style";
var Ripple = forwardRef(function (props, ref) {
  var _props$duration = props.duration,
      duration = _props$duration === void 0 ? 300 : _props$duration,
      _props$color = props.color,
      color = _props$color === void 0 ? '#fff' : _props$color,
      _props$easing = props.easing,
      easing = _props$easing === void 0 ? easeInOut : _props$easing,
      _props$opacity = props.opacity,
      opacity = _props$opacity === void 0 ? '1' : _props$opacity;
  var rippleRef = useRef(null);

  var handleRipple = function handleRipple(target, rect, clientX, clientY) {
    if (target.getElementsByClassName('unf-animation-ripple').length > 0) {
      target.removeChild(target.getElementsByClassName('unf-animation-ripple')[0]);
    }

    var size = Math.max(rect.width, rect.height);
    var x = clientX - rect.x - size / 2;
    var y = clientY - rect.y - size / 2;
    var circle = document.createElement('div');
    target.appendChild(circle);
    circle.style.width = size + 'px';
    circle.style.height = size + 'px';
    circle.style.left = x + 'px';
    circle.style.top = y + 'px';
    circle.classList.add('unf-animation-ripple');
  };

  var handleRippleClick = function handleRippleClick(event) {
    if (rippleRef.current !== null) {
      var target = rippleRef.current;
      var rect = event.currentTarget.getBoundingClientRect();
      handleRipple(target, rect, event.clientX, event.clientY);
    }
  };

  var handleRippleTouch = function handleRippleTouch(event) {
    if (rippleRef.current !== null) {
      var target = rippleRef.current;
      var pointerX = event.touches[0].clientX;
      var pointerY = event.touches[0].clientY;
      var rect = event.currentTarget.getBoundingClientRect();
      handleRipple(target, rect, pointerX, pointerY);
    }
  };

  useImperativeHandle(ref, function () {
    return {
      trigger: handleRippleClick,
      triggerTouch: handleRippleTouch
    };
  });
  return React.createElement("div", {
    ref: rippleRef,
    className: rippleStyle(color, duration, easing, opacity),
    onAnimationEnd: function onAnimationEnd(e) {
      return e.stopPropagation();
    }
  });
});
Ripple.displayName = 'Ripple';
export default memo(Ripple);