import React, { forwardRef, useEffect, useImperativeHandle, useRef } from 'react';
import { isOutOfBound, isStyledComponent } from "../functions";

var getElement = function getElement(target) {
  if (target) {
    if (typeof target === 'string') {
      return document.querySelector(target);
    }

    return target.current;
  }

  return null;
};

var UnifyPlacement = forwardRef(function (props, ref) {
  var _children$ref;

  var _props$autoAdjust = props.autoAdjust,
      autoAdjust = _props$autoAdjust === void 0 ? true : _props$autoAdjust,
      container = props.container,
      children = props.children,
      _props$placement = props.placement,
      placement = _props$placement === void 0 ? 'top' : _props$placement,
      _props$spacing = props.spacing,
      spacing = _props$spacing === void 0 ? 8 : _props$spacing,
      target = props.target;
  var containerElement = getElement(container);
  var imperativeRef = isStyledComponent(children) ? children.props.innerRef : children.ref;
  var childRef = useRef(null);
  useImperativeHandle(ref, function () {
    return imperativeRef.current ? imperativeRef.current : childRef.current;
  });

  var handlePlacement = function handlePlacement() {
    var targetElement = getElement(target);
    var targetElementRect = targetElement === null || targetElement === void 0 ? void 0 : targetElement.getBoundingClientRect();
    var element;

    if (isStyledComponent(children)) {
      element = children.props.innerRef.current ? children.props.innerRef.current : childRef.current;
    } else {
      element = children.ref.current ? children.ref.current : childRef.current;
    }

    var elementDimension = {
      width: element.offsetWidth,
      height: element.offsetHeight
    };

    var setPlacement = function setPlacement(newPlace) {
      element.setAttribute('data-placement', newPlace);
    };

    var handleXPosition = function handleXPosition(placement, originalPosition, isOb) {
      switch (true) {
        case isOb.left && !isOb.right:
          element.style.left = "".concat(targetElementRect.left + window.scrollX, "px");

          if (placement === 'top') {
            isOb.top ? setPlacement('bottom-left') : setPlacement('top-left');
          } else {
            isOb.bottom ? setPlacement('top-left') : setPlacement('bottom-left');
          }

          break;

        case !isOb.left && isOb.right:
          element.style.left = "".concat(targetElementRect.left - Math.abs(elementDimension.width - targetElementRect.width) + window.scrollX, "px");

          if (placement === 'top') {
            isOb.top ? setPlacement('bottom-right') : setPlacement('top-right');
          } else {
            isOb.bottom ? setPlacement('top-right') : setPlacement('bottom-right');
          }

          break;

        default:
          element.style.left = "".concat(originalPosition, "px");
          break;
      }
    };

    var handleYPosition = function handleYPosition(placement, originalPosition, isOb) {
      switch (true) {
        case isOb.top && !isOb.bottom:
          element.style.top = "".concat(targetElementRect.top + window.scrollY, "px");

          if (placement === 'right') {
            isOb.right ? setPlacement('left-top') : setPlacement('right-top');
          } else {
            isOb.left ? setPlacement('right-top') : setPlacement('left-top');
          }

          break;

        case !isOb.top && isOb.bottom:
          element.style.top = "".concat(targetElementRect.top - targetElementRect.height - elementDimension.height + window.scrollY, "px");

          if (placement === 'right') {
            isOb.right ? setPlacement('left-bottom') : setPlacement('right-bottom');
          } else {
            isOb.left ? setPlacement('right-bottom') : setPlacement('left-bottom');
          }

          break;

        default:
          element.style.top = "".concat(originalPosition, "px");
          break;
      }
    };

    switch (placement) {
      case 'top':
        {
          var targetTop = targetElementRect.top - elementDimension.height - spacing + window.scrollY;
          var targetLeft = targetElementRect.left - elementDimension.width / 2 + targetElementRect.width / 2 + window.scrollX;
          var isOb = isOutOfBound(targetTop, targetLeft, elementDimension, containerElement);
          element.style.top = "".concat(isOb.top ? targetElementRect.top + targetElementRect.height + spacing + window.scrollY : targetTop, "px");
          isOb.top ? setPlacement('bottom') : setPlacement('top');
          handleXPosition(placement, targetLeft, isOb);
          break;
        }

      case 'right':
        {
          var _targetTop = targetElementRect.top - elementDimension.height / 2 + targetElementRect.height / 2 + window.scrollY;

          var _targetLeft = targetElementRect.left + targetElementRect.width + spacing + window.scrollX;

          var _isOb = isOutOfBound(_targetTop, _targetLeft, elementDimension, containerElement);

          element.style.left = "".concat(_isOb.right ? targetElementRect.left - elementDimension.width - spacing + window.scrollX : _targetLeft, "px");
          _isOb.right ? setPlacement('left') : setPlacement('right');
          handleYPosition(placement, _targetTop, _isOb);
          break;
        }

      case 'left':
        {
          var _targetTop2 = targetElementRect.top - elementDimension.height / 2 + targetElementRect.height / 2 + window.scrollY;

          var _targetLeft2 = targetElementRect.left - elementDimension.width - spacing + window.scrollX;

          var _isOb2 = isOutOfBound(_targetTop2, _targetLeft2, elementDimension, containerElement);

          element.style.left = "".concat(_isOb2.left ? targetElementRect.left + targetElementRect.width + spacing + window.scrollX : _targetLeft2, "px");
          _isOb2.left ? setPlacement('right') : setPlacement('left');
          handleYPosition(placement, _targetTop2, _isOb2);
          break;
        }

      case 'bottom':
        {
          var _targetTop3 = targetElementRect.top + targetElementRect.height + spacing + window.scrollY;

          var _targetLeft3 = targetElementRect.left - elementDimension.width / 2 + targetElementRect.width / 2 + window.scrollX;

          var _isOb3 = isOutOfBound(_targetTop3, _targetLeft3, elementDimension, containerElement);

          element.style.top = "".concat(_isOb3.bottom ? targetElementRect.top - elementDimension.height - spacing + window.scrollY : _targetTop3, "px");
          _isOb3.bottom ? setPlacement('top') : setPlacement('bottom');
          handleXPosition(placement, _targetLeft3, _isOb3);
          break;
        }
    }
  };

  useEffect(function () {
    return handlePlacement();
  });
  useEffect(function () {
    autoAdjust && window.addEventListener('resize', handlePlacement);
    return function () {
      autoAdjust && window.removeEventListener('resize', handlePlacement);
    };
  }, []);

  if (isStyledComponent(children)) {
    var _children$props$inner;

    return React.cloneElement(children, {
      innerRef: (_children$props$inner = children.props.innerRef) !== null && _children$props$inner !== void 0 && _children$props$inner.current ? children.props.innerRef : childRef
    });
  }

  return React.cloneElement(children, {
    ref: (_children$ref = children.ref) !== null && _children$ref !== void 0 && _children$ref.current ? children.ref : childRef
  });
});
UnifyPlacement.displayName = 'UnifyPlacement';
export default UnifyPlacement;