import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import { canUseDOM } from "../../../../build/Providers/common/functions";
var keys = {
  37: 1,
  38: 1,
  39: 1,
  40: 1
};

var preventDefault = function preventDefault(e) {
  e.preventDefault();
};

var preventDefaultForScrollKeys = function preventDefaultForScrollKeys(e) {
  if (keys[e.keyCode]) {
    preventDefault(e);
    return false;
  }

  return null;
};

var supportsPassive = false;

try {
  window.addEventListener('test', function () {}, Object.defineProperty({}, 'passive', {
    get: function get() {
      supportsPassive = true;
      return supportsPassive;
    }
  }));
} catch (e) {}

var wheelOpt = supportsPassive ? {
  passive: false
} : false;

var wheelEvent = function wheelEvent() {
  return 'onwheel' in document.createElement('div') ? 'wheel' : 'mousewheel';
};

export var disableScroll = function disableScroll() {
  if (!canUseDOM) {
    return false;
  }

  window.addEventListener('DOMMouseScroll', preventDefault, false);
  window.addEventListener(wheelEvent(), preventDefault, wheelOpt);
  window.addEventListener('touchmove', preventDefault, wheelOpt);
  window.addEventListener('keydown', preventDefaultForScrollKeys, false);
  return null;
};
export var enableScroll = function enableScroll() {
  if (!canUseDOM) {
    return undefined;
  }

  window.removeEventListener('DOMMouseScroll', preventDefault, false);
  window.removeEventListener(wheelEvent(), preventDefault, wheelOpt);
  window.removeEventListener('touchmove', preventDefault, wheelOpt);
  window.removeEventListener('keydown', preventDefaultForScrollKeys, false);
  return null;
};

var getScrollParent = function getScrollParent(node) {
  if (node == null) {
    return null;
  }

  if (node.scrollHeight > node.clientHeight + 4) {
    return node;
  } else {
    return getScrollParent(node.parentNode);
  }
};

export var disableParentScroll = function disableParentScroll(node) {
  if (node) {
    var scrollableElement = getScrollParent(node);
    scrollableElement === null || scrollableElement === void 0 ? void 0 : scrollableElement.addEventListener('wheel', preventDefault);
  }
};
export var enableParentScroll = function enableParentScroll(node) {
  if (node) {
    var scrollableElement = getScrollParent(node);
    scrollableElement === null || scrollableElement === void 0 ? void 0 : scrollableElement.removeEventListener('wheel', preventDefault);
  }
};
export var findScrollableParents = function findScrollableParents(target) {
  var result = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var parent = target.parentElement;
  var parentOverflow = 'scroll';

  if (parent instanceof HTMLElement) {
    parentOverflow = getComputedStyle(parent, null).getPropertyValue('overflow');
  }

  if (parent) {
    if (parentOverflow !== 'visible' && (parent.scrollHeight > parent.offsetHeight || parent.scrollWidth > parent.offsetWidth)) return findScrollableParents(parent, [].concat(_toConsumableArray(result), [parent]));else return findScrollableParents(parent, result);
  }

  return [].concat(_toConsumableArray(result), [window]);
};