import styled, { css } from 'react-emotion';
import { GN500, NN300, NN400, NN600, NN950, RN500, NN200 } from 'unify-token/colors';
import { fontSizeLv2, fontSizeLv3, lineHeightLv1, lineHeightLv4, lineHeightRAWLv1, lineHeightRAWLv4, fontWeightExtraBold } from 'unify-token/build/v2/typographies';
import { easeInOut, durationT3 } from 'unify-token/build/v2/motions';
import { focusStyle } from "../../../../build/Providers/common/style";
export var FORM_GROUP_PADDING = 12;
export var FORM_INPUT_PADDING = 12;
export var FORM_INPUT_LINE_HEIGHT = lineHeightRAWLv4;
export var FORM_LABEL_LINE_HEIGHT_MIN = lineHeightRAWLv1;
export var FORM_TRANSITION_TIMING = "".concat(durationT3, " ").concat(easeInOut);
export var handleColor = function handleColor(disabled) {
  var lowEmphasis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  switch (true) {
    case disabled:
      return NN400;

    case lowEmphasis:
      return NN600;

    default:
      return NN950;
  }
};

var handleBorderColor = function handleBorderColor(_ref) {
  var disabled = _ref.disabled,
      error = _ref.error,
      focus = _ref.focus,
      success = _ref.success;

  switch (true) {
    case disabled:
      return NN200;

    case error:
      return RN500;

    case focus || success:
      return GN500;

    default:
      return NN300;
  }
};

var handleBorderTopColor = function handleBorderTopColor(_ref2) {
  var focus = _ref2.focus,
      formOption = _ref2.formOption,
      formPlaceholder = _ref2.formPlaceholder,
      formValue = _ref2.formValue,
      staticLabel = _ref2.staticLabel;

  switch (true) {
    case focus || formOption || Boolean(formPlaceholder) || Boolean(formValue) || staticLabel:
      return 'transparent';

    default:
      return undefined;
  }
};

export var FormContainer = styled("div", {
  target: "eexzuxt0"
})("padding-top:", function (_ref3) {
  var hasLabel = _ref3.hasLabel;
  return hasLabel && '6px';
}, ";margin:", function (_ref4) {
  var m = _ref4.m,
      margin = _ref4.margin;
  return m ? m : margin && margin;
}, ";margin-top:", function (_ref5) {
  var mt = _ref5.mt,
      marginTop = _ref5.marginTop;
  return mt ? mt : marginTop && marginTop;
}, ";margin-right:", function (_ref6) {
  var mr = _ref6.mr,
      marginRight = _ref6.marginRight;
  return mr ? mr : marginRight && marginRight;
}, ";margin-bottom:", function (_ref7) {
  var mb = _ref7.mb,
      marginBottom = _ref7.marginBottom;
  return mb ? mb : marginBottom && marginBottom;
}, ";margin-left:", function (_ref8) {
  var ml = _ref8.ml,
      marginLeft = _ref8.marginLeft;
  return ml ? ml : marginLeft && marginLeft;
}, ";");
export var FormGroup = styled("div", {
  target: "eexzuxt1"
})("label:group;border-radius:8px;display:flex;align-items:center;position:relative;padding:0 ", FORM_GROUP_PADDING, "px;transition:border-color ", FORM_TRANSITION_TIMING, ";border:1px solid ", function (props) {
  return handleBorderColor(props);
}, ";border-top-color:", function (props) {
  return props.formLabel ? handleBorderTopColor(props) : undefined;
}, ";");
var _ref9 = "width:100%;font-weight:normal;white-space:nowrap;text-overflow:ellipsis;pointer-events:none;overflow:hidden;position:absolute;top:";

var _ref10 = FORM_INPUT_PADDING * 100 / (FORM_INPUT_PADDING * 2 + FORM_INPUT_LINE_HEIGHT);

var _ref11 = "%;will-change:transform,font-size,line-height;color:";
var _ref12 = ";height:";
var _ref13 = ";visibility:";
var _ref14 = ";";
export var FormLabel = function FormLabel(props) {
  return css(_ref9, _ref10, _ref11, props.disabled ? NN400 : NN600, _ref12, props.formPlaceholder || props.staticLabel ? '0' : undefined, _ref13, props.formPlaceholder || props.staticLabel ? 'hidden' : 'visible', _ref14);
};
export var FormLabelSpacer = styled("div", {
  target: "eexzuxt2"
})("label:label-spacer;width:100%;display:flex;position:absolute;top:-1px;left:0;pointer-events:none;&::before,&::after{content:'';height:8px;border-top:1px solid ", function (props) {
  return handleBorderColor(props);
}, ";transition:border-top-color ", FORM_TRANSITION_TIMING, ",border-right-color ", FORM_TRANSITION_TIMING, ",border-left-color ", FORM_TRANSITION_TIMING, ";}&::before{flex-basis:10px;width:10px;border-left:1px solid ", function (props) {
  return handleBorderColor(props);
}, ";border-top-left-radius:8px;position:relative;left:-1px;margin-right:3px;}&::after{flex-basis:10px;flex-grow:1;border-right:1px solid ", function (props) {
  return handleBorderColor(props);
}, ";border-top-right-radius:8px;position:relative;right:-1px;margin-left:3px;}span{font-size:", fontSizeLv2, ";line-height:", lineHeightLv1, ";overflow:hidden;color:", function (_ref15) {
  var disabled = _ref15.disabled;
  return disabled ? NN400 : NN600;
}, ";height:", function (_ref16) {
  var staticLabel = _ref16.staticLabel,
      formPlaceholder = _ref16.formPlaceholder;
  return formPlaceholder || staticLabel ? undefined : '0';
}, ";transform:", function (_ref17) {
  var staticLabel = _ref17.staticLabel,
      formPlaceholder = _ref17.formPlaceholder;
  return formPlaceholder || staticLabel ? 'translateY(-50%)' : undefined;
}, ";white-space:nowrap;text-overflow:ellipsis;}");
export var FormInputContainer = css("label:container;display:flex;flex:1;position:relative;");
var _ref18 = "label:addon;height:";

var _ref19 = FORM_INPUT_PADDING * 2 + FORM_INPUT_LINE_HEIGHT;

var _ref20 = "px;max-height:";

var _ref21 = FORM_INPUT_PADDING * 2 + FORM_INPUT_LINE_HEIGHT;

var _ref22 = "px;color:";
var _ref23 = ";font-size:";
var _ref24 = ";font-weight:";
var _ref25 = ";line-height:";
var _ref26 = ";letter-spacing:-0.2px;display:flex;align-items:center;align-self:flex-end;overflow:";
var _ref27 = ";margin-right:8px;padding:12px 0;transition:color ";
var _ref28 = ";> *{margin-left:8px;&:first-child{margin-left:0;}}.";
var _ref29 = " ~ &{margin-right:0;margin-left:8px;}";
export var FormAddon = function FormAddon(props) {
  return css(_ref18, _ref19, _ref20, _ref21, _ref22, handleColor(props.disabled, true), _ref23, fontSizeLv3, _ref24, fontWeightExtraBold, _ref25, lineHeightLv4, _ref26, props.overflow, _ref27, FORM_TRANSITION_TIMING, _ref28, FormInputContainer, _ref29);
};
export var FormInfoContainer = css("label:info;width:100%;display:flex;padding:2px 12px 0;");
var _ref30 = "label:info__text;width:100%;color:";
var _ref31 = ";display:flex;position:relative;overflow:hidden;> div,> p{width:100%;word-break:break-word;color:inherit;font-size:";
var _ref32 = ";line-height:";
var _ref33 = ";position:relative;margin:0;transition:color ";
var _ref34 = ",opacity ";
var _ref35 = ",top ";
var _ref36 = ";}> div:first-child,> p:first-child{top:";
var _ref37 = ";opacity:";
var _ref38 = ";z-index:";
var _ref39 = ";}> div:last-child,> p:last-child{color:";
var _ref40 = ";left:0;position:";
var _ref41 = ";top:";
var _ref42 = ";opacity:";
var _ref43 = ";margin-left:";
var _ref44 = ";z-index:";
var _ref45 = ";}";
export var FormInfo = function FormInfo(props) {
  return css(_ref30, handleColor(props.disabled, true), _ref31, fontSizeLv2, _ref32, lineHeightLv1, _ref33, FORM_TRANSITION_TIMING, _ref34, FORM_TRANSITION_TIMING, _ref35, FORM_TRANSITION_TIMING, _ref36, props.message ? '-4px' : '0', _ref37, props.message ? 0 : 1, _ref38, props.message ? 1 : 2, _ref39, props.message && props.error && RN500, _ref40, props.message ? 'relative' : 'absolute', _ref41, props.message ? '0' : '-4px', _ref42, props.message ? 1 : 0, _ref43, props.message ? '-100%' : '0', _ref44, props.message ? 2 : 1, _ref45);
};
export var FormClear = css("border:none;padding:0;background-color:transparent;", focusStyle);
var _ref46 = "label:info__counter;flex:1 0 55px;width:55px;color:";
var _ref47 = ";font-size:";
var _ref48 = ";line-height:";
var _ref49 = ";text-align:right;> span{color:inherit;font-size:inherit;}";
export var FormCounter = function FormCounter(props) {
  return css(_ref46, handleColor(props.disabled, true), _ref47, fontSizeLv2, _ref48, lineHeightLv1, _ref49);
};