import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["className", "dataTest", "disabled", "lang", "max", "min", "readonly", "spinner", "value", "width", "onClickMin", "onClickPlus", "onChange"];
import React, { useState, useRef, useEffect } from 'react';
import Add from 'unify-icons/system/Add';
import Remove from 'unify-icons/system/Remove';
import { NN300, GN500 } from 'unify-token/colors';
import { Container, quantityButtonStyle, Input } from "./style";
var BUTTON_LABEL = {
  plus: {
    en: 'Add',
    id: 'Tambah'
  },
  minus: {
    en: 'Reduce',
    id: 'Kurangi'
  }
};
var noopObj = {};

var QuantityEditor = function QuantityEditor(_ref) {
  var className = _ref.className,
      _ref$dataTest = _ref.dataTest,
      dataTest = _ref$dataTest === void 0 ? noopObj : _ref$dataTest,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      _ref$max = _ref.max,
      max = _ref$max === void 0 ? 1000 : _ref$max,
      _ref$min = _ref.min,
      min = _ref$min === void 0 ? 1 : _ref$min,
      _ref$readonly = _ref.readonly,
      readonly = _ref$readonly === void 0 ? false : _ref$readonly,
      _ref$spinner = _ref.spinner,
      spinner = _ref$spinner === void 0 ? 1 : _ref$spinner,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      width = _ref.width,
      onClickMin = _ref.onClickMin,
      onClickPlus = _ref.onClickPlus,
      onChange = _ref.onChange,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isFocus = _useState2[0],
      setIsFocus = _useState2[1];

  var inputRef = useRef(null);
  useEffect(function () {
    if (isFocus) {
      if (inputRef.current) {
        inputRef.current.focus();
      }
    }
  }, [isFocus]);

  var stringifyValue = function stringifyValue(val) {
    if (typeof val === 'number') {
      return val.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    }

    return val;
  };

  var numerifyValue = function numerifyValue(val) {
    if (typeof val === 'string') {
      var newVal = parseInt(val.replace(/\./g, ''));

      if (isNaN(newVal) || newVal === undefined) {
        newVal = 0;
      }

      return newVal;
    }

    return val;
  };

  var handleChange = function handleChange(e) {
    var num = stringifyValue(numerifyValue(e.target.value));
    onChange && onChange(num);
  };

  var handleBlur = function handleBlur(e) {
    var newValue = numerifyValue(e.target.value);

    if (newValue >= max) {
      newValue = max;
    } else if (newValue <= min) {
      newValue = min;
    } else if (isNaN(newValue) || newValue === undefined) {
      newValue = min;
    }

    var num = stringifyValue(newValue);
    onChange && onChange(num);
    setIsFocus(false);
  };

  var handleFocus = function handleFocus() {
    setIsFocus(true);
  };

  var handleClickMin = function handleClickMin() {
    if (!checkMinButtonDisabled()) {
      var newValue = numerifyValue(value) - spinner;

      if (newValue < min) {
        newValue = min;
      }

      onChange && onChange(stringifyValue(newValue));
      onClickMin && onClickMin();
    }
  };

  var handleClickPlus = function handleClickPlus() {
    if (!checkPlusButtonDisabled()) {
      var newValue = numerifyValue(value) + spinner;

      if (newValue > max) {
        newValue = max;
      }

      onChange && onChange(stringifyValue(newValue));
      onClickPlus && onClickPlus();
    }
  };

  var checkMinButtonDisabled = function checkMinButtonDisabled() {
    var newValue = numerifyValue(value);

    if (newValue <= min || disabled) {
      return true;
    } else {
      return false;
    }
  };

  var checkPlusButtonDisabled = function checkPlusButtonDisabled() {
    var newValue = numerifyValue(value);

    if (newValue >= max || disabled) {
      return true;
    } else {
      return false;
    }
  };

  var handleIconColor = function handleIconColor(disabled) {
    return disabled ? NN300 : GN500;
  };

  return React.createElement(Container, {
    isFocus: isFocus,
    disabled: disabled,
    className: className,
    width: width,
    maxValueDigit: "".concat(max).length
  }, React.createElement("button", {
    "aria-label": "".concat(BUTTON_LABEL.minus[String(lang)], " ").concat(spinner),
    className: quantityButtonStyle,
    disabled: checkMinButtonDisabled(),
    "data-testid": dataTest.minusButton,
    tabIndex: -1,
    onClick: handleClickMin
  }, React.createElement(Remove, {
    height: "16px",
    width: "16px",
    color: handleIconColor(checkMinButtonDisabled())
  })), React.createElement(Input, _extends({
    "aria-valuenow": value ? Number(value) : undefined,
    "aria-valuemin": min,
    "aria-valuemax": max,
    "data-unify": "QuantityEditor",
    innerRef: inputRef,
    readOnly: readonly,
    role: "spinbutton",
    type: "text",
    value: stringifyValue(value),
    onChange: handleChange,
    onBlur: handleBlur,
    onFocus: handleFocus,
    disabled: disabled
  }, otherProps)), React.createElement("button", {
    "aria-label": "".concat(BUTTON_LABEL.plus[String(lang)], " ").concat(spinner),
    className: quantityButtonStyle,
    disabled: checkPlusButtonDisabled(),
    "data-testid": dataTest.plusButton,
    tabIndex: -1,
    onClick: handleClickPlus
  }, React.createElement(Add, {
    height: "16px",
    width: "16px",
    color: handleIconColor(checkPlusButtonDisabled())
  })));
};

export default QuantityEditor;