import React from 'react';
import { BottomSheetV2Props } from '../../build/BottomSheetV2';
export interface SelectV2Props {
    /**
     * Append object (node, image, icon, etc) on the component.
     */
    appendObject?: React.ReactNode;
    /**
     * Append suffix on the component.
     */
    appendText?: string;
    /**
     * Set the component options value.
     */
    children?: React.ReactNode | object[];
    /**
     * Set the component container className.
     */
    className?: string;
    /**
     * Set the component into disabled state.
     */
    disabled?: boolean;
    /**
     * Set the component into error state.
     */
    error?: boolean;
    /**
     * Set the component into focused state.
     */
    focus?: boolean;
    /**
     * Set the component id attribute.
     */
    id?: string;
    /**
     * Set the component info text.
     */
    info?: string;
    /**
     * Set the component label.
     */
    label?: string;
    /**
     * Set the component list description when `withSearch` is `true`.
     */
    listDescription?: string;
    /**
     * Set the component list title when `withSearch` is `true`.
     */
    listTitle?: string;
    /**
     * Show the component message on validation (onChange, etc).
     */
    message?: string;
    /**
     * Set the component name attribute.
     */
    name?: string;
    /**
     * Prepend object (node, image, icon, etc) on the component.
     */
    prependObject?: React.ReactNode;
    /**
     * Prepend prefix on the component.
     */
    prependText?: string;
    /**
     * Set search placeholder text when you enabled `withSearch`.
     */
    searchPlaceholder?: string;
    /**
     * Set search value when you enabled `withSearch`.
     */
    searchValue?: string;
    /**
     * Set the component default selected option.
     */
    selectedOption?: string;
    /**
     * Set bottomsheet properties
     */
    sheetProps?: BottomSheetV2Props;
    /**
     * Set the component label text position on top by default.
     */
    staticLabel?: boolean;
    /**
     * Set the component into success state.
     */
    success?: boolean;
    /**
     * Change from normal selection mode into BottomSheet with search feature on it.
     */
    withSearch?: boolean;
    /**
     * Callback for onblur.
     */
    onBlur?: (e: React.FocusEvent<HTMLInputElement | HTMLSelectElement>) => void;
    /**
     * Callback for onchange.
     */
    onChange?: (e: React.ChangeEvent<HTMLSelectElement>) => void;
    /**
     * Callback for onchange on searchbar when you enabled `withSearch`.
     */
    onChangeSearch?: (e: React.ChangeEvent<HTMLInputElement>) => void;
    /**
     * Callback for clear action on searchbar when you enabled `withSearch`.
     */
    onClearSearch?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /**
     * Callback when the BottomSheet is closed when you enabled `withSearch`.
     */
    onCloseSearch?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /**
     * Callback for onfocus.
     */
    onFocus?: (e: React.FocusEvent<HTMLInputElement>) => void;
}
declare const SelectV2: {
    (props: SelectV2Props): JSX.Element;
    propTypes: {
        appendObject: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        appendText: import("prop-types").Requireable<string>;
        children: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        className: import("prop-types").Requireable<string>;
        disabled: import("prop-types").Requireable<boolean>;
        error: import("prop-types").Requireable<boolean>;
        focus: import("prop-types").Requireable<boolean>;
        id: import("prop-types").Requireable<string>;
        info: import("prop-types").Requireable<string>;
        label: import("prop-types").Requireable<string>;
        listDescription: import("prop-types").Requireable<string>;
        listTitle: import("prop-types").Requireable<string>;
        message: import("prop-types").Requireable<string>;
        name: import("prop-types").Requireable<string>;
        prependObject: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        prependText: import("prop-types").Requireable<string>;
        searchPlaceholder: import("prop-types").Requireable<string>;
        searchValue: import("prop-types").Requireable<string>;
        selectedOption: import("prop-types").Requireable<string>;
        staticLabel: import("prop-types").Requireable<boolean>;
        success: import("prop-types").Requireable<boolean>;
        withSearch: import("prop-types").Requireable<boolean>;
        onBlur: import("prop-types").Requireable<(...args: any[]) => any>;
        onChange: import("prop-types").Requireable<(...args: any[]) => any>;
        onChangeSearch: import("prop-types").Requireable<(...args: any[]) => any>;
        onClearSearch: import("prop-types").Requireable<(...args: any[]) => any>;
        onCloseSearch: import("prop-types").Requireable<(...args: any[]) => any>;
        onFocus: import("prop-types").Requireable<(...args: any[]) => any>;
    };
    defaultProps: {
        disabled: boolean;
        error: boolean;
        focus: boolean;
        staticLabel: boolean;
        success: boolean;
        withSearch: boolean;
    };
};
export default SelectV2;
