import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import _typeof from "@babel/runtime/helpers/typeof";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["appendObject", "appendText", "children", "className", "disabled", "error", "focus", "id", "info", "label", "listDescription", "listTitle", "message", "name", "prependObject", "prependText", "selectedOption", "success", "staticLabel", "withSearch", "onBlur", "onChange", "onFocus", "searchPlaceholder", "searchValue", "sheetProps", "onChangeSearch", "onClearSearch", "onCloseSearch"];
import React, { useEffect, useRef, useState } from 'react';
import ChevronDown from 'unify-icons/system/ChevronDown';
import { usePrev } from "../../build/Providers/common/hooks";
import BottomSheetV2 from "../../build/BottomSheetV2";
import List from "../../build/List";
import SearchBar from "../../build/SearchBar";
import { FormContainer, FormGroup, FormLabelSpacer, FormInputContainer, FormAddon, FormInfoContainer, FormInfo, FORM_GROUP_PADDING, FORM_INPUT_LINE_HEIGHT, FORM_INPUT_PADDING, FORM_LABEL_LINE_HEIGHT_MIN, FORM_TRANSITION_TIMING } from "../../build/Providers/styles/Form/_Common.style";
import handleAnimationFrame from "../../build/Providers/common/functions/handleAnimationFrame";
import { Label, ListDescription, SelectInput, SelectText } from "./style";

var SelectV2 = function SelectV2(props) {
  var appendObject = props.appendObject,
      appendText = props.appendText,
      children = props.children,
      className = props.className,
      disabled = props.disabled,
      error = props.error,
      focus = props.focus,
      id = props.id,
      info = props.info,
      label = props.label,
      listDescription = props.listDescription,
      listTitle = props.listTitle,
      message = props.message,
      name = props.name,
      prependObject = props.prependObject,
      prependText = props.prependText,
      selectedOption = props.selectedOption,
      success = props.success,
      staticLabel = props.staticLabel,
      withSearch = props.withSearch,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onFocus = props.onFocus,
      searchPlaceholder = props.searchPlaceholder,
      searchValue = props.searchValue,
      sheetProps = props.sheetProps,
      onChangeSearch = props.onChangeSearch,
      onClearSearch = props.onClearSearch,
      onCloseSearch = props.onCloseSearch,
      otherProps = _objectWithoutProperties(props, _excluded);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      focusState = _useState2[0],
      setFocusState = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      sheetState = _useState4[0],
      setSheetState = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      optionLabel = _useState6[0],
      setOptionLabel = _useState6[1];

  var containerRef = useRef(null);
  var wrapperRef = useRef(null);
  var labelRef = useRef(null);
  var labelSpacerRef = useRef(null);
  var selectRef = useRef(null);
  var isAnimated = useRef(false);
  var prevMessage = usePrev(message);
  var labelTop = (FORM_LABEL_LINE_HEIGHT_MIN / 2 + 0.5) * 100 / (FORM_INPUT_PADDING * 2 + FORM_INPUT_LINE_HEIGHT + 2);

  var getOptionLabel = function getOptionLabel() {
    var select = selectRef.current;

    if (!select || !children) {
      return;
    }

    return select.selectedOptions[0].label;
  };

  useEffect(function () {
    selectRef.current && focus && selectRef.current.focus();
  }, [focus]);
  useEffect(function () {
    var optLabel = getOptionLabel();

    if (label) {
      if (focusState) {
        !isAnimated.current && animateLabel(true);
      } else {
        isAnimated.current && !selectedOption && !optLabel && animateLabel(false);
      }
    }
  }, [focusState]);
  useEffect(function () {
    var optLabel = getOptionLabel();

    if (label) {
      if (selectedOption) {
        animateLabel(true);
      } else if (optLabel) {
        setOptionLabel(true);
        !isAnimated.current && animateLabel(true);
      } else {
        isAnimated.current && !focusState && animateLabel(false);
      }
    }
  }, [label, selectedOption]);

  var animateLabel = function animateLabel(adjust) {
    var DOM = labelRef.current;

    if (staticLabel) {
      return false;
    } else {
      isAnimated.current = adjust;
      handleAnimationFrame(function () {
        DOM.style.top = adjust ? "-".concat(labelTop, "%") : '';
        DOM.style.transform = adjust ? "translateX(-".concat(wrapperRef.current.offsetLeft - FORM_GROUP_PADDING, "px)") : '';
      });
    }
  };

  var handleBlur = function handleBlur(e) {
    setFocusState(false);
    onBlur && onBlur(e);
  };

  var handleChange = function handleChange(e) {
    e.stopPropagation();
    onChange && onChange(e);
  };

  var handleFocus = function handleFocus(e) {
    setFocusState(true);
    onFocus && onFocus(e);
  };

  var renderAddon = function renderAddon(content) {
    if (_typeof(content) === 'object') {
      if (content.type && content.type === React.Fragment) {
        return React.createElement("div", {
          className: FormAddon({
            disabled: disabled
          })
        }, React.Children.map(content.props.children, function (child) {
          return typeof child === 'string' ? React.createElement("span", null, child) : child;
        }));
      }
    }

    return React.createElement("div", {
      className: FormAddon({
        disabled: disabled
      })
    }, content);
  };

  var bottomSheetProps = _objectSpread(_objectSpread({
    full: true
  }, sheetProps), {}, {
    display: sheetState,
    title: listTitle,
    onClose: function onClose(e) {
      return handleCloseSearch(e);
    }
  });

  var searchProps = {
    placeholder: searchPlaceholder,
    value: searchValue,
    margin: '8px 16px',
    onChange: onChangeSearch,
    onClear: onClearSearch
  };

  var handleInputBlur = function handleInputBlur(e) {
    e.stopPropagation();
    setFocusState(false);
    onBlur && onBlur(e);
  };

  var handleOpenSearch = function handleOpenSearch() {
    !disabled && setSheetState(true);
  };

  var handleCloseSearch = function handleCloseSearch(e) {
    !disabled && setSheetState(false);
    onCloseSearch && onCloseSearch(e);
  };

  return React.createElement(React.Fragment, null, React.createElement(FormContainer, _extends({
    innerRef: containerRef,
    className: className,
    hasLabel: label
  }, otherProps), React.createElement(FormGroup, {
    disabled: disabled,
    error: error,
    focus: focusState,
    formLabel: label,
    formOption: optionLabel,
    formValue: selectedOption,
    staticLabel: staticLabel,
    success: success
  }, label && React.createElement(FormLabelSpacer, {
    disabled: disabled,
    error: error,
    focus: focusState,
    staticLabel: staticLabel,
    success: success
  }, React.createElement("span", {
    ref: labelSpacerRef,
    "aria-hidden": staticLabel ? false : true,
    "aria-label": label
  }, label)), prependText && renderAddon(prependText), prependObject && renderAddon(prependObject), React.createElement("div", {
    ref: wrapperRef,
    className: FormInputContainer
  }, withSearch ? React.createElement("input", {
    "aria-haspopup": "listbox",
    "data-unify": "Select",
    className: SelectText({
      disabled: disabled
    }),
    disabled: disabled,
    id: id,
    name: name,
    readOnly: true,
    type: "text",
    value: selectedOption,
    onBlur: handleInputBlur,
    onClick: handleOpenSearch,
    onFocus: handleFocus
  }) : React.createElement("select", {
    ref: selectRef,
    "data-unify": "Select",
    className: SelectInput({
      disabled: disabled
    }),
    disabled: disabled,
    id: id,
    name: name,
    value: selectedOption,
    onBlur: handleBlur,
    onChange: handleChange,
    onFocus: handleFocus
  }, children), React.createElement(ChevronDown, {
    style: {
      opacity: disabled ? 0.32 : 1,
      transition: "opacity ".concat(FORM_TRANSITION_TIMING),
      position: 'absolute',
      top: '50%',
      right: 0,
      marginTop: '-12px'
    }
  }), label && React.createElement(Label, {
    innerRef: labelRef,
    "aria-hidden": staticLabel ? true : false,
    disabled: disabled,
    focus: focusState,
    formOption: optionLabel,
    formValue: selectedOption,
    hasPrepend: prependText || prependObject ? true : false,
    staticLabel: staticLabel
  }, label)), appendObject && renderAddon(appendObject), appendText && renderAddon(appendText)), info || message ? React.createElement("div", {
    className: FormInfoContainer
  }, info || message ? React.createElement("div", {
    className: FormInfo({
      disabled: disabled,
      error: error,
      message: message,
      success: success
    })
  }, React.createElement("div", null, info ? info : ''), React.createElement("div", null, message ? message : prevMessage)) : null) : null), withSearch ? React.createElement(BottomSheetV2, bottomSheetProps, React.createElement(SearchBar, searchProps), listDescription && React.createElement("div", {
    className: ListDescription
  }, listDescription), React.createElement(List, {
    noMargin: true,
    items: React.Children.map(children, function (item) {
      var _item$props;

      return {
        text: item === null || item === void 0 ? void 0 : (_item$props = item.props) === null || _item$props === void 0 ? void 0 : _item$props.children,
        onClick: function onClick() {
          if (item.props.onClick) {
            item.props.onClick();
          }

          setSheetState(false);
        }
      };
    })
  })) : null);
};

SelectV2.defaultProps = {
  disabled: false,
  error: false,
  focus: false,
  staticLabel: false,
  success: false,
  withSearch: false
};
export default SelectV2;