import { TouchEventHandler, MouseEventHandler, ComponentPropsWithoutRef, ReactNode } from 'react';
export interface OnTouchEvents {
    onTouchStart?: TouchEventHandler<HTMLDivElement>;
    onTouchMove?: TouchEventHandler<HTMLDivElement>;
    onTouchEnd?: TouchEventHandler<HTMLDivElement>;
    onMouseDown?: MouseEventHandler<HTMLDivElement>;
}
export declare type SliderV2IndicatorMode = 'count' | 'interval' | 'single' | 'none';
export declare type SliderV2SnapPointMode = 'count' | 'interval' | 'none';
declare type SliderV2Attributes = ComponentPropsWithoutRef<'div'>;
export interface SliderV2Props extends Omit<SliderV2Attributes, 'css'> {
    /**
     * To disable slider interactions. Also changes style.
     * @default false
     */
    disabled?: boolean;
    /**
     * To determine placement/behavior of value indicators. Check below for more explanation.
     * @default 'none'
     */
    indicatorMode?: SliderV2IndicatorMode;
    /**
     * To pass function to modify indicators. Check below for more explanation.
     * @default (val) => val
     */
    indicatorModifier?: (val: number) => string | number | ReactNode;
    /**
     * Works with `indicatorMode` to determine placement/behavior of indicators.
     * @default 5
     */
    indicatorUnit?: number;
    /**
     * To set max value.
     */
    maxValue: number;
    /**
     * To set min value.
     */
    minValue: number;
    /**
     * To use one handler mode.  Point to a single value. Will deprecate.
     * @default false
     */
    oneHandlerMode?: boolean;
    /**
     * To use single handler mode.
     * @default false
     */
    singleHandlerMode?: boolean;
    /**
     * To determine placement of snap points. Check below for a more detailed description.
     * @default 'none'
     */
    snapPointMode?: SliderV2SnapPointMode;
    /**
     * Works with `snapPointMode` to determine placement of snap points.
     * @default 5
     */
    snapPointUnit?: number;
    /**
     * To initialize/reinitialize value of first handler.
     * @default 0
     */
    value1?: number;
    /**
     * To initialize/reinitialize value of second handler.
     * @default 0
     */
    value2?: number;
    /**
     *  To pass callback that gets called anytime value of handlers is changed. Returns smaller value followed by the larger value. For `oneHandlerMode` only returns a single value.
     *  Returns smallerValue, biggerValue, value1, value2.
     * @default () => {}
     */
    onValueChange?: (val: number, ...args: number[]) => void;
}
export {};
