import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children", "className", "flat", "noShadow", "items", "indexActive", "onClickToggle", "onItemClick"];
import React, { Fragment, useEffect, useRef, useCallback, useState } from 'react';
import { cx } from 'emotion';
import { canUseDOM } from "../../build/Providers/common/functions";
import { Container, TabItemInk, WrapperTrigger, TriggerSection } from "./style";
import TabItem from "./_TabItem";

var Tab = function Tab(_ref) {
  var children = _ref.children,
      className = _ref.className,
      flat = _ref.flat,
      noShadow = _ref.noShadow,
      _ref$items = _ref.items,
      items = _ref$items === void 0 ? [] : _ref$items,
      _ref$indexActive = _ref.indexActive,
      indexActive = _ref$indexActive === void 0 ? 0 : _ref$indexActive,
      onClickToggle = _ref.onClickToggle,
      onItemClick = _ref.onItemClick,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      inkBarWidth = _useState2[0],
      setInkBarWidth = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      tabHeight = _useState4[0],
      setTabHeight = _useState4[1];

  var _useState5 = useState(0),
      _useState6 = _slicedToArray(_useState5, 2),
      left = _useState6[0],
      setLeft = _useState6[1];

  var containerRef = useRef(null);
  var focusActiveTab = useCallback(function () {
    var _containerRef$current;

    var item = (_containerRef$current = containerRef.current) === null || _containerRef$current === void 0 ? void 0 : _containerRef$current.querySelector('.unf-tab__item--active');
    var tab = item === null || item === void 0 ? void 0 : item.parentNode;

    if (item && tab) {
      var itemCenter = item.offsetLeft + item.offsetWidth / 2;
      var tabCenter = tab.offsetWidth / 2;
      var newScrollPosition = itemCenter - tabCenter;

      if (newScrollPosition >= 0) {
        if (Array.isArray(items) && items.length - 1 === indexActive && tab.scrollLeft > 0) {
          newScrollPosition = tab.scrollWidth - tab.offsetWidth;
        }

        tab.scrollLeft = newScrollPosition;
      } else {
        newScrollPosition = 0;
        tab.scrollLeft = 0;
      }

      setInkBarWidth(item.offsetWidth);
      setLeft(item.offsetLeft);
    }
  }, [indexActive, items, flat, onClickToggle]);
  useEffect(function () {
    focusActiveTab();

    if (canUseDOM && containerRef.current) {
      setTabHeight(containerRef.current.offsetHeight);
    }
  }, [focusActiveTab, indexActive]);
  useEffect(function () {
    if (canUseDOM) {
      window.addEventListener('resize', focusActiveTab);
    }

    return function () {
      window.removeEventListener('resize', focusActiveTab);
    };
  }, [focusActiveTab]);

  var renderChildren = function renderChildren() {
    var childrenWithProps = [];
    Array.isArray(children) && children.forEach(function (child, i) {
      var _items$Number, _items$Number$text, _items$Number$text$to;

      var id = (_items$Number = items[Number(i)]) === null || _items$Number === void 0 ? void 0 : (_items$Number$text = _items$Number.text) === null || _items$Number$text === void 0 ? void 0 : (_items$Number$text$to = _items$Number$text.toLowerCase()) === null || _items$Number$text$to === void 0 ? void 0 : _items$Number$text$to.replace(/\s/g, '-');
      childrenWithProps.push(React.cloneElement(child, {
        'aria-labelledby': "unf-tabitem-".concat(id),
        key: "unf-tab-".concat(i),
        id: "unf-tabpanel-".concat(id),
        index: child.props.index ? child.props.index : i,
        indexActive: indexActive,
        role: 'tabpanel',
        tabIndex: 0
      }));
    });
    return childrenWithProps;
  };

  var classes = cx('unf-tab', {
    'unf-tab--primary': otherProps.primary,
    'unf-tab--secondary': otherProps.secondary
  }, className);

  var handleClickToggle = function handleClickToggle(e) {
    typeof onClickToggle === 'function' && onClickToggle(e);
  };

  return React.createElement(Fragment, null, React.createElement(Container, _extends({
    innerRef: containerRef,
    "data-unify": "Tab",
    className: classes,
    flat: flat,
    noShadow: noShadow,
    role: "tablist",
    withToggle: typeof onClickToggle === 'function'
  }, otherProps), Array.isArray(items) && items.map(function (_ref2, i) {
    var text = _ref2.text,
        dataTest = _ref2.dataTest,
        count = _ref2.count,
        newNotification = _ref2.newNotification,
        notification = _ref2.notification,
        icon = _ref2.icon,
        iconSize = _ref2.iconSize,
        lang = _ref2.lang,
        value = _ref2.value,
        props = _ref2.props;
    var isActive = indexActive === i;
    var id = typeof text === 'string' ? text === null || text === void 0 ? void 0 : text.toLowerCase().replace(/\s/g, '-') : undefined;
    return React.createElement(TabItem, _extends({
      "aria-selected": isActive,
      "aria-controls": "unf-tabpanel-".concat(id),
      active: isActive,
      count: count,
      dataTest: dataTest === null || dataTest === void 0 ? void 0 : dataTest.tabItem,
      icon: icon,
      iconSize: iconSize,
      id: "unf-tabitem-".concat(id),
      index: i,
      key: i,
      lang: lang,
      last: i === items.length - 1,
      newNotification: newNotification,
      notification: notification,
      role: "tab",
      text: text,
      value: value,
      onClick: onItemClick
    }, otherProps, props));
  }), React.createElement(TabItemInk, {
    width: inkBarWidth,
    active: indexActive === indexActive,
    left: left
  })), typeof onClickToggle === 'function' && !flat && React.createElement(WrapperTrigger, {
    className: "unf-tab-wrapper-trigger"
  }, React.createElement(TriggerSection, {
    tabHeight: tabHeight,
    onClick: handleClickToggle
  })), renderChildren());
};

export default Tab;