import React, { PureComponent } from 'react';
export interface TextAreaProps {
    /**
     * Set the component container className (not the textarea element).
     */
    className?: string;
    /**
     * Set the maximum number of characters and show the character counter.
     */
    counter?: number;
    /**
     * Set the component into disabled state.
     */
    disabled?: boolean;
    /**
     * Set the component into error state.
     */
    error?: boolean;
    /**
     * Remove any styling of the component, this mode is used when you have TextArea inside BottomSheet and needed a full height TextArea.
     */
    full?: boolean;
    /**
     * Set the component id attribute.
     */
    id?: string;
    /**
     * Set the component info text.
     */
    info?: string;
    /**
     * Set the component label text.
     */
    label?: string;
    /**
     * Set the component maximum number of characters without showing any counter.
     */
    maxLength?: number;
    /**
     * Show the component message on validation (onChange, etc), if `info` is present, message will be hidden until info is cleared.
     */
    message?: string;
    /**
     * Set the component name attribute.
     */
    name?: string;
    /**
     * Set the component placeholder. If the TextArea has `label` property, the label will be positioned on top by default.
     */
    placeholder?: string;
    /**
     * Set the component into readonly state.
     */
    readonly?: boolean;
    /**
     * Set the component into success state.
     */
    success?: boolean;
    /**
     * Set the component input value.
     */
    value?: string;
    /**
     * Reserve space for any `info` and `message` prop provided.
     */
    withInfo?: boolean;
    /**
     * `Deprecated` Remove any component animation.
     */
    withoutAnimation?: boolean;
    /**
     * Callback for onblur.
     */
    onBlur?: (e: React.FocusEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onchange.
     */
    onChange?: (e: React.ChangeEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback when user click clear button (passing a function to this callback will shown clear button whenever the value length is more than 3).
     */
    onClear?: (e: React.ChangeEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onclick.
     */
    onClick?: (e: React.MouseEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onfocus.
     */
    onFocus?: (e: React.FocusEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for oninput.
     */
    onInput?: (e: React.KeyboardEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onkeydown.
     */
    onKeyDown?: (e: React.KeyboardEvent<HTMLTextAreaElement>) => void;
}
declare class TextArea extends PureComponent<TextAreaProps> {
    componentDidMount: () => void;
    componentDidUpdate(prevProps: any): void;
    handleMessage: (text: any) => void;
    handleNoAnimation: (text: any) => void;
    handleTextInput: () => void;
    handleTextEnter: (event: any) => void;
    handleFocus: (e: any) => void;
    handleBlur: (e: any) => void;
    handleChange: (e: any) => void;
    handleClear: (e: any) => void;
    handleKeyDown: (e: any) => void;
    render(): JSX.Element;
}
export default TextArea;
