import _extends from "@babel/runtime/helpers/extends";
import _typeof from "@babel/runtime/helpers/typeof";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
var _excluded = ["appendObject", "appendText", "className", "focus", "full", "isClearable", "id", "name", "value", "maxLength", "counter", "label", "lang", "loading", "info", "inputProps", "maxRows", "minRows", "message", "placeholder", "staticLabel", "success", "error", "disabled", "readOnly", "onBlur", "onChange", "onClick", "onClear", "onFocus", "onInput", "onKeyDown", "onKeyPress", "onKeyUp"];
import React, { useRef, useState, useEffect } from 'react';
import Clear from 'unify-icons/system/Clear';
import { usePrev } from "../../build/Providers/common/hooks";
import LoaderCircular from "../../build/Circular";
import { FormAddon, FormClear, FormContainer, FormGroup, FormLabelSpacer, FormInputContainer, FormInfoContainer, FormInfo, FormCounter, FORM_GROUP_PADDING, FORM_INPUT_LINE_HEIGHT, FORM_LABEL_LINE_HEIGHT_MIN } from "../../build/Providers/styles/Form/_Common.style";
import { canUseDOM, handleAnimationFrame } from "../../build/Providers/common/functions";
import { Area, Label, LegacyAreaFull } from "./style";

var TextAreaV2 = function TextAreaV2(props) {
  var _useState = useState(props.focus),
      _useState2 = _slicedToArray(_useState, 2),
      focusState = _useState2[0],
      setFocusState = _useState2[1];

  var appendObject = props.appendObject,
      appendText = props.appendText,
      className = props.className,
      focus = props.focus,
      full = props.full,
      isClearable = props.isClearable,
      id = props.id,
      name = props.name,
      value = props.value,
      maxLength = props.maxLength,
      counter = props.counter,
      label = props.label,
      lang = props.lang,
      loading = props.loading,
      info = props.info,
      inputProps = props.inputProps,
      maxRows = props.maxRows,
      minRows = props.minRows,
      message = props.message,
      placeholder = props.placeholder,
      staticLabel = props.staticLabel,
      success = props.success,
      error = props.error,
      disabled = props.disabled,
      readOnly = props.readOnly,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onClick = props.onClick,
      onClear = props.onClear,
      onFocus = props.onFocus,
      onInput = props.onInput,
      onKeyDown = props.onKeyDown,
      onKeyPress = props.onKeyPress,
      onKeyUp = props.onKeyUp,
      otherProps = _objectWithoutProperties(props, _excluded);

  var containerRef = useRef(null);
  var wrapperRef = useRef(null);
  var labelRef = useRef(null);
  var labelSpacerRef = useRef(null);
  var areaRef = useRef(null);
  var areaInitHeight = useRef(minRows * FORM_INPUT_LINE_HEIGHT);
  var isAnimated = useRef(false);
  var isMounted = useRef(false);
  var prevMessage = usePrev(message);
  var ariaLabel = {
    id: {
      clear: "Hapus".concat(label ? " ".concat(label) : '')
    },
    en: {
      clear: "Clear".concat(label ? " ".concat(label) : '')
    }
  };
  useEffect(function () {
    focus && areaRef.current.focus();
  }, [focus]);
  useEffect(function () {
    if (label) {
      if (!isAnimated.current) {
        focusState && animateLabel(true);
      } else {
        value === '' && animateLabel(false);
      }
    }
  }, [focusState]);
  useEffect(function () {
    if (full) {
      var fullArea = areaRef.current;
      var sheetWrapper = fullArea.closest('.unf-sheet__inner-wrapper');

      if (sheetWrapper) {
        sheetWrapper.style.height = '100%';
      }
    }
  }, [full]);
  useEffect(function () {
    var textarea = areaRef.current;

    if (!full) {
      if (label) {
        if (value !== '') {
          !isAnimated.current && animateLabel(true);
        } else {
          !focusState && animateLabel(false);
        }
      }

      if (value !== '') {
        if (areaInitHeight.current < textarea.scrollHeight) {
          if (textarea.scrollHeight > minRows * FORM_INPUT_LINE_HEIGHT) {
            textarea.style.height = "".concat(FORM_INPUT_LINE_HEIGHT, "px");
            textarea.style.height = "".concat(textarea.scrollHeight, "px");
          }
        }
      } else {
        textarea.style.height = "".concat(minRows * FORM_INPUT_LINE_HEIGHT, "px");
      }
    }
  }, [value]);
  useEffect(function () {
    var textarea = areaRef.current;

    if (!full) {
      textarea.style.height = minRows ? "".concat(minRows * FORM_INPUT_LINE_HEIGHT, "px") : '';

      if (!isMounted.current) {
        if (textarea.scrollHeight > minRows * FORM_INPUT_LINE_HEIGHT) {
          textarea.style.height = "".concat(minRows * FORM_INPUT_LINE_HEIGHT, "px");
          textarea.style.height = "".concat(textarea.scrollHeight, "px");
        }

        isMounted.current = true;
      }
    }
  }, [minRows]);

  var handleClear = function handleClear(e) {
    e.preventDefault();
    e.stopPropagation();
    areaRef.current.style.height = "".concat(minRows * FORM_INPUT_LINE_HEIGHT, "px");
    isAnimated.current = false;
    areaRef.current.focus();
    onClear && onClear(e);
  };

  var handleBlur = function handleBlur(e) {
    setFocusState(false);
    onBlur && onBlur(e);
  };

  var handleFocus = function handleFocus(e) {
    areaRef.current.scrollTop = areaRef.current.scrollHeight;
    setFocusState(true);
    onFocus && onFocus(e);
  };

  var handleKeyDown = function handleKeyDown(e) {
    var textarea = areaRef.current;

    if (canUseDOM) {
      if (e.keyCode === 13 || e.keyCode === 8) {
        handleAnimationFrame(function () {
          if (textarea.scrollHeight > minRows * FORM_INPUT_LINE_HEIGHT) {
            textarea.style.height = "".concat(FORM_INPUT_LINE_HEIGHT, "px");
            textarea.style.height = "".concat(textarea.scrollHeight, "px");
          }
        });
      }
    }

    onKeyDown && onKeyDown(e);
  };

  var animateLabel = function animateLabel(adjust) {
    var DOM = labelRef.current;

    if (placeholder || staticLabel) {
      return false;
    } else {
      isAnimated.current = adjust;
      handleAnimationFrame(function () {
        var _wrapperRef$current;

        DOM.style.top = adjust ? "-".concat(FORM_LABEL_LINE_HEIGHT_MIN / 2 + 0.5, "px") : '';
        DOM.style.transform = adjust ? "translateX(-".concat(((_wrapperRef$current = wrapperRef.current) === null || _wrapperRef$current === void 0 ? void 0 : _wrapperRef$current.offsetLeft) - FORM_GROUP_PADDING, "px)") : '';
      });
    }
  };

  var renderAddon = function renderAddon(content) {
    var overflow = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'hidden';

    if (_typeof(content) === 'object') {
      if (content.type && content.type === React.Fragment) {
        return React.createElement("div", {
          className: FormAddon({
            disabled: disabled,
            overflow: overflow
          })
        }, React.Children.map(content.props.children, function (child) {
          return typeof child === 'string' ? React.createElement("span", null, child) : child;
        }));
      }
    }

    return React.createElement("div", {
      className: FormAddon({
        disabled: disabled,
        overflow: overflow
      })
    }, content);
  };

  if (full) {
    return React.createElement(LegacyAreaFull, _extends({
      innerRef: areaRef,
      "aria-label": "unf-textarea",
      "data-unf": "textarea",
      "data-unify": "TextArea",
      disabled: disabled,
      placeholder: placeholder,
      readOnly: readOnly,
      value: value,
      onBlur: onBlur,
      onChange: onChange,
      onClick: onClick,
      onFocus: onFocus,
      onInput: onInput,
      onKeyDown: onKeyDown,
      onKeyPress: onKeyPress,
      onKeyUp: onKeyUp
    }, otherProps));
  }

  return React.createElement(FormContainer, _extends({
    innerRef: containerRef,
    className: className,
    hasLabel: label,
    "data-unf": "textarea"
  }, otherProps), React.createElement(FormGroup, {
    disabled: disabled,
    error: error,
    focus: focusState,
    formLabel: label,
    formPlaceholder: placeholder,
    formValue: value,
    staticLabel: staticLabel,
    success: success
  }, label && React.createElement(FormLabelSpacer, {
    disabled: disabled,
    error: error,
    focus: focusState,
    formPlaceholder: placeholder,
    staticLabel: staticLabel,
    success: success
  }, React.createElement("span", {
    ref: labelSpacerRef,
    "aria-hidden": placeholder || staticLabel ? false : true,
    "aria-label": label
  }, label)), React.createElement("div", {
    ref: wrapperRef,
    className: FormInputContainer
  }, React.createElement(Area, _extends({
    innerRef: areaRef,
    "aria-describedby": id ? "".concat(id, "-info-text") : null
  }, inputProps, {
    "data-unify": "TextArea",
    disabled: disabled,
    id: id,
    isClearable: isClearable,
    maxLength: counter || maxLength,
    maxRows: maxRows,
    minRows: minRows,
    name: name,
    placeholder: placeholder ? placeholder : undefined,
    readOnly: readOnly,
    value: value,
    onBlur: handleBlur,
    onChange: onChange,
    onClear: onClear,
    onClick: onClick,
    onFocus: handleFocus,
    onInput: onInput,
    onKeyDown: handleKeyDown,
    onKeyPress: onKeyPress,
    onKeyUp: onKeyUp
  })), label && React.createElement(Label, {
    innerRef: labelRef,
    htmlFor: id,
    "aria-hidden": placeholder || staticLabel ? true : false,
    disabled: disabled,
    focus: focusState,
    formPlaceholder: placeholder,
    formValue: value,
    staticLabel: staticLabel
  }, label)), !disabled && isClearable && value.length > 0 && renderAddon(React.createElement("button", {
    className: FormClear,
    "aria-label": ariaLabel[String(lang)].clear,
    onClick: handleClear,
    onFocus: function onFocus() {
      return setFocusState(true);
    }
  }, React.createElement(Clear, {
    size: 20
  })), 'visible'), loading && renderAddon(React.createElement(LoaderCircular, {
    width: 20,
    indeterminate: true
  })), !loading && appendObject && renderAddon(appendObject), !loading && appendText && renderAddon(appendText)), info || message || counter ? React.createElement("div", {
    className: FormInfoContainer
  }, info || message ? React.createElement("div", {
    id: id ? "".concat(id, "-info-text") : null,
    className: FormInfo({
      disabled: disabled,
      error: error,
      message: message,
      success: success
    }),
    "aria-live": "polite"
  }, React.createElement("div", null, info ? info : ''), React.createElement("div", null, message ? message : prevMessage)) : null, counter ? React.createElement("div", {
    className: FormCounter({
      disabled: disabled
    })
  }, React.createElement("span", null, value.length), "/", counter) : null) : null);
};

TextAreaV2.defaultProps = {
  disabled: false,
  error: false,
  focus: false,
  full: false,
  isClearable: true,
  lang: 'id',
  loading: false,
  minRows: 3,
  readOnly: false,
  staticLabel: false,
  success: false,
  value: ''
};
export default TextAreaV2;