import type { ReactNode } from 'react';
export interface TextAreaV2Props {
    /**
     * Append object (node, image, icon, etc) on the component.
     */
    appendObject?: object | ReactNode;
    /**
     * Append suffix on the component.
     */
    appendText?: string;
    /**
     * Set the component container className.
     */
    className?: string;
    /**
     * Set the maximum number of characters and show the character counter.
     */
    counter?: number;
    /**
     * Set the component into disabled state.
     */
    disabled?: boolean;
    /**
     * Set the component into error state.
     */
    error?: boolean;
    /**
     * Set the component into focused state.
     */
    focus?: boolean;
    /**
     * Remove any styling of the component, this mode is used when you have TextArea inside BottomSheet and needed a full height TextArea.
     */
    full?: boolean;
    /**
     * Set the component id attribute.
     */
    id?: string;
    /**
     * Set the component info text.
     */
    info?: string;
    /**
     * Pass additional props to input element.
     */
    inputProps?: Record<string, any>;
    /**
     * Show component clear action, when the value length is more than zero.
     */
    isClearable?: boolean;
    /**
     * Set the component label text.
     */
    label?: string;
    /**
     * Set the component language, this affect several aria attributes for accessibilities.
     */
    lang?: 'id' | 'en';
    /**
     * Set the component into loading state.
     */
    loading?: boolean;
    /**
     * Set the component maximum number of characters without showing any counter.
     */
    maxLength?: number;
    /**
     * Set the component maximum number of rows.
     */
    maxRows?: number;
    /**
     * Show the component message on validation (onChange, etc).
     */
    message?: string;
    /**
     * Set the component minimum number of rows.
     */
    minRows?: number;
    /**
     * Set the component name attribute.
     */
    name?: string;
    /**
     * Set the component placeholder. If the TextArea has `label` property, the label will be positioned on top by default.
     */
    placeholder?: string;
    /**
     * Set the component into readonly state.
     */
    readOnly?: boolean;
    /**
     * Set the component label text position on top by default.
     */
    staticLabel?: boolean;
    /**
     * Set the component into success state.
     */
    success?: boolean;
    /**
     * Set the component value.
     */
    value?: string;
    /**
     * Callback for onblur.
     */
    onBlur?: (e: React.FocusEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onchange.
     */
    onChange?: (e: React.ChangeEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback when clicking the clear icon when `isClearable` is set to `true`.
     */
    onClear?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /**
     * Callback for onclick.
     */
    onClick?: (e: React.MouseEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onfocus.
     */
    onFocus?: (e: React.FocusEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for oninput.
     */
    onInput?: (e: React.KeyboardEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onkeydown.
     */
    onKeyDown?: (e: React.KeyboardEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onkeypress.
     */
    onKeyPress?: (e: React.KeyboardEvent<HTMLTextAreaElement>) => void;
    /**
     * Callback for onkeyup.
     */
    onKeyUp?: (e: React.KeyboardEvent<HTMLTextAreaElement>) => void;
}
