import React, { PureComponent } from 'react';
export interface TextFieldProps {
    /**
     * Append object (node, image, icon, etc) on the component.
     */
    appendObject?: React.ReactNode;
    /**
     * Prepend suffix string on the component.
     */
    appendText?: string;
    /**
     * Turn on native autocapitalize.
     */
    autoCapitalize?: string;
    /**
     * Turn on native autocomplete.
     */
    autoComplete?: string;
    /**
     * Turn on auto native autocorrect.
     */
    autoCorrect?: string;
    /**
     * Set the component container className (not the input element).
     */
    className?: string;
    /**
     * Set the maximum number of characters and show the character counter.
     */
    counter?: number;
    /**
     * Set the component into disabled state.
     */
    disabled?: boolean;
    /**
     * Display suggestions, use in tandem with `suggestions`.
     */
    displaySuggestions?: boolean;
    /**
     * Set the component into error state.
     */
    error?: boolean;
    /**
     * Set the component input id attribute.
     */
    id?: string;
    /**
     * Set the component info text.
     */
    info?: string;
    /**
     * Set the component label text position on top by default.
     */
    inlineLabel?: boolean;
    /**
     * Set the component label.
     */
    label?: string;
    /**
     * Set the component maximum number of characters without showing any counter.
     */
    maxLength?: number;
    /**
     * Show the TextField message on validation (onChange, etc), if `info` is present, message will be hidden until info is cleared.
     */
    message?: string;
    /**
     * Set the component input name attribute.
     */
    name?: string;
    /**
     * Set the component placeholder text. If the component has `label` property, the label will be positioned on top by default.
     */
    placeholder?: string;
    /**
     * Prepend object (node, image, icon, etc) on the component.
     */
    prependObject?: React.ReactNode;
    /**
     * Prepend prefix string on the component.
     */
    prependText?: string;
    /**
     * Set the TextField into readonly state.
     */
    readonly?: boolean;
    /**
     * Turn on native spellcheck.
     */
    spellCheck?: string;
    /**
     * Set the component into success state.
     */
    success?: boolean;
    /**
     * Show list of suggestions below the component.
     */
    suggestions?: object[];
    /**
     * Set the component input type.
     */
    type?: string;
    /**
     * Set the component input value.
     */
    value?: string;
    /**
     * Reserve space for any `info` and `message` prop provided.
     */
    withInfo?: boolean;
    /**
     * `Deprecated` Remove any component animation.
     */
    withoutAnimation?: boolean;
    /**
     * Callback for onblur.
     */
    onBlur?: (e: React.FocusEvent<HTMLInputElement>) => void;
    /**
     * Callback for onchange.
     */
    onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
    /**
     * Callback for onclick.
     */
    onClick?: (e: React.MouseEvent<HTMLInputElement>) => void;
    /**
     * Callback for onfocus.
     */
    onFocus?: (e: React.FocusEvent<HTMLInputElement>) => void;
    /**
     * Callback for oninput.
     */
    onInput?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    /**
     * Callback for onkeydown.
     */
    onKeyDown?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    /**
     * Callback for onkeypress.
     */
    onKeyPress?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    /**
     * Callback for onkeyup.
     */
    onKeyUp?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    /**
     * Callback when Suggestion is selected
     */
    onSelect?: (e: React.MouseEvent<HTMLDivElement>) => void;
}
declare class TextField extends PureComponent<TextFieldProps> {
    constructor(props: any);
    componentDidMount(): void;
    componentDidUpdate(prevProps: any, prevState: any): void;
    handleMessage: (text: any) => void;
    handleNoAnimation: (text: any) => void;
    handleFocus: (e: any) => void;
    handleBlur: (e: any) => void;
    handleSelect: (event: any, suggestion: any) => void;
    handlePasswordVisibility: () => void;
    handleLabelPosition: (adjust: any) => void;
    renderAddon: (props: any) => JSX.Element;
    renderAddonPassword: () => JSX.Element;
    handleToolbar: (bool: any) => void;
    render(): JSX.Element;
}
export default TextField;
