import React, { ReactNode } from 'react';
import { MarginType } from '~/common/types/styles';
export interface TextFieldV2Props extends MarginType {
    /**
     * Append object (node, image, icon, etc) on the component.
     */
    appendObject?: ReactNode;
    /**
     * Append suffix on the component.
     */
    appendText?: string;
    /**
     * Turn on native autocapitalize.
     */
    autoCapitalize?: string;
    /**
     * Turn on native autocomplete.
     */
    autoComplete?: string;
    /**
     * Turn on auto native autocorrect.
     */
    autoCorrect?: string;
    /**
     * Set the component container className (not the input element).
     */
    className?: string;
    /**
     * Set the maximum number of characters and show the character counter.
     */
    counter?: number;
    /**
     * Set the component into disabled state.
     */
    disabled?: boolean;
    /**
     * Display suggestions, use in tandem with `suggestions`.
     */
    displaySuggestions?: boolean;
    /**
     * Set the component into error state.
     */
    error?: boolean;
    /**
     * Set the component into focused state.
     */
    focus?: boolean;
    /**
     * Set the component input id attribute.
     */
    id?: string;
    /**
     * Set the component info text.
     */
    info?: string;
    /**
     * Set the component input inputMode attribute.
     */
    inputMode?: 'text' | 'search' | 'none' | 'tel' | 'url' | 'email' | 'numeric' | 'decimal';
    /**
     * Props spread into input element
     */
    inputProps?: React.ComponentPropsWithoutRef<'input'>;
    /**
     * Show component clear action, when the value length is more than zero.
     */
    isClearable?: boolean;
    /**
     * Set the component label.
     */
    label?: string;
    /**
     * Set the component language, this affect several aria attributes for accessibilities.
     */
    lang?: 'id' | 'en';
    /**
     * Set the component into loading state.
     */
    loading?: boolean;
    /**
     * Set the component maximum number of characters without showing any counter.
     */
    maxLength?: number;
    /**
     * Show the component message on validation (onChange, etc).
     */
    message?: ReactNode;
    /**
     * Set the component input name attribute.
     */
    name?: string;
    /**
     * Set the component placeholder text. If the component has `label` property, the label will be positioned on top by default.
     */
    placeholder?: string;
    /**
     * Prepend object (node, image, icon, etc) on the component.
     */
    prependObject?: ReactNode;
    /**
     * Prepend prefix on the component.
     */
    prependText?: string;
    /**
     * Set the TextField into readonly state.
     */
    readOnly?: boolean;
    /**
     * Turn on native spellcheck.
     */
    spellCheck?: boolean;
    /**
     * Set the component label text position on top by default.
     */
    staticLabel?: boolean;
    /**
     * Set the component into success state.
     */
    success?: boolean;
    /**
     * Show list of suggestions below the component.
     */
    suggestions?: object[];
    /**
     * Set the component input type.
     */
    type?: string;
    /**
     * Set the component input value.
     */
    value?: string;
    /**
     * Callback for onblur.
     */
    onBlur?: (e: React.FocusEvent<HTMLInputElement>) => void;
    /**
     * Callback for onchange.
     */
    onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
    /**
     * Callback when clicking the clear icon when `isClearable` is set to `true`.
     */
    onClear?: (e: React.MouseEvent<HTMLButtonElement>) => void;
    /**
     * Callback for onclick.
     */
    onClick?: (e: React.MouseEvent<HTMLInputElement>) => void;
    /**
     * Callback for onfocus.
     */
    onFocus?: (e: React.FocusEvent<HTMLInputElement>) => void;
    /**
     * Callback for oninput.
     */
    onInput?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    /**
     * Callback for onkeydown.
     */
    onKeyDown?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    /**
     * Callback for onkeypress.
     */
    onKeyPress?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    /**
     * Callback for onkeyup.
     */
    onKeyUp?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
}
declare const TextFieldV2: {
    (props: TextFieldV2Props): JSX.Element;
    propTypes: {
        appendObject: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        appendText: import("prop-types").Requireable<string>;
        autoCapitalize: import("prop-types").Requireable<string>;
        autoComplete: import("prop-types").Requireable<string>;
        autoCorrect: import("prop-types").Requireable<string>;
        className: import("prop-types").Requireable<string>;
        counter: import("prop-types").Requireable<number>;
        disabled: import("prop-types").Requireable<boolean>;
        displaySuggestions: import("prop-types").Requireable<boolean>;
        error: import("prop-types").Requireable<boolean>;
        focus: import("prop-types").Requireable<boolean>;
        id: import("prop-types").Requireable<string>;
        info: import("prop-types").Requireable<string>;
        inputMode: import("prop-types").Requireable<string>;
        isClearable: import("prop-types").Requireable<boolean>;
        label: import("prop-types").Requireable<string>;
        lang: import("prop-types").Requireable<string>;
        loading: import("prop-types").Requireable<boolean>;
        maxLength: import("prop-types").Requireable<number>;
        message: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        name: import("prop-types").Requireable<string>;
        placeholder: import("prop-types").Requireable<string>;
        prependObject: import("prop-types").Requireable<import("prop-types").ReactNodeLike>;
        prependText: import("prop-types").Requireable<string>;
        readOnly: import("prop-types").Requireable<boolean>;
        spellCheck: import("prop-types").Requireable<boolean>;
        staticLabel: import("prop-types").Requireable<boolean>;
        success: import("prop-types").Requireable<boolean>;
        suggestions: import("prop-types").Requireable<object[]>;
        type: import("prop-types").Requireable<string>;
        value: import("prop-types").Requireable<string>;
        onBlur: import("prop-types").Requireable<(...args: any[]) => any>;
        onChange: import("prop-types").Requireable<(...args: any[]) => any>;
        onClear: import("prop-types").Requireable<(...args: any[]) => any>;
        onClick: import("prop-types").Requireable<(...args: any[]) => any>;
        onFocus: import("prop-types").Requireable<(...args: any[]) => any>;
        onInput: import("prop-types").Requireable<(...args: any[]) => any>;
        onKeyDown: import("prop-types").Requireable<(...args: any[]) => any>;
        onKeyPress: import("prop-types").Requireable<(...args: any[]) => any>;
        onKeyUp: import("prop-types").Requireable<(...args: any[]) => any>;
    };
    defaultProps: {
        disabled: boolean;
        displaySuggestions: boolean;
        error: boolean;
        focus: boolean;
        isClearable: boolean;
        lang: string;
        loading: boolean;
        readOnly: boolean;
        staticLabel: boolean;
        success: boolean;
        suggestions: any[];
        type: string;
        value: string;
    };
};
export default TextFieldV2;
