import _extends from "@babel/runtime/helpers/extends";
import _typeof from "@babel/runtime/helpers/typeof";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
var _excluded = ["appendObject", "appendText", "autoCapitalize", "autoComplete", "autoCorrect", "spellCheck", "className", "counter", "disabled", "displaySuggestions", "error", "focus", "id", "info", "inputMode", "inputProps", "isClearable", "label", "lang", "loading", "maxLength", "message", "name", "placeholder", "prependObject", "prependText", "readOnly", "staticLabel", "success", "suggestions", "type", "value", "onBlur", "onChange", "onClear", "onClick", "onFocus", "onInput", "onKeyDown", "onKeyPress", "onKeyUp"];
import React, { useEffect, useRef, useState } from 'react';
import { NN900L } from 'unify-token/colors';
import { Visibility, VisibilityOff } from 'unify-icons/system';
import Clear from 'unify-icons/system/Clear';
import LoaderCircular from "../../build/Circular";
import Toolbar from "../../build/Toolbar";
import { FormContainer, FormGroup, FormLabelSpacer, FormInputContainer, FormAddon, FormClear, FormInfoContainer, FormInfo, FormCounter, FORM_GROUP_PADDING, FORM_INPUT_LINE_HEIGHT, FORM_INPUT_PADDING, FORM_LABEL_LINE_HEIGHT_MIN } from "../../build/Providers/styles/Form/_Common.style";
import { addClass, handleAnimationFrame, removeClass } from "../../build/Providers/common/functions";
import { Input, Label, VisibilityButton, VisibilityIcon } from "./style";

var TextFieldV2 = function TextFieldV2(props) {
  var _useState = useState(props.focus),
      _useState2 = _slicedToArray(_useState, 2),
      focusState = _useState2[0],
      setFocusState = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      showPassword = _useState4[0],
      setShowPassword = _useState4[1];

  var appendObject = props.appendObject,
      appendText = props.appendText,
      autoCapitalize = props.autoCapitalize,
      autoComplete = props.autoComplete,
      autoCorrect = props.autoCorrect,
      spellCheck = props.spellCheck,
      className = props.className,
      counter = props.counter,
      disabled = props.disabled,
      displaySuggestions = props.displaySuggestions,
      error = props.error,
      focus = props.focus,
      id = props.id,
      info = props.info,
      inputMode = props.inputMode,
      inputProps = props.inputProps,
      isClearable = props.isClearable,
      label = props.label,
      lang = props.lang,
      loading = props.loading,
      maxLength = props.maxLength,
      message = props.message,
      name = props.name,
      placeholder = props.placeholder,
      prependObject = props.prependObject,
      prependText = props.prependText,
      readOnly = props.readOnly,
      staticLabel = props.staticLabel,
      success = props.success,
      suggestions = props.suggestions,
      type = props.type,
      value = props.value,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onClear = props.onClear,
      onClick = props.onClick,
      onFocus = props.onFocus,
      onInput = props.onInput,
      onKeyDown = props.onKeyDown,
      onKeyPress = props.onKeyPress,
      onKeyUp = props.onKeyUp,
      otherProps = _objectWithoutProperties(props, _excluded);

  var containerRef = useRef(null);
  var wrapperRef = useRef(null);
  var labelRef = useRef(null);
  var labelSpacerRef = useRef(null);
  var inputRef = useRef(null);
  var toolbarRef = useRef(null);
  var isAnimated = useRef(false);
  var labelTop = (FORM_LABEL_LINE_HEIGHT_MIN / 2 + 0.5) * 100 / (FORM_INPUT_PADDING * 2 + FORM_INPUT_LINE_HEIGHT + 2);
  var ariaLabel = {
    id: {
      clear: "Hapus".concat(label ? " ".concat(label) : ''),
      password_hide: 'Sembunyikan password',
      password_show: 'Tampilkan password'
    },
    en: {
      clear: "Clear".concat(label ? " ".concat(label) : ''),
      password_hide: 'Hide password',
      password_show: 'Show password'
    }
  };
  useEffect(function () {
    focus && inputRef.current.focus();
  }, [focus]);
  useEffect(function () {
    if (label) {
      if (!isAnimated.current) {
        focusState && animateLabel(true);
      } else {
        value === '' && animateLabel(false);
      }
    }
  }, [focusState]);
  useEffect(function () {
    if (label) {
      if (value !== '') {
        !isAnimated.current && animateLabel(true);
      } else {
        !focusState && animateLabel(false);
      }
    }
  }, [value]);

  var animateLabel = function animateLabel(adjust) {
    var DOM = labelRef.current;

    if (placeholder || staticLabel) {
      return false;
    } else {
      isAnimated.current = adjust;
      var offsetLeft = wrapperRef.current ? wrapperRef.current.offsetLeft : 0;
      handleAnimationFrame(function () {
        DOM.style.top = adjust ? "-".concat(labelTop, "%") : '';
        DOM.style.transform = adjust ? "translateX(-".concat(offsetLeft - FORM_GROUP_PADDING, "px)") : '';
      });
    }
  };

  var animateToolbar = function animateToolbar(bool) {
    var toolbar = toolbarRef.current;
    setTimeout(function () {
      toolbar && bool ? addClass('unf-toolbar--show', toolbar) : removeClass('unf-toolbar--show', toolbar);
    }, 50);
  };

  var handleBlur = function handleBlur(e) {
    setFocusState(false);
    displaySuggestions && animateToolbar(false);
    onBlur && onBlur(e);
  };

  var handleFocus = function handleFocus(e) {
    setFocusState(true);
    displaySuggestions && animateToolbar(true);
    onFocus && onFocus(e);
  };

  var handleSelect = function handleSelect(e, suggestion) {
    suggestion.onSelect && suggestion.onSelect(e, suggestion);
    addClass('unf-toolbar--show', toolbarRef.current);
    inputRef.current.focus();
  };

  var handleClear = function handleClear(e) {
    e.preventDefault();
    e.stopPropagation();
    isAnimated.current = false;
    inputRef.current.focus();
    onClear && onClear(e);
  };

  var renderAddon = function renderAddon(content) {
    var overflow = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'hidden';

    if (_typeof(content) === 'object') {
      if (content.type && content.type === React.Fragment) {
        return React.createElement("div", {
          className: FormAddon({
            disabled: disabled,
            overflow: overflow
          })
        }, React.Children.map(content.props.children, function (child) {
          return typeof child === 'string' ? React.createElement("span", null, child) : child;
        }));
      }
    }

    return React.createElement("div", {
      className: FormAddon({
        disabled: disabled,
        overflow: overflow
      })
    }, content);
  };

  var renderAddonPassword = function renderAddonPassword() {
    var iconProps = {
      'aria-label': showPassword ? ariaLabel[String(lang)].password_hide : ariaLabel[String(lang)].password_show,
      color: disabled && NN900L,
      size: 20,
      disabled: disabled
    };
    return React.createElement("button", {
      className: VisibilityButton,
      type: "button",
      onClick: function onClick() {
        !disabled && setShowPassword(!showPassword);
      }
    }, showPassword ? React.createElement(VisibilityOff, _extends({
      className: VisibilityIcon
    }, iconProps)) : React.createElement(Visibility, _extends({
      className: VisibilityIcon
    }, iconProps)));
  };

  return React.createElement(FormContainer, _extends({
    innerRef: containerRef,
    className: className,
    hasLabel: label
  }, otherProps), React.createElement(FormGroup, {
    disabled: disabled,
    error: error,
    focus: focusState,
    formLabel: label,
    formPlaceholder: placeholder,
    formValue: value,
    staticLabel: staticLabel,
    success: success
  }, label && React.createElement(FormLabelSpacer, {
    disabled: disabled,
    error: error,
    focus: focusState,
    formPlaceholder: placeholder,
    staticLabel: staticLabel,
    success: success
  }, React.createElement("span", {
    ref: labelSpacerRef,
    "aria-hidden": placeholder || staticLabel ? false : true,
    "aria-label": placeholder && label
  }, label)), prependText && renderAddon(prependText), prependObject && renderAddon(prependObject), React.createElement("div", {
    ref: wrapperRef,
    className: FormInputContainer
  }, React.createElement(Input, _extends({
    "aria-describedby": id ? "".concat(id, "-info-text") : null
  }, inputProps, {
    innerRef: inputRef,
    "data-unify": "TextField",
    autoCapitalize: autoCapitalize,
    autoComplete: autoComplete,
    autoCorrect: autoCorrect,
    disabled: disabled,
    id: id,
    isClearable: isClearable,
    inputMode: inputMode,
    maxLength: counter || maxLength,
    name: name,
    placeholder: placeholder,
    readOnly: readOnly,
    spellCheck: spellCheck,
    type: type === 'password' && showPassword ? 'text' : type,
    value: value,
    onBlur: handleBlur,
    onChange: onChange,
    onClick: onClick,
    onFocus: handleFocus,
    onInput: onInput,
    onKeyDown: onKeyDown,
    onKeyPress: onKeyPress,
    onKeyUp: onKeyUp
  })), label && React.createElement(Label, {
    innerRef: labelRef,
    htmlFor: id,
    "aria-hidden": placeholder || staticLabel ? true : false,
    disabled: disabled,
    focus: focusState,
    formPlaceholder: placeholder,
    formValue: value,
    hasPrepend: prependText || prependObject ? true : false,
    staticLabel: staticLabel
  }, label)), type === 'password' && renderAddonPassword(), !disabled && isClearable && value.length > 0 && renderAddon(React.createElement("button", {
    className: FormClear,
    "aria-label": ariaLabel[String(lang)].clear,
    onClick: handleClear,
    onFocus: function onFocus() {
      return setFocusState(true);
    }
  }, React.createElement(Clear, {
    size: 20
  })), 'visible'), loading && renderAddon(React.createElement(LoaderCircular, {
    width: 20,
    indeterminate: true
  })), appendObject && renderAddon(appendObject), appendText && renderAddon(appendText)), info || message || counter ? React.createElement("div", {
    className: FormInfoContainer
  }, info || message ? React.createElement("div", {
    id: id ? "".concat(id, "-info-text") : null,
    className: FormInfo({
      disabled: disabled,
      error: error,
      message: message,
      success: success
    }),
    "aria-live": "polite"
  }, React.createElement("div", null, info ? info : ''), React.createElement("div", null, message ? message : '')) : null, counter ? React.createElement("div", {
    className: FormCounter({
      disabled: disabled
    })
  }, React.createElement("span", null, value.length), "/", counter) : null) : null, displaySuggestions && React.createElement(Toolbar, {
    toolbarRef: toolbarRef,
    suggestions: suggestions,
    onSelect: handleSelect
  }));
};

TextFieldV2.defaultProps = {
  disabled: false,
  displaySuggestions: false,
  error: false,
  focus: false,
  isClearable: false,
  lang: 'id',
  loading: false,
  readOnly: false,
  staticLabel: false,
  success: false,
  suggestions: [],
  type: 'text',
  value: ''
};
export default TextFieldV2;