import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["additional", "auto", "className", "error", "indexActive", "items", "slideDuration", "warning", "full", "onClick", "onClose", "onSwipe"];
import React, { useState, useEffect, useRef, useCallback } from 'react';
import { Information, Warning, Block } from 'unify-icons/system';
import { cx } from 'emotion';
import { RN500, BN400, YN300, NN950 } from 'unify-token/colors';
import Close from 'unify-icons/system/Close';
import PageControl from "../../build/PageControl";
import Typography from "../../build/Typography";
import { useKeyboardControl } from "../../build/Providers/common/hooks";
import checkString from "../../build/Providers/common/functions/isString";
import { noop } from "../../build/Providers/common/functions/noop";
import { Container, List, Slider, Item, unf_ticker_child_wrap, handlePageControlColor, tickerIconContainer } from "./style";

var Ticker = function Ticker(_ref) {
  var _ref$additional = _ref.additional,
      additional = _ref$additional === void 0 ? [] : _ref$additional,
      auto = _ref.auto,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      error = _ref.error,
      _ref$indexActive = _ref.indexActive,
      indexActiveProp = _ref$indexActive === void 0 ? 0 : _ref$indexActive,
      _ref$items = _ref.items,
      items = _ref$items === void 0 ? [] : _ref$items,
      _ref$slideDuration = _ref.slideDuration,
      slideDuration = _ref$slideDuration === void 0 ? 3000 : _ref$slideDuration,
      warning = _ref.warning,
      full = _ref.full,
      _ref$onClick = _ref.onClick,
      _onClick = _ref$onClick === void 0 ? noop : _ref$onClick,
      onClose = _ref.onClose,
      _ref$onSwipe = _ref.onSwipe,
      onSwipe = _ref$onSwipe === void 0 ? noop : _ref$onSwipe,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var _useState = useState(indexActiveProp),
      _useState2 = _slicedToArray(_useState, 2),
      indexActive = _useState2[0],
      setIndexActive = _useState2[1];

  var autoIntervalRef = useRef();
  var swiped = useRef(false);

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      isFocused = _useState4[0],
      setIsFocused = _useState4[1];

  var _useState5 = useState(true),
      _useState6 = _slicedToArray(_useState5, 2),
      show = _useState6[0],
      setShow = _useState6[1];

  var xDown;
  var yDown = 0;
  var startAutoplay = useCallback(function () {
    autoIntervalRef.current && clearInterval(autoIntervalRef.current);
    autoIntervalRef.current = setInterval(function () {
      setIndexActive(function (prevIndex) {
        return (prevIndex + 1) % items.length;
      });
    }, slideDuration);
  }, [items.length, slideDuration]);

  var stopAutoplay = function stopAutoplay() {
    autoIntervalRef.current && clearInterval(autoIntervalRef.current);
  };

  useEffect(function () {
    if (auto) {
      startAutoplay();
    }

    return function () {
      stopAutoplay();
    };
  }, [auto, startAutoplay]);
  useEffect(function () {
    if (auto && swiped.current) {
      stopAutoplay();
      startAutoplay();
      swiped.current = false;
    }
  }, [auto, indexActive, startAutoplay]);
  useEffect(function () {
    setIndexActive(Math.abs(indexActiveProp % items.length));
  }, [indexActiveProp, items.length]);

  var renderAction = function renderAction(item, isActiveItem) {
    var actionLink = item.actionLink,
        action = item.action;
    var tabIndex = isActiveItem ? '0' : '-1';
    return checkString(actionLink) ? React.createElement(Typography, {
      caption: true,
      bold: true,
      "data-unf": "unf-ticker-link",
      link: actionLink,
      tabIndex: Number(tabIndex)
    }, action) : React.createElement(Typography, {
      caption: true,
      bold: true,
      "data-unf": "unf-ticker-link",
      onClick: actionLink,
      tabIndex: Number(tabIndex)
    }, action);
  };

  var renderAdditional = function renderAdditional() {
    return additional && additional.length > 0 && React.createElement(List, null, additional.map(function (item, i) {
      return React.createElement("li", {
        key: i
      }, React.createElement(Typography, {
        caption: true,
        main: true,
        style: {
          display: 'inline-block'
        },
        margin: "0"
      }, item));
    }));
  };

  var handleTouchStart = function handleTouchStart(e) {
    var _e$touches$ = e.touches[0],
        clientX = _e$touches$.clientX,
        clientY = _e$touches$.clientY;
    xDown = clientX;
    yDown = clientY;
    stopAutoplay();
  };

  var handleTouchMove = function handleTouchMove(e) {
    var _e$touches$2 = e.touches[0],
        clientX = _e$touches$2.clientX,
        clientY = _e$touches$2.clientY;

    if (!xDown || !yDown) {
      return;
    }

    var xDiff = xDown - clientX;
    var yDiff = yDown - clientY;

    if (Math.abs(xDiff) > Math.abs(yDiff)) {
      swiped.current = true;

      if (xDiff > 0) {
        setIndexActive(function (prevIndex) {
          var newIndex = (prevIndex + 1) % items.length;
          onSwipe(newIndex, prevIndex, e);
          return newIndex;
        });
      } else {
        setIndexActive(function (prevIndex) {
          var newIndex = (prevIndex - 1 + items.length) % items.length;
          onSwipe(newIndex, prevIndex, e);
          return newIndex;
        });
      }
    }
  };

  var handleClose = function handleClose(e) {
    setShow(false);
    onClose && onClose(items[Number(indexActive)], indexActive, e);
  };

  var renderIcon = function renderIcon(item) {
    var single = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

    if (item.warning || single && warning) {
      return React.createElement(Warning, {
        color: YN300,
        size: 22
      });
    } else if (item.error || single && error) {
      return React.createElement(Block, {
        color: RN500,
        size: 22
      });
    } else if (item.info) {
      return;
    }

    return React.createElement(Information, {
      color: BN400,
      size: 22
    });
  };

  var classes = cx('unf-ticker', {
    'unf-ticker--warning': warning
  }, className);
  useKeyboardControl({
    ArrowRight: function ArrowRight() {
      setIndexActive(function (prevIndex) {
        var newIndex = (prevIndex + 1) % items.length;
        return newIndex;
      });
    },
    ArrowLeft: function ArrowLeft() {
      setIndexActive(function (prevIndex) {
        var newIndex = (prevIndex - 1 + items.length) % items.length;
        return newIndex;
      });
    }
  }, isFocused);

  var handleFocus = function handleFocus(e) {
    e.preventDefault();
    e.stopPropagation();

    if (auto) {
      stopAutoplay();
    }

    setIsFocused(true);
  };

  var handleBlur = function handleBlur(e) {
    e.preventDefault();
    e.stopPropagation();

    if (auto) {
      startAutoplay();
    }

    setIsFocused(false);
  };

  var focusAttr = auto ? {
    onMouseEnter: stopAutoplay,
    onMouseLeave: startAutoplay,
    onFocus: handleFocus,
    onBlur: handleBlur
  } : {};

  var handleItemOnClick = function handleItemOnClick(item, index, e) {
    typeof item.onClick === 'function' ? item.onClick(item, index, e) : null;
  };

  return items.length > 0 && React.createElement(Container, _extends({
    className: classes,
    onClick: function onClick(e) {
      _onClick(items[Number(indexActive)], indexActive, e);
    },
    show: show,
    full: full,
    onTouchStart: handleTouchStart,
    onTouchMove: handleTouchMove,
    "data-unf-test": indexActive,
    "data-unify": "Ticker",
    role: "marquee",
    "aria-live": "assertive",
    "aria-label": "You are currently on a Ticker with ".concat(items.length, " items. Navigate by swiping this region to the right or left."),
    "aria-describedby": 'unf-ticker__active-item',
    tabIndex: 0
  }, otherProps, focusAttr), onClose && React.createElement(Close, {
    onClick: function onClick(e) {
      handleClose(e);
    },
    style: {
      position: 'absolute',
      right: '8px',
      top: '8px',
      zIndex: 1
    },
    size: 18,
    className: "unf-ticker__close",
    role: "button",
    tabIndex: "0"
  }), items.length > 1 ? React.createElement(React.Fragment, null, React.createElement(Slider, {
    indexActive: indexActive
  }, items.map(function (item, i) {
    return React.createElement(Item, {
      warning: Boolean(item.warning),
      additional: [],
      error: item.error,
      info: item.info,
      key: i,
      full: full,
      itemNum: items.length,
      onClose: onClose,
      onFocusCapture: function onFocusCapture(e) {
        e.stopPropagation();
      },
      onBlurCapture: function onBlurCapture(e) {
        e.stopPropagation();
      },
      onClick: function onClick(e) {
        handleItemOnClick(item, i, e);
      },
      "aria-hidden": i === indexActive ? 'false' : 'true',
      id: i === indexActive ? 'unf-ticker__active-item' : '',
      "data-unify": "ticker__item"
    }, !item.info && React.createElement("div", {
      className: tickerIconContainer
    }, renderIcon(item)), React.createElement("div", null, item.title && React.createElement(Typography, {
      color: NN950,
      tag: 5,
      bold: true,
      margin: "0"
    }, item.title), React.createElement("span", {
      className: unf_ticker_child_wrap
    }, item.setInnerHTML ? React.createElement("span", {
      dangerouslySetInnerHTML: {
        __html: item.text ? item.text : ''
      }
    }) : item.text), item.action && renderAction(item, i === indexActive)));
  })), React.createElement(PageControl, {
    "data-unf": "unf__ticker-control",
    activeColor: handlePageControlColor(items[Number(indexActive)]),
    currentPage: indexActive,
    numberOfPage: items.length
  })) : React.createElement(Item, {
    "aria-label": items[0].title,
    warning: items[0].warning,
    additional: additional,
    error: error || items[0].error,
    full: full,
    itemNum: items.length,
    id: 'unf-ticker__active-item',
    "data-unify": "ticker__item",
    info: items[0].info,
    onClose: onClose
  }, !items[0].info && additional.length <= 0 && React.createElement("div", {
    className: tickerIconContainer
  }, renderIcon(items[0], true)), React.createElement("div", null, items[0].title && React.createElement(Typography, {
    tag: 5,
    main: true,
    bold: true,
    margin: "0"
  }, items[0].title), React.createElement("span", {
    className: unf_ticker_child_wrap
  }, items[0].setInnerHTML ? React.createElement("span", {
    dangerouslySetInnerHTML: {
      __html: items[0].text ? items[0].text : ''
    }
  }) : items[0].text, items[0].action && renderAction(items[0], true)), renderAdditional())));
};

export default Ticker;