import React, { MouseEvent, TouchEvent, ComponentPropsWithoutRef } from 'react';
export interface TickerItem {
    action?: string;
    actionLink?: string | (() => void);
    error?: boolean;
    info?: boolean;
    setInnerHTML?: boolean;
    text?: React.ReactNode;
    title?: string;
    warning?: boolean;
    onClick?: (item: TickerItem, i: number, e: MouseEvent<HTMLDivElement>) => void;
}
declare type TickerAttributes = ComponentPropsWithoutRef<'div'>;
export interface TickerProps extends Omit<TickerAttributes, 'css' | 'onClick'> {
    /**
     * To apply info Ticker design. WILL DEPRECATE, use component Tips instead.
     * @default []
     */
    additional?: string[];
    /**
     * To apply auto slide. Auto slide stops when Ticker is focused or hovered for accessibiliity purpose.
     */
    auto?: boolean;
    /**
     * To pass custom classname to apply custom style
     * @default ''
     */
    className?: string;
    /**
     * To apply error ticker design
     */
    error?: boolean;
    /**
     * To apply full ticker design
     */
    full?: boolean;
    /**
     * To indicate active ticker
     * @default 0
     */
    indexActive?: number;
    /**
     * To specify ticker items
     * @default []
     */
    items?: TickerItem[];
    /**
     * To specify timeout duration before sliding to next index
     * @default 3000
     */
    slideDuration?: number;
    /**
     * To apply warning Ticker design
     */
    warning?: boolean;
    /**
     * To pass callback when ticker is clicked
     * @default {}
     */
    onClick?: (item: TickerItem, indexActive: number, e: MouseEvent<HTMLDivElement>) => void;
    /**
     * To pass callback when ticker is closed. Close button will be shown when this is set.
     */
    onClose?: (item: TickerItem, indexActive: number, e: MouseEvent<HTMLDivElement>) => void;
    /**
     * To pass callback when ticker is swiped
     * @default {}
     */
    onSwipe?: (newIndex: number, prevIndex: number, e: TouchEvent<HTMLDivElement>) => void;
}
export {};
