import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["colorVariant", "description", "highlightColor", "highlightLabel", "highlightSize", "id", "lang", "showIcon", "stickyProps", "targetTime", "timeFormat", "type", "onFinish"];
import React, { forwardRef, useEffect, useState, useRef, useCallback, Fragment, useImperativeHandle } from 'react';
import Clock from 'unify-icons/system/Clock';
import { easeDefault, durationT4 } from 'unify-token/build/v2/motions';
import { noop } from "../../build/Providers/common/functions/noop";
import { TimerContainer, TimerDescription, TimerLabel, TimerText, TimerTextBox, TimerTextNumber, HighlightContainer, HighlightElement, HighlightNumber, HighlightBox, HighlightContent, HighlightSeparator, HighlightLabel, timerLabelSticky, handleTimerTextColor } from "./style";

var padding0 = function padding0(string) {
  if ("".concat(string).length === 1) {
    return "0".concat(string);
  }

  return "".concat(string);
};

var Timer = forwardRef(function (_ref, ref) {
  var _ref$colorVariant = _ref.colorVariant,
      colorVariant = _ref$colorVariant === void 0 ? 'general' : _ref$colorVariant,
      _ref$description = _ref.description,
      description = _ref$description === void 0 ? '' : _ref$description,
      _ref$highlightColor = _ref.highlightColor,
      highlightColor = _ref$highlightColor === void 0 ? 'light' : _ref$highlightColor,
      _ref$highlightLabel = _ref.highlightLabel,
      highlightLabel = _ref$highlightLabel === void 0 ? true : _ref$highlightLabel,
      _ref$highlightSize = _ref.highlightSize,
      highlightSize = _ref$highlightSize === void 0 ? 'small' : _ref$highlightSize,
      _ref$id = _ref.id,
      id = _ref$id === void 0 ? 'default' : _ref$id,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      _ref$showIcon = _ref.showIcon,
      showIcon = _ref$showIcon === void 0 ? true : _ref$showIcon,
      _ref$stickyProps = _ref.stickyProps,
      stickyProps = _ref$stickyProps === void 0 ? {
    placement: 'top',
    distance: '0px',
    zIndex: '10'
  } : _ref$stickyProps,
      _ref$targetTime = _ref.targetTime,
      targetTime = _ref$targetTime === void 0 ? new Date() : _ref$targetTime,
      _ref$timeFormat = _ref.timeFormat,
      timeFormat = _ref$timeFormat === void 0 ? 'auto' : _ref$timeFormat,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'single' : _ref$type,
      _ref$onFinish = _ref.onFinish,
      onFinish = _ref$onFinish === void 0 ? noop : _ref$onFinish,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var getTimeDiff = useCallback(function () {
    var seconds = (targetTime.getTime() - new Date().getTime()) / 1000;
    var rounded = Math.round(seconds);

    if (Math.abs(rounded - seconds) < 0.1) {
      return rounded;
    }

    return seconds;
  }, [targetTime]);
  var processTime = useCallback(function (aria) {
    var seconds = getTimeDiff();
    var day;
    var hour;
    var minute;
    day = hour = minute = 0;

    if (seconds > 0) {
      day = Math.floor(seconds / 86400);
      seconds %= 86400;
      hour = Math.floor(seconds / 3600);
      seconds %= 3600;
      minute = Math.floor(seconds / 60);
      seconds %= 60;
    } else {
      seconds = 0;
    }

    switch (timeFormat) {
      case 'HH:MM:SS':
        {
          hour = day * 24 + hour;
          day = 0;

          if (hour > 99) {
            hour = 99;
          }

          break;
        }

      case 'MM:SS':
        {
          minute = day * 1440 + hour * 60 + minute;
          day = 0;
          hour = 0;

          if (minute > 99) {
            minute = 99;
          }

          break;
        }

      case 'minutes':
        {
          minute = day * 1440 + hour * 60 + minute;
          day = 0;
          hour = 0;

          if (minute > 99) {
            minute = 99;
          }

          break;
        }

      case 'seconds':
        {
          seconds = day * 86400 + hour * 3600 + minute * 60 + seconds;
          day = 0;
          hour = 0;
          minute = 0;

          if (seconds > 99) {
            seconds = 99;
          }

          break;
        }
    }

    if (aria) {
      return {
        day: String(day),
        hour: String(hour),
        minute: String(minute),
        second: String(Math.floor(seconds))
      };
    }

    return {
      day: padding0(String(day)),
      hour: padding0(String(hour)),
      minute: padding0(String(minute)),
      second: padding0(String(Math.floor(seconds)))
    };
  }, [timeFormat, getTimeDiff]);

  var _useState = useState(processTime()),
      _useState2 = _slicedToArray(_useState, 2),
      timeCount = _useState2[0],
      setTimeCount = _useState2[1];

  var timeCountRef = useRef(processTime());
  var timeOutRef = useRef();
  var intervalRef = useRef();
  var ariaTimeoutRef = useRef();
  var ariaLabelRef = useRef(null);
  var containerRef = useRef(null);
  var firstUpdateRef = useRef(true);
  var singleContainerRef = useRef(null);
  useImperativeHandle(ref, function () {
    return type === 'single' ? singleContainerRef === null || singleContainerRef === void 0 ? void 0 : singleContainerRef.current : containerRef === null || containerRef === void 0 ? void 0 : containerRef.current;
  });
  var animateRotation = useCallback(function () {
    var classNames = ['day', 'hour', 'minute', 'second'];
    var timeCt = timeCountRef.current;
    var value = [timeCt.day, timeCt.hour, timeCt.minute, timeCt.second];
    var nextTimeCount = processTime();
    var nextValue = [nextTimeCount.day, nextTimeCount.hour, nextTimeCount.minute, nextTimeCount.second];

    if (type === 'highlight' || timeFormat !== 'auto') {
      value.map(function (item, i) {
        var _containerRef$current;

        var dom = containerRef === null || containerRef === void 0 ? void 0 : (_containerRef$current = containerRef.current) === null || _containerRef$current === void 0 ? void 0 : _containerRef$current.querySelector(".unf-timer__".concat(classNames[i]));
        var nextValueI = nextValue[i];

        if (dom) {
          if (item[0] !== nextValueI[0] && dom.children[0]) {
            var dom0 = dom.children[0];
            dom0.style.transition = "transform ".concat(durationT4, " ").concat(easeDefault);
            dom0.children[0].textContent = nextValueI[0];
            dom0.style.transform = 'translateY(0px)';
            setTimeout(function () {
              var dom0 = dom.children[0];
              dom0.style.transition = '';
              dom0.children[1].textContent = nextValueI[0];
              dom0.style.transform = '';
            }, 400);
          }

          if (item[1] !== nextValueI[1] && dom.children[1]) {
            var dom1 = dom.children[1];
            dom1.style.transition = "transform ".concat(durationT4, " ").concat(easeDefault);
            dom1.children[0].textContent = nextValueI[1];
            dom1.style.transform = 'translateY(0px)';
            setTimeout(function () {
              var dom1 = dom.children[1];
              dom1.style.transition = '';
              dom1.children[1].textContent = nextValueI[1];
              dom1.style.transform = '';
            }, 400);
          }
        }
      });
    } else {
      var seconds = getTimeDiff();

      if (seconds === 86399 || seconds === 3599 || seconds === 59) {
        setTimeout(function () {
          var timeCountVar = processTime();
          timeCountVar.second = '59';
          setTimeCount(timeCountVar);
        }, 400);
      }

      if (seconds !== 86399 && seconds !== 3599 && seconds !== 59) {
        value.map(function (item, i) {
          var _containerRef$current2;

          var dom = containerRef === null || containerRef === void 0 ? void 0 : (_containerRef$current2 = containerRef.current) === null || _containerRef$current2 === void 0 ? void 0 : _containerRef$current2.querySelector(".unf-timer__".concat(classNames[i]));
          var nextValueI = nextValue[i];

          if (dom) {
            if (item[0] !== nextValueI[0] && dom.children[0]) {
              var dom0 = dom.children[0];
              dom0.style.transition = "transform ".concat(durationT4, " ").concat(easeDefault);
              dom0.children[0].textContent = nextValueI[0];
              dom0.style.transform = 'translateY(0)';
              setTimeout(function () {
                var dom0 = dom.children[0];
                dom0.style.transition = '';
                dom0.children[1].textContent = nextValueI[0];
                dom0.style.transform = '';
              }, 400);
            }

            if (item[1] !== nextValueI[1] && dom.children[1]) {
              var dom1 = dom.children[1];
              dom1.style.transition = "transform ".concat(durationT4, " ").concat(easeDefault);
              dom1.children[0].textContent = nextValueI[1];
              dom1.style.transform = 'translateY(0)';
              setTimeout(function () {
                var dom1 = dom.children[1];
                dom1.style.transition = '';
                dom1.children[1].textContent = nextValueI[1];
                dom1.style.transform = '';
              }, 400);
            }
          }
        });
      }
    }
  }, [getTimeDiff, processTime, type, timeFormat]);
  var countDown = useCallback(function () {
    var setTimeoutRerender = function setTimeoutRerender(delay) {
      timeOutRef.current = setTimeout(function () {
        setTimeCount(processTime());
        timeCountRef.current = processTime();
        countDown();
      }, delay);
    };

    var timeCt = timeCountRef.current;
    timeOutRef.current && clearTimeout(timeOutRef.current);
    intervalRef.current && clearInterval(intervalRef.current);

    if (type !== 'highlight' && timeFormat === 'auto' && parseInt(timeCt.day) >= 1) {
      setTimeoutRerender((parseInt(timeCt.hour) * 3600 + parseInt(timeCt.minute) * 60 + parseInt(timeCt.second)) * 1000 + 1000);
    } else if (timeFormat === 'days') {
      var now = new Date();
      var nextDay = new Date(now.getFullYear(), now.getMonth(), now.getDate() + 1);
      var timeoutDelay;

      if (nextDay.getTime() < targetTime.getTime()) {
        timeoutDelay = nextDay.getTime() - now.getTime();
      } else {
        timeoutDelay = targetTime.getTime() - now.getTime();
      }

      setTimeoutRerender(timeoutDelay);
    } else {
      animateRotation();
      timeCountRef.current = processTime();
      intervalRef.current = setInterval(function () {
        var seconds = getTimeDiff();

        if (seconds >= 0) {
          animateRotation();
          timeCountRef.current = processTime();
        } else {
          timeCountRef.current = processTime();
          onFinish();
          setTimeCount(processTime());
          intervalRef.current && clearInterval(intervalRef.current);
        }
      }, 1000);
    }
  }, [animateRotation, timeFormat, getTimeDiff, onFinish, processTime, type, targetTime]);
  var renderAriaText = useCallback(function () {
    var ariaText = '';
    var textArr = {
      id: ['hari', 'jam', 'menit', 'detik'],
      en: ['days', 'hours', 'minutes', 'seconds']
    };
    var timeCt = processTime(true);
    var value = [timeCt.day, timeCt.hour, timeCt.minute, timeCt.second];
    var iterator = [];
    iterator = [0, 1, 2, 3];
    var firstFlag = false;
    iterator.map(function (i) {
      if (!firstFlag) {
        firstFlag = Number(value[i]) > 0;
      }

      if (firstFlag || i === 3) {
        ariaText += "".concat(value[i], " ").concat(textArr[String(lang)][i]);
      }
    });
    return ariaText;
  }, [lang, processTime]);
  var ariaAnnounceInterval = useCallback(function () {
    var timeDiff = getTimeDiff() * 1000 - 1000;

    var delayTimeout = function delayTimeout(nearestMilliseconds) {
      ariaTimeoutRef.current = setTimeout(function () {
        if (ariaLabelRef.current) {
          ariaLabelRef.current.textContent = renderAriaText();
          ariaAnnounceInterval();
        }
      }, timeDiff % nearestMilliseconds + 1000);
    };

    switch (true) {
      case timeDiff > 86400000:
        delayTimeout(86400000);
        break;

      case timeDiff > 3600000:
        delayTimeout(1800000);
        break;

      case timeDiff > 60000:
        delayTimeout(300000);
        break;

      case timeDiff > 5000:
        delayTimeout(5000);
        break;

      case timeDiff > 0:
        delayTimeout(1000);
        break;
    }
  }, [getTimeDiff, renderAriaText]);
  useEffect(function () {
    if (!firstUpdateRef.current) {
      setTimeCount(processTime());
      timeCountRef.current = processTime();
    } else {
      firstUpdateRef.current = false;
    }

    timeOutRef.current = setTimeout(function () {
      countDown();
      ariaAnnounceInterval();
    }, (targetTime.getTime() - new Date().getTime()) % 1000);
    return function () {
      timeOutRef.current && clearTimeout(timeOutRef.current);
      intervalRef.current && clearInterval(intervalRef.current);
      ariaTimeoutRef.current && clearTimeout(ariaTimeoutRef.current);
    };
  }, [targetTime, countDown, processTime, ariaAnnounceInterval]);

  var getDayDiff = function getDayDiff() {
    var todayDate = new Date();
    todayDate.setHours(0, 0, 0, 0);
    var targetDateWithoutDay = new Date(targetTime.getFullYear(), targetTime.getMonth(), targetTime.getDate());
    var dayDiff = (targetDateWithoutDay.getTime() - todayDate.getTime()) / (1000 * 60 * 60 * 24);
    return dayDiff;
  };

  var renderDigitContainer = function renderDigitContainer(className, val) {
    return React.createElement(TimerTextBox, {
      className: "unf-timer__".concat(className),
      style: {
        width: '16px'
      }
    }, React.createElement(TimerTextNumber, {
      style: {
        textAlign: 'right'
      }
    }, React.createElement("div", null, "0"), React.createElement("div", null, val[0])), React.createElement(TimerTextNumber, {
      style: {
        textAlign: 'left'
      }
    }, React.createElement("div", null, "0"), React.createElement("div", null, val[1])));
  };

  var renderTimer = function renderTimer() {
    var classNames = ['day', 'hour', 'minute', 'second'];
    var toReturn = [];

    if (type === 'highlight') {
      var timeCt = timeCountRef.current;
      var textArr = {
        id: ['Hari', 'Jam', 'Menit', 'Detik'],
        en: ['Days', 'Hours', 'Minutes', 'Seconds']
      };
      var value = [timeCt.day, timeCt.hour, timeCt.minute, timeCt.second];
      value.map(function (item, i) {
        toReturn.push(React.createElement(Fragment, {
          key: i
        }, React.createElement(HighlightElement, null, React.createElement(HighlightBox, {
          highlightColor: highlightColor,
          highlightSize: highlightSize
        }, React.createElement(HighlightContent, {
          highlightSize: highlightSize,
          className: "unf-timer__".concat(classNames[i])
        }, React.createElement(HighlightNumber, {
          highlightSize: highlightSize,
          style: {
            textAlign: 'right'
          }
        }, React.createElement("div", null, "0"), React.createElement("div", null, item[0])), React.createElement(HighlightNumber, {
          highlightSize: highlightSize,
          style: {
            textAlign: 'left'
          }
        }, React.createElement("div", null, "0"), React.createElement("div", null, item[1])))), highlightLabel && React.createElement(HighlightLabel, {
          highlightColor: highlightColor,
          highlightSize: highlightSize
        }, textArr[String(lang)][String(i)])), i !== value.length - 1 && React.createElement(HighlightSeparator, {
          highlightColor: highlightColor,
          highlightSize: highlightSize
        }, ":")));
      });
      return React.createElement(HighlightContainer, {
        innerRef: containerRef,
        className: "unf-timer",
        "data-unify": "Timer",
        highlightSize: highlightSize,
        highlightLabel: highlightLabel
      }, toReturn);
    } else {
      var text = [];
      var _textArr = {
        id: ['hari', 'jam', 'menit', 'detik'],
        en: ['days', 'hours', 'minutes', 'seconds']
      };
      var _timeCt = timeCount;
      var _value = [_timeCt.day, _timeCt.hour, _timeCt.minute, _timeCt.second];
      var iterator = [];

      switch (timeFormat) {
        case 'HH:MM:SS':
          {
            iterator = [1, 2, 3];
            iterator.map(function (i) {
              text.push(React.createElement(Fragment, {
                key: i
              }, renderDigitContainer(classNames[i], _value[i]), i !== _value.length - 1 && React.createElement(TimerTextBox, {
                style: {
                  margin: '0 3px'
                }
              }, ":")));
            });
            break;
          }

        case 'MM:SS':
          {
            iterator = [2, 3];
            iterator.map(function (i) {
              text.push(React.createElement(Fragment, {
                key: i
              }, renderDigitContainer(classNames[i], _value[i]), i !== _value.length - 1 && React.createElement(TimerTextBox, {
                style: {
                  margin: '0 3px'
                }
              }, ":")));
            });
            break;
          }

        case 'days':
          {
            text.push("".concat(getDayDiff(), " ").concat(_textArr[String(lang)][0]));
            break;
          }

        case 'minutes':
          {
            iterator = [2, 3];
            iterator.map(function (i) {
              text.push(React.createElement(Fragment, {
                key: i
              }, renderDigitContainer(classNames[i], _value[i]), React.createElement(TimerTextBox, {
                style: {
                  margin: '0 3px'
                }
              }, _textArr[String(lang)][i])));
            });
            break;
          }

        case 'seconds':
          {
            var i = 3;
            text.push(React.createElement(Fragment, null, renderDigitContainer(classNames[i], _value[i]), React.createElement(TimerTextBox, {
              style: {
                margin: '0 3px'
              }
            }, _textArr[String(lang)][i])));
            break;
          }

        default:
          {
            if (parseInt(_timeCt.day) > 0) {
              text.push("".concat(getDayDiff(), " ").concat(_textArr[String(lang)][0]));
            } else {
              iterator = [1, 2, 3];
              iterator.map(function (i) {
                text.push(React.createElement(Fragment, {
                  key: i
                }, renderDigitContainer(classNames[i], _value[i]), i !== _value.length - 1 && React.createElement(TimerTextBox, {
                  style: {
                    margin: '0 3px'
                  }
                }, ":")));
              });
            }
          }
      }

      var timerHTML = React.createElement("div", {
        style: {
          display: 'flex',
          flexDirection: 'row',
          alignItems: 'center'
        }
      }, showIcon && React.createElement(Clock, {
        style: {
          flex: '0 0 16px',
          marginRight: '2px',
          marginLeft: 'auto'
        },
        size: 16,
        color: handleTimerTextColor({
          day: getDayDiff(),
          colorVariant: colorVariant,
          type: type,
          finished: getTimeDiff() < 0
        })
      }), React.createElement(TimerText, null, text), React.createElement("div", {
        id: "".concat(id, "-timerAria"),
        "aria-live": "polite",
        role: "timer",
        ref: ariaLabelRef,
        style: {
          width: '0',
          height: '0',
          overflow: 'hidden'
        }
      }, renderAriaText()));
      return type === 'single' ? React.createElement(TimerContainer, _extends({
        innerRef: singleContainerRef,
        className: "unf-timer",
        "data-unify": "Timer",
        "aria-labelledby": "".concat(id, "-timerAria")
      }, otherProps), description && React.createElement(TimerDescription, {
        type: type,
        colorVariant: colorVariant
      }, description), React.createElement(TimerLabel, {
        day: getDayDiff(),
        colorVariant: colorVariant,
        showIcon: showIcon,
        type: type,
        stickyProps: stickyProps,
        innerRef: containerRef,
        finished: getTimeDiff() < 0
      }, timerHTML)) : React.createElement(TimerLabel, _extends({
        className: "".concat(type === 'sticky' ? "unf-timer ".concat(timerLabelSticky) : 'unf-timer'),
        day: getDayDiff(),
        colorVariant: colorVariant,
        showIcon: showIcon,
        type: type,
        stickyProps: stickyProps,
        innerRef: containerRef,
        finished: getTimeDiff() < 0,
        "data-unify": "Timer"
      }, otherProps), description && React.createElement(TimerDescription, {
        type: type,
        colorVariant: colorVariant
      }, description), timerHTML);
    }
  };

  return renderTimer();
});
Timer.displayName = 'Timer';
export default Timer;