import styled, { css } from 'react-emotion';
import { RN50, RN600, YN500, YN600, TN600, NN0, NN0L, NN100, NN400, NN950, NN900RGB, TN50 } from 'unify-token/colors';
import { fontSizeLv1, fontSizeLv2, fontSizeLv3, fontSizeLv7 } from 'unify-token/build/v2/typographies';

var handleBackgroundColor = function handleBackgroundColor(_ref) {
  var day = _ref.day,
      colorVariant = _ref.colorVariant,
      type = _ref.type,
      finished = _ref.finished;

  switch (true) {
    case type === 'single' && finished:
      return NN100;

    case type === 'single' && colorVariant === 'main' && day > 4:
      return YN500;

    case colorVariant === 'main':
      return RN600;

    case colorVariant === 'general':
      return RN50;

    case colorVariant === 'informative':
      return TN50;

    case colorVariant === 'alternate':
      return NN0L;

    case colorVariant === 'informativeAlternate':
      return "rgba(".concat(NN900RGB, ", 0.48)");

    default:
      return RN50;
  }
};

export var handleTimerTextColor = function handleTimerTextColor(_ref2) {
  var day = _ref2.day,
      colorVariant = _ref2.colorVariant,
      type = _ref2.type,
      finished = _ref2.finished;

  switch (true) {
    case type === 'single' && finished:
      return NN400;

    case type === 'single' && colorVariant === 'alternate' && day > 4:
      return YN600;

    case colorVariant === 'alternate':
      return RN600;

    case colorVariant === 'informativeAlternate':
      return NN0L;

    case colorVariant === 'main':
      return NN0L;

    case colorVariant === 'general':
      return RN600;

    case colorVariant === 'informative':
      return TN600;

    default:
      return RN600;
  }
};

var handleDescriptionColor = function handleDescriptionColor(_ref3) {
  var colorVariant = _ref3.colorVariant,
      type = _ref3.type;

  switch (true) {
    case type === 'single' && colorVariant !== 'alternate' && colorVariant !== 'informativeAlternate':
      return NN950;

    case type === 'single' && (colorVariant === 'alternate' || colorVariant === 'informativeAlternate'):
      return NN0;

    case colorVariant === 'alternate' || colorVariant === 'general' || colorVariant === 'informative':
      return NN950;

    default:
      return NN0L;
  }
};

var handleBorderRadius = function handleBorderRadius(_ref4) {
  var type = _ref4.type;

  switch (true) {
    case type === 'sticky':
      return '';

    case type === 'full':
      return '8px';

    default:
      return '14px';
  }
};

var handlePadding = function handlePadding(_ref5) {
  var type = _ref5.type,
      showIcon = _ref5.showIcon;

  switch (true) {
    case type === 'full':
      return '0 12px';

    case type === 'sticky':
      return '0 16px';

    case !showIcon:
      return '0 8px 0 8px';

    default:
      return '0 8px 0 4px';
  }
};

export var TimerContainer = styled('div', {
  target: "e1ds5axq0"
})("max-width:100%;display:inline-flex;align-items:center;");
export var TimerLabel = styled("div", {
  target: "e1ds5axq1"
})("height:", function (_ref6) {
  var type = _ref6.type;
  return type !== 'full' ? '20px' : '28px';
}, ";line-height:", function (_ref7) {
  var type = _ref7.type;
  return type !== 'full' ? '20px' : '28px';
}, ";border-radius:", handleBorderRadius, ";background-color:", handleBackgroundColor, ";color:", handleTimerTextColor, ";padding:", handlePadding, ";display:", function (_ref8) {
  var type = _ref8.type;
  return type !== 'single' ? 'flex' : 'inline-flex';
}, ";flex-shrink:0;align-items:center;font-weight:bold;bottom:", function (_ref9) {
  var stickyProps = _ref9.stickyProps,
      type = _ref9.type;
  return type === 'sticky' && (stickyProps === null || stickyProps === void 0 ? void 0 : stickyProps.placement) === 'bottom' ? stickyProps === null || stickyProps === void 0 ? void 0 : stickyProps.distance : '';
}, ";top:", function (_ref10) {
  var stickyProps = _ref10.stickyProps,
      type = _ref10.type;
  return type === 'sticky' && (stickyProps === null || stickyProps === void 0 ? void 0 : stickyProps.placement) === 'top' ? stickyProps === null || stickyProps === void 0 ? void 0 : stickyProps.distance : '';
}, ";z-index:", function (_ref11) {
  var stickyProps = _ref11.stickyProps,
      type = _ref11.type;
  return type === 'sticky' ? stickyProps === null || stickyProps === void 0 ? void 0 : stickyProps.zIndex : '';
}, ";");
export var timerLabelSticky = css("position:fixed;height:28px;line-height:28px;width:100%;");
export var TimerDescription = styled('div', {
  target: "e1ds5axq2"
})("font-size:", fontSizeLv2, ";font-weight:normal;line-height:18px;color:", handleDescriptionColor, ";margin-right:", function (_ref12) {
  var type = _ref12.type;
  return type === 'single' ? '4px' : '';
}, ";flex-grow:", function (_ref13) {
  var type = _ref13.type;
  return type !== 'single' ? '1' : '';
}, ";white-space:nowrap;overflow:hidden;text-overflow:ellipsis;padding-right:4px;");
export var TimerText = styled('div', {
  target: "e1ds5axq3"
})("height:", fontSizeLv2, ";line-height:", fontSizeLv2, ";font-size:", fontSizeLv2, ";flex-shrink:0;overflow:hidden;");
export var TimerTextBox = styled('div', {
  target: "e1ds5axq4"
})("font-size:12px;text-align:center;display:inline-flex;position:relative;box-sizing:border-box;overflow:hidden;");
export var TimerTextNumber = styled('div', {
  target: "e1ds5axq5"
})("width:50%;position:relative;transform:translateY(-", fontSizeLv2, ");will-change:transform;div{font-size:12px;}");

var handleHighlightBoxColor = function handleHighlightBoxColor(_ref14) {
  var highlightColor = _ref14.highlightColor;

  switch (true) {
    case highlightColor === 'dark':
      return RN600;

    case highlightColor === 'alternate':
      return NN0;

    default:
      return RN50;
  }
};

var handleHighlightHeight = function handleHighlightHeight(_ref15) {
  var highlightSize = _ref15.highlightSize,
      highlightLabel = _ref15.highlightLabel;

  switch (true) {
    case highlightLabel && highlightSize === 'medium':
      return '65px';

    case highlightLabel && highlightSize === 'small':
      return '41px';

    default:
      return '';
  }
};

export var HighlightContainer = styled('div', {
  target: "e1ds5axq6"
})("height:", handleHighlightHeight, ";display:inline-flex;");
export var HighlightElement = styled('div', {
  target: "e1ds5axq7"
})("position:relative;text-align:center;margin:0 4px 0 4px;box-sizing:border-box;display:inline-block;vertical-align:top;&:first-child{margin-left:0;}&:last-child{margin-right:0;}");
export var HighlightBox = styled("div", {
  target: "e1ds5axq8"
})("position:relative;height:", function (_ref16) {
  var highlightSize = _ref16.highlightSize;
  return highlightSize === 'medium' ? '44px' : '24px';
}, ";width:", function (_ref17) {
  var highlightSize = _ref17.highlightSize;
  return highlightSize === 'medium' ? '44px' : '24px';
}, ";box-sizing:border-box;background:", handleHighlightBoxColor, ";color:", function (_ref18) {
  var highlightColor = _ref18.highlightColor;
  return highlightColor === 'dark' ? NN0L : RN600;
}, ";border-radius:", function (_ref19) {
  var highlightSize = _ref19.highlightSize;
  return highlightSize === 'medium' ? '8px' : '4px';
}, ";display:flex;justify-content:center;align-items:center;");
export var HighlightContent = styled("div", {
  target: "e1ds5axq9"
})("height:", function (_ref20) {
  var highlightSize = _ref20.highlightSize;
  return highlightSize === 'medium' ? fontSizeLv7 : fontSizeLv2;
}, ";width:100%;line-height:", function (_ref21) {
  var highlightSize = _ref21.highlightSize;
  return highlightSize === 'medium' ? fontSizeLv7 : fontSizeLv2;
}, ";overflow:hidden;font-weight:bold;overflow:hidden;box-sizing:border-box;position:relative;");
export var HighlightNumber = styled("div", {
  target: "e1ds5axq10"
})("width:50%;display:inline-block;vertical-align:top;transform:", function (_ref22) {
  var highlightSize = _ref22.highlightSize;
  return highlightSize === 'medium' ? "translateY(-".concat(fontSizeLv7, ")") : "translateY(-".concat(fontSizeLv2, ")");
}, ";will-change:transform;position:relative;div{font-size:", function (_ref23) {
  var highlightSize = _ref23.highlightSize;
  return highlightSize === 'medium' ? fontSizeLv7 : fontSizeLv2;
}, ";}");
export var HighlightSeparator = styled("span", {
  target: "e1ds5axq11"
})("display:inline-block;color:", function (_ref24) {
  var highlightColor = _ref24.highlightColor;
  return highlightColor === 'alternate' ? NN0 : RN600;
}, ";height:", function (_ref25) {
  var highlightSize = _ref25.highlightSize;
  return highlightSize === 'medium' ? '44px' : '24px';
}, ";line-height:", function (_ref26) {
  var highlightSize = _ref26.highlightSize;
  return highlightSize === 'medium' ? '44px' : '24px';
}, ";font-size:", function (_ref27) {
  var highlightSize = _ref27.highlightSize;
  return highlightSize === 'medium' ? fontSizeLv3 : fontSizeLv1;
}, ";");
export var HighlightLabel = styled("div", {
  target: "e1ds5axq12"
})("color:", function (_ref28) {
  var highlightColor = _ref28.highlightColor;
  return highlightColor === 'alternate' ? NN0 : NN950;
}, ";font-size:", function (_ref29) {
  var highlightSize = _ref29.highlightSize;
  return highlightSize === 'medium' ? fontSizeLv2 : '8px';
}, ";font-weight:normal;text-align:center;position:absolute;left:0;right:0;margin-top:4px;margin-right:-100%;margin-left:-100%;");