import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread2";
import React, { useEffect, useRef } from 'react';
import { cx } from 'emotion';
import { NN0L } from 'unify-token/colors';
import Delayed from "../../build/Providers/common/components/Delayed";
import PortalWrapper from "../../build/Providers/common/components/PortalWrapper";
import Typography from "../../build/Typography";
import { canUseDOM } from "../../build/Providers/common/functions";
import { ActionTextWrapper, Container } from "./style";

var Toaster = function Toaster(_ref) {
  var _ref$autoClose = _ref.autoClose,
      autoClose = _ref$autoClose === void 0 ? false : _ref$autoClose,
      _ref$autoCloseDuratio = _ref.autoCloseDuration,
      autoCloseDuration = _ref$autoCloseDuratio === void 0 ? 3000 : _ref$autoCloseDuratio,
      bottomDistance = _ref.bottomDistance,
      _ref$dataTest = _ref.dataTest,
      dataTest = _ref$dataTest === void 0 ? {} : _ref$dataTest,
      _ref$display = _ref.display,
      display = _ref$display === void 0 ? false : _ref$display,
      onClose = _ref.onClose,
      className = _ref.className,
      _ref$error = _ref.error,
      error = _ref$error === void 0 ? false : _ref$error,
      _ref$actionText = _ref.actionText,
      actionText = _ref$actionText === void 0 ? '' : _ref$actionText,
      onActionClick = _ref.onActionClick,
      children = _ref.children,
      onSwipeDown = _ref.onSwipeDown;
  var unmountAnimationDelay = 1000;
  var el = useRef(null);
  var xDown;
  var yDown = 0;
  var prevDisplayRef = useRef();
  var autoCloseTimeoutRef = useRef();
  useEffect(function () {
    prevDisplayRef.current = display;
  });
  var prevDisplay = prevDisplayRef.current;
  useEffect(function () {
    var containerEl = el.current;

    if (display && containerEl && !containerEl.classList.contains('unf-toaster--show') && canUseDOM) {
      setTimeout(function () {
        if (containerEl) {
          if (document.getElementsByClassName('unf-bottomnav').length > 0) {
            containerEl.classList.add('unf-toaster--bottomnav');
          } else {
            containerEl.classList.remove('unf-toaster--bottomnav');
          }

          if (document.getElementsByClassName('unf-btn__floating-container').length > 0) {
            containerEl.classList.add('unf-toaster--btn');
          } else {
            containerEl.classList.remove('unf-toaster--btn');
          }

          if (document.getElementsByClassName('unf-overlay').length > 0) {
            containerEl.classList.add('unf-toaster--overlay');
          } else {
            containerEl.classList.remove('unf-toaster--overlay');
          }

          if (document.getElementsByClassName('unf-bottomsheet').length > 0) {
            containerEl.classList.add('unf-toaster--bottomsheet');
          } else {
            containerEl.classList.remove('unf-toaster--bottomsheet');
          }

          containerEl.classList.add('unf-toaster--show');
        }
      }, 1);
    } else if (containerEl && prevDisplay !== display && !display) {
      containerEl.classList.remove('unf-toaster--show');
      containerEl.classList.add('unf-toaster--hide');
    }

    if (!prevDisplay && display && onClose && autoClose) {
      autoCloseTimeoutRef.current = setTimeout(function () {
        onClose();
      }, autoCloseDuration);
    }
  }, [autoClose, autoCloseDuration, display, onClose, prevDisplay]);
  useEffect(function () {
    if (!display && prevDisplay) {
      clearTimeout(autoCloseTimeoutRef.current);
    }
  }, [display, prevDisplay]);

  var setContainerRef = function setContainerRef(element) {
    el.current = element;
    var containerEl = el.current;

    if (display && containerEl) {
      setTimeout(function () {
        if (containerEl) {
          if (document.getElementsByClassName('unf-bottomnav').length > 0) {
            containerEl.classList.add('unf-toaster--bottomnav');
          }

          if (document.getElementsByClassName('unf-btn__floating-container').length > 0) {
            containerEl.classList.add('unf-toaster--btn');
          }

          if (document.getElementsByClassName('unf-overlay').length > 0) {
            containerEl.classList.add('unf-toaster--overlay');
          }

          if (document.getElementsByClassName('unf-bottomsheet').length > 0) {
            containerEl.classList.add('unf-toaster--bottomsheet');
          }

          containerEl.classList.add('unf-toaster--show');
        }
      }, 1);
    }
  };

  var handleTouchStart = function handleTouchStart(e) {
    xDown = e.touches[0].clientX;
    yDown = e.touches[0].clientY;
  };

  var handleTouchMove = function handleTouchMove(e) {
    if (!xDown || !yDown) {
      return false;
    }

    var xUp = e.touches[0].clientX;
    var yUp = e.touches[0].clientY;
    var xDiff = xDown - xUp;
    var yDiff = yDown - yUp;

    if (Math.abs(xDiff) > Math.abs(yDiff)) {
      if (xDiff > 0) {} else {}
    } else if (yDiff > 0) {} else {
      onSwipeDown ? onSwipeDown() : null;
    }

    xDown = null;
    yDown = null;
  };

  var classes = cx('unf-toaster', {
    'unf-toaster--error': error
  }, className);
  var containerProps = {
    distance: bottomDistance,
    className: classes,
    error: error,
    innerRef: setContainerRef,
    onTouchStart: handleTouchStart,
    onTouchMove: handleTouchMove
  };

  var renderChild = function renderChild() {
    var customStyle = {
      color: NN0L,
      display: 'inline-block',
      verticalAlign: 'middle'
    };
    var style1 = {
      width: '85%'
    };
    return actionText ? React.createElement(React.Fragment, null, React.createElement(Typography, {
      caption: true,
      "data-testid": dataTest.text,
      margin: "0",
      style: _objectSpread(_objectSpread({}, customStyle), style1)
    }, children), React.createElement(ActionTextWrapper, {
      type: "button"
    }, React.createElement(Typography, {
      bold: true,
      caption: true,
      "data-testid": dataTest.actionText,
      margin: "0",
      style: _objectSpread({}, customStyle),
      actionText: actionText,
      onClick: onActionClick
    }, actionText))) : children;
  };

  var dataTestProps = {
    'data-testid': dataTest.text
  };
  var testId = !actionText && dataTestProps;
  return React.createElement(PortalWrapper, null, React.createElement(Delayed, {
    mounted: display,
    unmountAfter: unmountAnimationDelay
  }, React.createElement(Container, _extends({}, testId, {
    "data-unify": "Toaster",
    role: "alert"
  }, containerProps), renderChild())));
};

export default Toaster;