import React from 'react';
declare type ToasterAttributes = React.ComponentPropsWithoutRef<'div'>;
export interface ToasterProps extends Omit<ToasterAttributes, 'css'> {
    /**
     * To specify action text on right
     */
    actionText?: string;
    /**
     * To toggle autoClose
     * @default false
     */
    autoClose?: boolean;
    /**
     * To determine timeout duration before closing
     * @default 3000
     */
    autoCloseDuration?: number;
    /**
     * To set Toaster **extra** length of distance from bottom. By default Toaster distance is `24px` from the bottom, if you set the `bottomDistance` value , it will be **compounded** with the default distance
     */
    bottomDistance?: string | number;
    /**
     * To specify content on Toaster
     */
    children?: React.ReactNode;
    /**
     * To pass custom className to create custom styles
     */
    className?: string;
    /**
     * To pass data-testid on Toaster
     * @default {}
     */
    dataTest?: {
        actionText?: string;
        text?: string;
    };
    /**
     * To toggle visibility on Toaster
     * @default false
     */
    display?: boolean;
    /**
     * To apply error Toaster design
     * @default false
     */
    error?: boolean;
    /**
     * To pass callback when action text is clicked
     */
    onActionClick?: (e: React.MouseEvent<HTMLHeadingElement | HTMLParagraphElement | HTMLAnchorElement>) => void;
    /**
     * To pass callback when Toaster is closed
     */
    onClose?: () => void;
    /**
     * To pass callback when Toaster is swiped down
     */
    onSwipeDown?: () => void;
}
export {};
