import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["backgroundColor", "backgroundImage", "className", "description", "imageAlt", "imageAsBanner", "imageRatio", "imageSize", "imageSrc", "inverted", "lang", "linkText", "linkUrl", "title", "titleSize", "onClick"];
import React, { useEffect, useRef, useState } from 'react';
import ChevronRight from 'unify-icons/system/ChevronRight';
import { GN500 } from 'unify-token/colors';
import Typography from "../../build/Typography";
import Image from "../../build/Image";
import { colorWhiteAlways } from "../../build/Providers/common/style";
import { Container, contentLinkWrapper, imgBannerWrapper, linkWrapper, linkIconWrapper } from "./style";

var ViewAllCard = function ViewAllCard(_ref) {
  var backgroundColor = _ref.backgroundColor,
      backgroundImage = _ref.backgroundImage,
      className = _ref.className,
      description = _ref.description,
      imageAlt = _ref.imageAlt,
      imageAsBanner = _ref.imageAsBanner,
      imageRatio = _ref.imageRatio,
      imageSize = _ref.imageSize,
      imageSrc = _ref.imageSrc,
      inverted = _ref.inverted,
      _ref$lang = _ref.lang,
      lang = _ref$lang === void 0 ? 'id' : _ref$lang,
      linkText = _ref.linkText,
      linkUrl = _ref.linkUrl,
      title = _ref.title,
      titleSize = _ref.titleSize,
      _onClick = _ref.onClick,
      otherProps = _objectWithoutProperties(_ref, _excluded);

  var ariaLabels = {
    en: 'See All',
    id: 'Lihat Semua'
  };

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      cardHeight = _useState2[0],
      setCardHeight = _useState2[1];

  var containerRef = useRef(null);
  var shortestCard = cardHeight < 65;
  useEffect(function () {
    if (containerRef.current) {
      var containerHeight = containerRef.current.offsetHeight;
      setCardHeight(containerHeight);
    }
  }, []);

  var handleLinkColor = function handleLinkColor(_ref2) {
    var backgroundColor = _ref2.backgroundColor,
        inverted = _ref2.inverted;

    switch (true) {
      case Boolean(backgroundColor) || inverted:
        return colorWhiteAlways;

      default:
        return GN500;
    }
  };

  var handleFontColor = function handleFontColor(_ref3) {
    var backgroundColor = _ref3.backgroundColor,
        inverted = _ref3.inverted;

    switch (true) {
      case Boolean(backgroundColor) || inverted:
        return colorWhiteAlways;

      default:
        return 'initial';
    }
  };

  var handleFontSize = function handleFontSize(_ref4) {
    var titleSize = _ref4.titleSize;

    switch (true) {
      case titleSize === 'large':
        return {
          tag: 3
        };

      default:
        return {
          body: 2,
          bold: true,
          main: true
        };
    }
  };

  var renderContent = function renderContent() {
    var renderDescription = function renderDescription() {
      return description && React.createElement(Typography, {
        body: 3,
        color: (backgroundColor || inverted) && handleFontColor({
          backgroundColor: backgroundColor,
          inverted: inverted
        }),
        main: true,
        margin: shortestCard ? '0 0 4px 0' : '0'
      }, description);
    };

    if (imageSrc) {
      return React.createElement(React.Fragment, null, React.createElement(Image, {
        className: imageAsBanner ? imgBannerWrapper : '',
        product: true,
        src: imageSrc,
        size: imageSize,
        ratio: imageRatio,
        alt: imageAlt,
        style: {
          marginBottom: description ? '2px' : '0',
          height: imageAsBanner ? '100%' : 'auto'
        }
      }), renderDescription());
    } else if (title) {
      return React.createElement(React.Fragment, null, React.createElement(Typography, _extends({
        color: (backgroundColor || inverted) && handleFontColor({
          backgroundColor: backgroundColor,
          inverted: inverted
        }),
        main: true,
        margin: "0 0 2px"
      }, handleFontSize({
        titleSize: titleSize
      })), title), renderDescription());
    } else {
      return renderDescription();
    }
  };

  var renderLink = function renderLink() {
    if (linkText) {
      return React.createElement(Typography, {
        body: 3,
        caption: true,
        className: linkWrapper,
        color: backgroundColor || inverted ? "".concat(colorWhiteAlways) : '',
        link: linkUrl,
        style: {
          position: shortestCard ? 'relative' : undefined,
          bottom: shortestCard ? '0' : undefined,
          width: shortestCard ? '100%' : undefined
        }
      }, React.createElement("span", null, linkText), React.createElement(ChevronRight, {
        color: handleLinkColor({
          backgroundColor: backgroundColor,
          inverted: inverted
        }),
        size: 16
      }));
    } else if (!imageAsBanner) {
      return React.createElement("a", {
        "aria-label": ariaLabels[String(lang)],
        className: linkIconWrapper,
        href: linkUrl,
        target: "_blank",
        rel: "noreferrer"
      }, React.createElement(ChevronRight, {
        color: GN500,
        size: 24
      }));
    } else {
      return null;
    }
  };

  var ConditionalContentWrapper = function ConditionalContentWrapper(_ref5) {
    var children = _ref5.children,
        condition = _ref5.condition,
        wrapper = _ref5.wrapper;
    return condition ? wrapper(children) : children;
  };

  return React.createElement(ConditionalContentWrapper, {
    condition: Boolean(linkUrl),
    wrapper: function wrapper(children) {
      return React.createElement("a", {
        className: contentLinkWrapper,
        href: linkUrl,
        target: "_blank",
        rel: "noreferrer"
      }, children);
    }
  }, React.createElement(Container, _extends({
    innerRef: containerRef,
    cardHeight: cardHeight,
    backgroundColor: backgroundColor,
    backgroundImage: backgroundImage,
    className: className,
    inverted: inverted,
    titleSize: titleSize,
    onClick: function onClick(e) {
      return _onClick && _onClick(e);
    },
    style: {
      padding: imageAsBanner ? '0' : undefined
    }
  }, otherProps), React.createElement("div", {
    className: "unf-card__content--wrapper"
  }, renderContent()), renderLink()));
};

export default ViewAllCard;